@@ -1,15 +1,15 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _GUI_PLUGIN_HPP_
-#define _GUI_PLUGIN_HPP_
+#ifndef __GUI_PLUGIN_HPP__
+#define __GUI_PLUGIN_HPP__
 
 #include <fwRuntime/Plugin.hpp>
 
-#include "gui/export.hpp"
+#include "gui/config.hpp"
 
 namespace gui
 {
@@ -24,8 +24,8 @@ class GUI_CLASS_API Plugin : public ::fwRuntime::Plugin
 
 public:
 
-     ///@brief  Destructor. Do nothing.
-    GUI_API virtual ~Plugin() throw();
+    ///@brief  Destructor. Do nothing.
+    GUI_API virtual ~Plugin() noexcept;
 
     /**
      * @brief This method is used by runtime to initialize the bundle.
@@ -35,15 +35,15 @@ public:
      * Register first basic services of type IAction, IEditor and IView.
      * Secondly, verifies if the command line and profile.xml are well formed and starts the wxWidgets IHM.
      */
-    GUI_API void start() throw(::fwRuntime::RuntimeException);
+    GUI_API void start();
 
     /**
-    * @brief This method is used by runtime to close the bundle. Do nothing.
-    */
-    GUI_API void stop() throw();
+     * @brief This method is used by runtime to close the bundle. Do nothing.
+     */
+    GUI_API void stop() noexcept;
 
 };
 
 } // namespace gui
 
-#endif //_GUI_PLUGIN_HPP_
+#endif //__GUI_PLUGIN_HPP__
