@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -13,17 +13,20 @@ namespace gui
 
 static ::fwRuntime::utils::GenericExecutableFactoryRegistrar<Plugin> registrar("::gui::Plugin");
 
-Plugin::~Plugin() throw()
-{}
+Plugin::~Plugin() noexcept
+{
+}
 
 //-----------------------------------------------------------------------------
 
-void Plugin::start() throw(::fwRuntime::RuntimeException)
-{}
+void Plugin::start()
+{
+}
 
 //-----------------------------------------------------------------------------
 
-void Plugin::stop() throw()
-{}
+void Plugin::stop() noexcept
+{
+}
 
 } // namespace gui
