@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _MEMORY_PLUGIN_HPP_
-#define _MEMORY_PLUGIN_HPP_
+#ifndef __MEMORY_PLUGIN_HPP__
+#define __MEMORY_PLUGIN_HPP__
 
 #include <fwRuntime/Plugin.hpp>
 
@@ -19,7 +19,7 @@ struct Plugin : public ::fwRuntime::Plugin
     /**
      * @brief   Destructor
      */
-    ~Plugin() throw();
+    ~Plugin() noexcept;
 
     /**
      * @brief Start method. (does nothing)
@@ -28,17 +28,17 @@ struct Plugin : public ::fwRuntime::Plugin
      *
      * @exception ::fwRuntime::RuntimeException.
      */
-    void start() throw(::fwRuntime::RuntimeException);
+    void start();
 
     /**
      * @brief Stop method. (does nothing)
      *
      * This method is used by runtime in order to close the bundle.
      */
-    void stop() throw();
+    void stop() noexcept;
 
 };
 
 } // namespace memory
 
-#endif //_MEMORY_PLUGIN_HPP_
+#endif //__MEMORY_PLUGIN_HPP__
