@@ -1,42 +1,41 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _SERVICESREG_PLUGIN_HPP_
-#define _SERVICESREG_PLUGIN_HPP_
-
-#include <fwRuntime/Plugin.hpp>
+#ifndef __SERVICESREG_PLUGIN_HPP__
+#define __SERVICESREG_PLUGIN_HPP__
 
 #include "servicesReg/config.hpp"
 
+#include <fwRuntime/Plugin.hpp>
+
 namespace servicesReg
 {
 
 /**
  * @brief   This class is started when the bundles is loaded.
- * @class   Plugin
  */
 struct SERVICESREG_CLASS_API Plugin : public ::fwRuntime::Plugin
 {
     /// Destructor. Do nothing.
-    SERVICESREG_API ~Plugin() throw();
+    SERVICESREG_API ~Plugin() noexcept;
 
-    /// Overrides start method. Service declarations (services declared in fwServices / fwComEd libraries ).
-    SERVICESREG_API void start() throw(::fwRuntime::RuntimeException);
+    /// Overrides start method. Service declarations (services declared in fwServices libraries ).
+    SERVICESREG_API void start();
 
     /// Overrides initialize method
-    SERVICESREG_API void initialize() throw( ::fwRuntime::RuntimeException );
+    SERVICESREG_API void initialize();
 
     /// Overrides uninitialize method
-    SERVICESREG_API void uninitialize() throw( ::fwRuntime::RuntimeException );
+    SERVICESREG_API void uninitialize();
 
     /// Overrides stop method. Do nothing
-    SERVICESREG_API void stop() throw();
+    SERVICESREG_API void stop() noexcept;
 
 };
 
 } // namespace servicesReg
 
-#endif // _SERVICESREG_PLUGIN_HPP_
+#endif // __SERVICESREG_PLUGIN_HPP__
