@@ -33,6 +33,8 @@
 #include <fwJobs/Aggregator.hpp>
 #include <fwJobs/Job.hpp>
 
+#include <fwMDSemanticPatch/PatchLoader.hpp>
+
 #include <fwServices/macros.hpp>
 
 #include <fwZip/WriteDirArchive.hpp>
@@ -42,6 +44,8 @@
 #include <boost/assign.hpp>
 #include <boost/filesystem/path.hpp>
 
+#include <regex>
+
 namespace ioAtoms
 {
 
@@ -85,55 +89,55 @@ void SWriter::configuring()
 {
     ::fwIO::IWriter::configuring();
 
-    typedef SPTR (::fwRuntime::ConfigurationElement) ConfigurationElement;
-    typedef std::vector < ConfigurationElement >    ConfigurationElementContainer;
-
     m_customExts.clear();
     m_allowedExtLabels.clear();
 
-    ConfigurationElementContainer customExtsList = m_configuration->find("archive");
-    for(ConfigurationElement archive :  customExtsList)
+    const ConfigType config = this->getConfigTree();
+
+    const auto archiveCfgs = config.equal_range("archive");
+
+    for (auto it = archiveCfgs.first; it != archiveCfgs.second; ++it)
     {
-        const std::string& backend = archive->getAttributeValue("backend");
+        const std::string backend = it->second.get<std::string>("<xmlattr>.backend");
         SLM_ASSERT("No backend attribute given in archive tag", backend != "");
         SLM_ASSERT("Unsupported backend '" + backend + "'",
                    SReader::s_EXTENSIONS.find("." + backend) != SReader::s_EXTENSIONS.end());
 
-        ConfigurationElementContainer exts = archive->find("extension");
-        for(ConfigurationElement ext :  exts)
+        const auto extCfgs = it->second.equal_range("extension");
+
+        for (auto itExt = extCfgs.first; itExt != extCfgs.second; ++itExt)
         {
-            const std::string& extension = ext->getValue();
+            const std::string extension = itExt->second.get<std::string>("");
             SLM_ASSERT("No extension given for backend '" + backend + "'", !extension.empty());
             SLM_ASSERT("Extension must begin with '.'", extension[0] == '.');
 
             m_customExts[extension]       = backend;
-            m_allowedExtLabels[extension] = ext->getAttributeValue("label");
+            m_allowedExtLabels[extension] = itExt->second.get("<xmlattr>.label", "");
         }
     }
 
-    ConfigurationElementContainer extensionsList = m_configuration->find("extensions");
-    SLM_ASSERT("The <extensions> element can be set at most once.", extensionsList.size() <= 1);
+    const auto extensionsCfg = config.get_child_optional("extensions");
 
-    if(extensionsList.size() == 1)
+    if (extensionsCfg)
     {
         m_allowedExts.clear();
 
-        ConfigurationElementContainer extensions = extensionsList.at(0)->find("extension");
-        for(ConfigurationElement extension :  extensions)
+        const auto extCfgs = extensionsCfg->equal_range("extension");
+        for (auto it = extCfgs.first; it != extCfgs.second; ++it)
         {
-            const std::string& ext = extension->getValue();
+            const std::string ext = it->second.get<std::string>("");
 
             // The extension must be found either in custom extensions list or in known extensions
             FileExtension2NameType::const_iterator itKnown  = SReader::s_EXTENSIONS.find(ext);
             FileExtension2NameType::const_iterator itCustom = m_customExts.find(ext);
 
             const bool extIsKnown = (itKnown != SReader::s_EXTENSIONS.end() || itCustom != m_customExts.end());
-            OSLM_ASSERT("Extension '" << ext << "' is not allowed in configuration", extIsKnown);
+            SLM_ASSERT("Extension '" + ext + "' is not allowed in configuration", extIsKnown);
 
             if(extIsKnown)
             {
                 m_allowedExts.insert(m_allowedExts.end(), ext);
-                m_allowedExtLabels[ext] = extension->getAttributeValue("label");
+                m_allowedExtLabels[ext] = it->second.get("<xmlattr>.label", "");
             }
         }
     }
@@ -153,13 +157,13 @@ void SWriter::configuring()
         }
     }
 
-    ConfigurationElementContainer patcher = m_configuration->find("patcher");
-    SLM_ASSERT("The <patcher> element can be set at most once.", patcher.size() <= 1 );
-    if (patcher.size() == 1)
+    const auto patcherCfg = config.get_child_optional("patcher");
+
+    if (patcherCfg)
     {
-        m_context         = patcher.at(0)->getExistingAttributeValue("context");
-        m_version         = patcher.at(0)->getExistingAttributeValue("version");
-        m_exportedVersion = m_version;
+        m_context = patcherCfg->get<std::string>("<xmlattr>.context", "MedicalData");
+        m_version = patcherCfg->get<std::string>("<xmlattr>.version",
+                                                 ::fwMDSemanticPatch::PatchLoader::getCurrentVersion());
         m_useAtomsPatcher = true;
     }
 }
@@ -184,16 +188,104 @@ bool SWriter::versionSelection()
         else
         {
             versions.push_back(m_version);
+
+            std::transform(versions.begin(), versions.end(), versions.begin(), [](const std::string& _version)
+                {
+                    static const std::regex ala("ALA");
+                    return std::regex_replace(_version, ala, "");
+                } );
+
+            // Sort versions according to repository/number. This is not really honnest since we should not make any
+            // assumption about the versioning convention, especially for child repositories... But since this is
+            // how things are organized currently I don't think this is such a big issue
+            std::sort(versions.begin(), versions.end(), [](const std::string& _a, const std::string& _b)
+                {
+                    try
+                    {
+                        // Assume a pattern like V[0-9][0-9][A-Z][A-Z][A-Z]
+                        // Sort with the version number
+                        const std::string repoA = _a.substr(3, _a.size());
+                        const std::string repoB = _b.substr(3, _b.size());
+                        if(repoA == repoB)
+                        {
+                            const std::string numA = _a.substr(1, 2);
+                            const std::string numB = _b.substr(1, 2);
+                            return numA > numB;
+                        }
+                        return repoA < repoB;
+                    }
+                    catch ( std::out_of_range e)
+                    {
+                        OSLM_ERROR("Bad version format: either " + _a + " or " + _b);
+                        return false;
+                    }
+                });
+
+            std::vector< std::string > prettyVersionsAll;
+            std::map< std::string, std::string > prettyVersionsToVersions;
+
+            for(const auto& v : versions)
+            {
+                try
+                {
+                    const std::string num  = v.substr(0, 3);
+                    const std::string repo = v.substr(3, v.size());
+
+                    const std::string prettyVersion = num + ((repo.empty()) ? "" : " (" + repo + ")");
+                    prettyVersionsAll.push_back(prettyVersion);
+                    prettyVersionsToVersions[ prettyVersion ] = v;
+
+                }
+                catch ( std::out_of_range e)
+                {
+                    OSLM_ERROR("Bad version format: " + v);
+
+                    prettyVersionsAll.push_back(v);
+                    prettyVersionsToVersions[ v ] = v;
+                }
+            }
+
+            // Create a shortened list of versions, with only the latest ones of each repo
+            std::vector< std::string > prettyVersions;
+            prettyVersions.push_back(prettyVersionsAll[0]);
+            for(auto itVersion = prettyVersionsAll.begin() + 1; itVersion != prettyVersionsAll.end(); ++itVersion)
+            {
+                const auto& versionA    = *(itVersion - 1);
+                const auto& versionB    = *(itVersion);
+                const std::string repoA = versionA.substr(3, versionA.size());
+                const std::string repoB = versionB.substr(3, versionB.size());
+
+                if(repoA != repoB)
+                {
+                    prettyVersions.push_back(versionB);
+                }
+            }
+
             ::fwGui::dialog::SelectorDialog dialogVersion;
 
             dialogVersion.setTitle("Archive version");
             dialogVersion.setMessage("Select an archive version");
 
-            dialogVersion.setSelections(versions);
+            bool selectAmongstAllVersions = false;
+            dialogVersion.addCustomButton("Advanced", [&selectAmongstAllVersions]()
+                {
+                    selectAmongstAllVersions = true;
+                });
+
+            dialogVersion.setSelections(prettyVersions);
             std::string result = dialogVersion.show();
-            if ( !result.empty() )
+            if(selectAmongstAllVersions)
             {
-                m_exportedVersion = result;
+                ::fwGui::dialog::SelectorDialog dialogVersionAll;
+
+                dialogVersionAll.setTitle("Archive version");
+                dialogVersionAll.setMessage("Select an archive version");
+                dialogVersionAll.setSelections(prettyVersionsAll);
+                result = dialogVersionAll.show();
+            }
+            if( !result.empty() )
+            {
+                m_exportedVersion = prettyVersionsToVersions[result];
             }
             return !result.empty();
         }
@@ -214,7 +306,12 @@ void SWriter::updating()
         return;
     }
 
-    ::fwData::Object::sptr obj = this->getObject< ::fwData::Object >();
+    ::fwData::Object::csptr obj = this->getInput< ::fwData::Object >(::fwIO::s_DATA_KEY);
+    if (!obj)
+    {
+        FW_DEPRECATED_KEY(::fwIO::s_DATA_KEY, "inout", "18.0");
+        obj = this->getObject< ::fwData::Object >();
+    }
 
     ::fwGui::Cursor cursor;
     cursor.setCursor(::fwGui::ICursor::BUSY);
@@ -284,7 +381,7 @@ void SWriter::updating()
         {
             runningJob.doneWork(progressBarOffset);
 
-            atom = ::fwAtomConversion::convert(obj);
+            atom = ::fwAtomConversion::convert(::fwData::Object::constCast(obj));
             runningJob.done();
         }, m_associatedWorker );
 
