@@ -21,7 +21,23 @@ class Image;
 
 namespace ioITK
 {
-
+/**
+ * @brief Reader for .inr.gz image
+ *
+ * @section XML XML Configuration
+ *
+ * @code{.xml}
+   <service type="::ioITK::InrImageReaderService">
+       <inout key="data" uid="..." />
+       <file>...</file>
+   </service>
+   @endcode
+ * @subsection In-Out In-Out
+ * - \b data [::fwData::Image]: loaded image.
+ * @subsection Configuration Configuration
+ * - \b file (optional): path of the image to load, if it is not defined, 'configureWithIHM()' should be called to
+ * define the path.
+ */
 class IOITK_CLASS_API InrImageReaderService : public ::fwIO::IReader
 {
 
