@@ -1,21 +1,15 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __OPIMAGEFILTER_NAMESPACE_HPP__
-#define __OPIMAGEFILTER_NAMESPACE_HPP__
+#pragma once
 
 /**
  * @brief       The namespace opImageFilter contains several operators on image.
- * @namespace   opImageFilter
- *
- * @date        2009-2010.
- *
  */
 namespace opImageFilter
 {
 
 }
-#endif /* __OPIMAGEFILTER_NAMESPACE_HPP__ */
