@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __UIMEASUREMENT_ACTION_ADDDISTANCE_HPP__
-#define __UIMEASUREMENT_ACTION_ADDDISTANCE_HPP__
+#pragma once
 
 #include "uiMeasurement/config.hpp"
 
@@ -17,7 +16,17 @@ namespace action
 {
 
 /**
- * @brief   This action adds distance on image.
+ * @brief This action adds distances on an image field.
+ *
+ * @section XML XML Configuration
+ *
+ * @code{.xml}
+   <service type="::uiMeasurement::action::AddDistance">
+       <inout key="image" uid="..." />
+   </service>
+   @endcode
+ * @subsection In-Out In-Out
+ * - \b image [::fwData::Image]: image containing the distance field.
  */
 class UIMEASUREMENT_CLASS_API AddDistance : public ::fwGui::IActionSrv
 {
@@ -38,14 +47,8 @@ protected:
 
     void stopping() override;
 
-    UIMEASUREMENT_API void info(std::ostream& _sstream ) override;
-
-private:
-    int m_actionCheckId;
 };
 
 } // namespace action
 
 } // namespace uiMeasurement
-
-#endif // __UIMEASUREMENT_ACTION_ADDDISTANCE_HPP__
