@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __UIMEASUREMENT_ACTION_REMOVEDISTANCE_HPP__
-#define __UIMEASUREMENT_ACTION_REMOVEDISTANCE_HPP__
+#pragma once
 
 #include "uiMeasurement/config.hpp"
 
@@ -21,7 +20,20 @@ namespace action
 {
 
 /**
- * @brief   This action removes distances.
+ */
+
+/**
+ * @brief   This action removes distances from the image field.
+ *
+ * @section XML XML Configuration
+ *
+ * @code{.xml}
+   <service type="::uiMeasurement::action::RemoveDistance">
+       <inout key="image" uid="..." />
+   </service>
+   @endcode
+ * @subsection In-Out In-Out
+ * - \b image [::fwData::Image]: image containing the distance field.
  */
 class UIMEASUREMENT_CLASS_API RemoveDistance : public ::fwGui::IActionSrv
 {
@@ -42,8 +54,6 @@ protected:
 
     void stopping() override;
 
-    UIMEASUREMENT_API void info(std::ostream& _sstream ) override;
-
 private:
     void notifyNewDistance(const ::fwData::Image::csptr& image, const ::fwData::PointList::sptr& distance) const;
 
@@ -53,5 +63,3 @@ private:
 } // namespace action
 
 } // namespace uiMeasurement
-
-#endif // __UIMEASUREMENT_ACTION_REMOVEDISTANCE_HPP__
