@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __UIMEASUREMENT_ACTION_REMOVELANDMARK_HPP__
-#define __UIMEASUREMENT_ACTION_REMOVELANDMARK_HPP__
+#pragma once
 
 #include "uiMeasurement/config.hpp"
 
@@ -21,7 +20,17 @@ namespace action
 {
 
 /**
- * @brief   This action removes landmarks.
+ * @brief   This action removes landmarks from an image.
+ *
+ * @section XML XML Configuration
+ *
+ * @code{.xml}
+   <service type="::uiMeasurement::action::RemoveLandmark">
+       <inout key="image" uid="..." />
+   </service>
+   @endcode
+ * @subsection In-Out In-Out
+ * - \b image [::fwData::Image]: image containing the field of landmarks.
  */
 class UIMEASUREMENT_CLASS_API RemoveLandmark : public ::fwGui::IActionSrv
 {
@@ -53,5 +62,3 @@ private:
 } // namespace action
 
 } // namespace uiMeasurement
-
-#endif // __UIMEASUREMENT_ACTION_REMOVELANDMARK_HPP__
