@@ -1,20 +1,15 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __VISUVTK_NAMESPACE_HPP__
-#define __VISUVTK_NAMESPACE_HPP__
+#pragma once
 
 /**
  * @brief       The namespace visuVTK supplies a  default plugin implementation for the visuVTK bundle.
- * @namespace   visuVTK
- *
- * @date        2009-2010.
  *
  */
 namespace visuVTK
 {
 }
-#endif /* __VISUVTK_NAMESPACE_HPP__ */
