@@ -1,23 +1,19 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __VISUVTK_PLUGIN_HPP__
-#define __VISUVTK_PLUGIN_HPP__
-
-#include <fwRuntime/Plugin.hpp>
+#pragma once
 
 #include "visuVTK/config.hpp"
 
+#include <fwRuntime/Plugin.hpp>
+
 namespace visuVTK
 {
 /**
  * @brief   This class is started when the bundles is loaded.
- * @class   Plugin
- *
- * @date    2009.
  */
 struct VISUVTK_CLASS_API Plugin : public ::fwRuntime::Plugin
 {
@@ -26,14 +22,12 @@ struct VISUVTK_CLASS_API Plugin : public ::fwRuntime::Plugin
      */
     ~Plugin() noexcept;
 
-    // Overrides
+    /// Overrides
     VISUVTK_API void start();
 
-    // Overrides
+    /// Overrides
     VISUVTK_API void stop() noexcept;
 
 };
 
 } // namespace visuVTK
-
-#endif //__VISUVTK_PLUGIN_HPP__
