@@ -1,21 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __TUTO02DATASERVICEBASICCTRL_PLUGIN_HPP__
-#define __TUTO02DATASERVICEBASICCTRL_PLUGIN_HPP__
+#pragma once
 
-#include <fwRuntime/Plugin.hpp>
-
-#include <fwCom/Connection.hpp>
+#include "Tuto02DataServiceBasicCtrl/config.hpp"
 
 #include <fwData/Image.hpp>
 
-#include <fwServices/IService.hpp>
+#include <fwRuntime/Plugin.hpp>
 
-#include "Tuto02DataServiceBasicCtrl/config.hpp"
+#include <fwServices/IService.hpp>
 
 namespace Tuto02DataServiceBasicCtrl
 {
@@ -51,5 +48,3 @@ private:
 };
 
 } // namespace Tuto02DataServiceBasicCtrl
-
-#endif // __TUTO02DATASERVICEBASICCTRL_PLUGIN_HPP__
