@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,14 +7,10 @@
 #ifndef __FWACTIVITIES_BUILDER_FACTORY_NEW_HPP__
 #define __FWACTIVITIES_BUILDER_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
-#include "fwActivities/config.hpp"
 #include "fwActivities/builder/registry/detail.hpp"
+#include "fwActivities/config.hpp"
+
+#include <string>
 
 namespace fwActivities
 {
@@ -26,7 +22,6 @@ namespace builder
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -35,17 +30,19 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwActivities::builder::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwActivities::builder::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
 FWACTIVITIES_API SPTR( ::fwActivities::IBuilder ) New( const ::fwActivities::builder::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) builder = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) builder = std::make_shared< CLASSNAME >( Key() );
     return builder;
 }
 
@@ -55,4 +52,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWACTIVITIES_BUILDER_FACTORY_NEW_HPP__ */
 
-
