@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWACTIVITIES_BUILDER_REGISTRY_MACRO_HPP__
-#define __FWACTIVITIES_BUILDER_REGISTRY_MACRO_HPP__
+#ifndef __FWACTIVITIES_BUILDER_REGISTRY_MACROS_HPP__
+#define __FWACTIVITIES_BUILDER_REGISTRY_MACROS_HPP__
 
 #include <boost/preprocessor/cat.hpp>
 
@@ -27,4 +27,4 @@ namespace registry
 } // end namespace builder
 } // end namespace fwActivities
 
-#endif /*__FWACTIVITIES_BUILDER_REGISTRY_MACRO_HPP__*/
+#endif /*__FWACTIVITIES_BUILDER_REGISTRY_MACROS_HPP__*/
