@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWACTIVITIES_VALIDATOR_RELATEDSTUDY_HPP__
-#define __FWACTIVITIES_VALIDATOR_RELATEDSTUDY_HPP__
+#pragma once
 
 #include "fwActivities/config.hpp"
 #include "fwActivities/IValidator.hpp"
@@ -40,11 +39,8 @@ public:
      */
     FWACTIVITIES_API virtual IValidator::ValidationType validate(
         const ::fwActivities::registry::ActivityInfo& activityInfo,
-        SPTR(::fwData::Vector) currentSelection ) const override;
+        const CSPTR(::fwData::Vector)& currentSelection ) const override;
 };
 
 } // namespace validator
 } // namespace fwActivities
-
-#endif // __FWACTIVITIES_VALIDATOR_RELATEDSTUDY_HPP__
-
