@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,11 @@
 #ifndef __FWACTIVITIES_VALIDATOR_FACTORY_NEW_HPP__
 #define __FWACTIVITIES_VALIDATOR_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwActivities/config.hpp"
 #include "fwActivities/validator/registry/detail.hpp"
 
+#include <string>
+
 namespace fwActivities
 {
 
@@ -26,7 +22,6 @@ namespace validator
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -35,17 +30,20 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwActivities::validator::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwActivities::validator::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
-FWACTIVITIES_API SPTR( ::fwActivities::IValidator ) New( const ::fwActivities::validator::registry::KeyType & classname );
+FWACTIVITIES_API SPTR( ::fwActivities::IValidator ) New( const ::fwActivities::validator::registry::KeyType &
+                                                         classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) validator = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) validator = std::make_shared< CLASSNAME >( Key() );
     return validator;
 }
 
@@ -55,4 +53,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWACTIVITIES_VALIDATOR_FACTORY_NEW_HPP__ */
 
-
