@@ -1,20 +1,20 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <fwData/Vector.hpp>
-
 #include "fwActivities/IBuilder.hpp"
 
+#include <fwData/Vector.hpp>
 
 namespace fwActivities
 {
 
 //------------------------------------------------------------------------------
 
-::fwData::Vector::sptr IBuilder::getType( ::fwData::Vector::sptr currentSelection, std::string type ) const
+::fwData::Vector::sptr IBuilder::getType( const ::fwData::Vector::csptr& currentSelection,
+                                          const std::string& type ) const
 {
     SLM_ASSERT("currentSelection not instanced", currentSelection);
 
@@ -33,4 +33,3 @@ namespace fwActivities
 //------------------------------------------------------------------------------
 
 } // namespace fwActivities
-
