@@ -1,14 +1,15 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <fwData/Vector.hpp>
-#include <fwData/Composite.hpp>
+#include "fwActivities/builder/ActivitySeriesInitData.hpp"
 
 #include "fwActivities/builder/registry/macros.hpp"
-#include "fwActivities/builder/ActivitySeriesInitData.hpp"
+
+#include <fwData/Composite.hpp>
+#include <fwData/Vector.hpp>
 
 namespace fwActivities
 {
@@ -20,8 +21,8 @@ fwActivitiesBuilderRegisterMacro(
 
 //-----------------------------------------------------------------------------
 
-ActivitySeriesInitData::ActivitySeriesInitData(::fwActivities::IBuilder::Key key)
-    : fwActivities::builder::ActivitySeries(key)
+ActivitySeriesInitData::ActivitySeriesInitData(::fwActivities::IBuilder::Key key) :
+    fwActivities::builder::ActivitySeries(key)
 {
 }
 
@@ -35,7 +36,7 @@ ActivitySeriesInitData::~ActivitySeriesInitData()
 
 ::fwMedData::ActivitySeries::sptr ActivitySeriesInitData::buildData(
     const ::fwActivities::registry::ActivityInfo& activityInfo,
-    ::fwData::Vector::sptr currentSelection ) const
+    const ::fwData::Vector::csptr& currentSelection ) const
 {
     ::fwMedData::ActivitySeries::sptr actSeries = this->ActivitySeries::buildData(activityInfo, currentSelection);
     ::fwData::Composite::sptr data              = actSeries->getData();
@@ -58,4 +59,3 @@ ActivitySeriesInitData::~ActivitySeriesInitData()
 
 } // namespace builder
 } // namespace fwActivities
-
