@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,6 +7,12 @@
 #ifndef __FWACTIVITIES_UT_BUILDER_ACTIVITYSERIESBUILDERTEST_HPP__
 #define __FWACTIVITIES_UT_BUILDER_ACTIVITYSERIESBUILDERTEST_HPP__
 
+#include <fwActivities/registry/Activities.hpp>
+
+#include <fwCore/macros.hpp>
+
+#include <fwRuntime/Bundle.hpp>
+
 #include <cppunit/extensions/HelperMacros.h>
 
 namespace fwActivities
@@ -17,11 +23,11 @@ namespace ut
 
 class ActivitySeriesBuilderTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ActivitySeriesBuilderTest );
+CPPUNIT_TEST_SUITE( ActivitySeriesBuilderTest );
 
-    CPPUNIT_TEST(builDataTest);
+CPPUNIT_TEST(builDataTest);
 
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
