@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,27 +7,25 @@
 #ifndef __FWACTIVITIES_UT_REGISTRY_ACTIVITYREGISTRYTEST_HPP__
 #define __FWACTIVITIES_UT_REGISTRY_ACTIVITYREGISTRYTEST_HPP__
 
+#include <fwCore/macros.hpp>
+
 #include <cppunit/extensions/HelperMacros.h>
 
-
-namespace fwRuntime
-{
-struct Bundle;
-}
-
 namespace fwActivities
 {
 
 namespace ut
 {
 
+struct ActivityRegistryTestPimpl;
+
 class ActivityRegistryTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ActivityRegistryTest );
+CPPUNIT_TEST_SUITE( ActivityRegistryTest );
 
-    CPPUNIT_TEST(registryTest);
+CPPUNIT_TEST(registryTest);
 
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -38,8 +36,7 @@ public:
 
 protected:
 
-    SPTR( fwRuntime::Bundle ) m_bundle;
-    SPTR( fwActivities::registry::Activities ) m_activities;
+    SPTR( ActivityRegistryTestPimpl ) m_pimpl;
 };
 
 } //namespace ut
