@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,14 +7,11 @@
 #ifndef __FWATOMCONVERSION_MAPPER_FACTORY_NEW_HPP__
 #define __FWATOMCONVERSION_MAPPER_FACTORY_NEW_HPP__
 
-#include <string>
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwAtomConversion/config.hpp"
 #include "fwAtomConversion/mapper/registry/detail.hpp"
 
+#include <string>
+
 namespace fwAtomConversion
 {
 namespace mapper
@@ -28,12 +25,11 @@ namespace factory
 template<class CLASSNAME > SPTR( CLASSNAME ) New();
 
 FWATOMCONVERSION_API SPTR(::fwAtomConversion::mapper::Base) New(
-        const ::fwAtomConversion::mapper::registry::KeyType & classname );
-
+    const ::fwAtomConversion::mapper::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME ) New()
 {
-    SPTR(CLASSNAME) obj = ::boost::make_shared< CLASSNAME >();
+    SPTR(CLASSNAME) obj = std::make_shared< CLASSNAME >();
     return obj;
 }
 
@@ -43,4 +39,3 @@ template<class CLASSNAME > SPTR( CLASSNAME ) New()
 
 #endif /* __FWATOMCONVERSION_MAPPER_FACTORY_NEW_HPP__ */
 
-
