@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWATOMS_EXCEPTION_HPP_
-#define _FWATOMS_EXCEPTION_HPP_
+#ifndef __FWATOMS_EXCEPTION_HPP__
+#define __FWATOMS_EXCEPTION_HPP__
 
 #include <exception>
 #include <string>
@@ -27,17 +27,17 @@ struct FWATOMS_CLASS_API Exception : public ::fwCore::Exception
      *
      * @param[in]   message a string containing the failure message
      */
-    FWATOMS_API Exception(const std::string &message) throw();
+    FWATOMS_API Exception(const std::string &message) noexcept;
 
     /**
      * @brief   Destructor : do nothing.
      */
-    FWATOMS_API ~Exception() throw();
+    FWATOMS_API ~Exception() noexcept;
 
 
 };
 
 } // namespace fwAtoms
 
-#endif // _FWATOMS_EXCEPTION_HPP_
+#endif // __FWATOMS_EXCEPTION_HPP__
 
