@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,11 @@
 #ifndef __FWATOMS_FACTORY_NEW_HPP__
 #define __FWATOMS_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwAtoms/config.hpp"
 #include "fwAtoms/registry/detail.hpp"
 
+#include <string>
+
 namespace fwAtoms
 {
 
@@ -24,7 +20,6 @@ class Base;
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -33,18 +28,19 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwAtoms::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwAtoms::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
-
 FWATOMS_API SPTR( ::fwAtoms::Base ) New( const ::fwAtoms::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) obj = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) obj = std::make_shared< CLASSNAME >( Key() );
     return obj;
 }
 
@@ -54,4 +50,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWATOMS_FACTORY_NEW_HPP__ */
 
-
