@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -9,13 +9,15 @@
 namespace fwAtoms
 {
 
-Exception::Exception(const std::string &message) throw()
-: ::fwCore::Exception(message)
-{}
+Exception::Exception(const std::string &message) noexcept
+    : ::fwCore::Exception(message)
+{
+}
 
 
-Exception::~Exception() throw()
-{}
+Exception::~Exception() noexcept
+{
+}
 
 
 
