@@ -1,13 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/foreach.hpp>
-
-#include "fwAtoms/registry/macros.hpp"
 #include "fwAtoms/Map.hpp"
+#include "fwAtoms/registry/macros.hpp"
 
 fwAtomsRegisterMacro( ::fwAtoms::Map );
 
@@ -19,7 +17,7 @@ namespace fwAtoms
 Base::sptr Map::clone() const
 {
     Map::sptr cloneMap = Map::New();
-    BOOST_FOREACH(const ValueType &elem, m_value)
+    for(const ValueType &elem :  m_value)
     {
         cloneMap->m_value.insert( ValueType(elem.first, elem.second->clone() ) );
     }
