@@ -1,14 +1,15 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/foreach.hpp>
-#include <limits>
+#include "StringTest.hpp"
 
 #include <fwAtoms/String.hpp>
-#include "StringTest.hpp"
+
+#include <limits>
+
 
 
 CPPUNIT_TEST_SUITE_REGISTRATION( ::fwAtoms::ut::StringTest );
@@ -36,7 +37,7 @@ void StringTest::conversion()
     const std::string VALUES[] = {"", "azerty"};
     fwAtoms::String::sptr metaString;
 
-    BOOST_FOREACH ( std::string str, VALUES )
+    for ( std::string str: VALUES )
     {
         metaString = ::fwAtoms::String::New(str);
 
