@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,10 @@
 #ifndef __FWATOMSFILTER_FACTORY_NEW_HPP__
 #define __FWATOMSFILTER_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwAtomsFilter/config.hpp"
 #include "fwAtomsFilter/registry/detail.hpp"
 
+#include <string>
 
 namespace fwAtomsFilter
 {
@@ -25,7 +20,6 @@ class IFilter;
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -34,20 +28,20 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwAtomsFilter::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwAtomsFilter::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
-
 FWATOMSFILTER_API SPTR(::fwAtomsFilter::IFilter) New(
-        const ::fwAtomsFilter::registry::KeyType & classname );
-
+    const ::fwAtomsFilter::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) obj = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) obj = std::make_shared< CLASSNAME >( Key() );
 
     return obj;
 }
