@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWATOMSFILTER_FACTORY_NAMESPACE_HPP__
-#define __FWATOMSFILTER_FACTORY_NAMESPACE_HPP__
+#ifndef __FWATOMSFILTER_NAMESPACE_HPP__
+#define __FWATOMSFILTER_NAMESPACE_HPP__
 
 /**
  * @brief Proposes an API to filter atoms.
@@ -32,5 +32,5 @@ namespace registry
 
 } // namespace fwAtomsFilter
 
-#endif /* __FWATOMSFILTER_FACTORY_NAMESPACE_HPP__ */
+#endif /* __FWATOMSFILTER_NAMESPACE_HPP__ */
 
