@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -18,11 +18,13 @@ namespace exceptions
 /**
  * @brief Exception defining a wrong extension in a filename.
  */
-class BadExtension: public fwAtomsPatch::exceptions::Base
+class BadExtension : public fwAtomsPatch::exceptions::Base
 {
 public:
     BadExtension(const std::string& message);
-    virtual ~BadExtension() throw(){};
+    virtual ~BadExtension() noexcept
+    {
+    }
 };
 
 } // namespace exceptions
