@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -19,11 +19,13 @@ namespace exceptions
 /**
  * @brief Base class of fwAtomsPatch exceptions
  */
-class Base: public fwCore::Exception
+class Base : public fwCore::Exception
 {
 public:
     Base(const std::string& message);
-    virtual ~Base() throw () {};
+    virtual ~Base() noexcept
+    {
+    }
 };
 
 
