@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWATOMSPATCH_REGISTRY_DETAIL_HPP__
-#define __FWATOMSPATCH_REGISTRY_DETAIL_HPP__
+#ifndef __FWATOMSPATCH_PATCHER_REGISTRY_DETAIL_HPP__
+#define __FWATOMSPATCH_PATCHER_REGISTRY_DETAIL_HPP__
 
 #include <string>
 
@@ -27,7 +27,7 @@ namespace registry
 
 typedef std::string KeyType;
 
-typedef ::fwCore::util::FactoryRegistry< SPTR(::fwAtomsPatch::patcher::IPatcher) () , KeyType > Type;
+typedef ::fwCore::util::FactoryRegistry< SPTR(::fwAtomsPatch::patcher::IPatcher) (), KeyType > Type;
 
 FWATOMSPATCH_API SPTR(Type) get();
 
@@ -37,6 +37,6 @@ FWATOMSPATCH_API SPTR(Type) get();
 
 } // namespace fwAtomsPatch
 
-#endif /* __FWATOMSPATCHE_REGISTRY_DETAIL_HPP__ */
+#endif /* __FWATOMSPATCH_PATCHER_REGISTRY_DETAIL_HPP__ */
 
 
