@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWATOMSPATCH_REGISTRY_MACRO_HPP__
-#define __FWATOMSPATCH_REGISTRY_MACRO_HPP__
+#ifndef __FWATOMSPATCH_PATCHER_REGISTRY_MACROS_HPP__
+#define __FWATOMSPATCH_PATCHER_REGISTRY_MACROS_HPP__
 
 #include <boost/preprocessor/cat.hpp>
 
@@ -23,7 +23,7 @@ namespace registry
 
 #define patcherRegisterMacro( classname, objectKey )                                  \
     static ::fwAtomsPatch::patcher::IPatcher::Registrar< classname >                  \
-    BOOST_PP_CAT(s__factory__record__object__, __LINE__) ( objectKey ) ;
+    BOOST_PP_CAT(s__factory__record__object__, __LINE__) ( objectKey );
 
 } // namespace registry
 
@@ -31,4 +31,4 @@ namespace registry
 
 } // namespace fwAtomsPatch
 
-#endif /*__FWATOMSPATCH_REGISTRY_MACRO_HPP__*/
+#endif /*__FWATOMSPATCH_PATCHER_REGISTRY_MACROS_HPP__*/
