@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -13,7 +13,9 @@ namespace conditions
 {
 
 Abstract::Abstract(::fwAtoms::Base::sptr defaultValue)
-    : m_defaultValue(defaultValue){}
+    : m_defaultValue(defaultValue)
+{
+}
 
 // ----------------------------------------------------------------------------
 
