@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWCAMP_CAMP_TYPE_HPP__
-#define __FWCAMP_CAMP_TYPE_HPP__
+#ifndef __FWCAMP_CAMP_CUSTOMTYPE_HPP__
+#define __FWCAMP_CAMP_CUSTOMTYPE_HPP__
 
 namespace camp
 {
@@ -18,4 +18,4 @@ enum CustomType
 
 } //camp
 
-#endif /* __FWCAMP_CAMP_TYPE_HPP__ */
+#endif /* __FWCAMP_CAMP_CUSTOMTYPE_HPP__ */
