@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWCOM_HASIGNALS_HPP__
-#define __FWCOM_HASIGNALS_HPP__
+#ifndef __FWCOM_HASSIGNALS_HPP__
+#define __FWCOM_HASSIGNALS_HPP__
 
 #include "fwCom/config.hpp"
 #include "fwCom/Signals.hpp"
@@ -16,18 +16,22 @@ namespace fwCom
 struct SignalBase;
 
 /**
- * @class   HasSignals
  * @brief   This class proposes a mapping between a SignalKeyType and a SignalBase.
- * @date   2012.
  */
 class HasSignals
 {
 
 public:
 
-    typedef ::boost::shared_ptr< HasSignals > sptr;
+    typedef std::shared_ptr< HasSignals > sptr;
+    typedef std::shared_ptr< const HasSignals > csptr;
 
-    HasSignals(){}
+    HasSignals()
+    {
+    }
+    virtual ~HasSignals()
+    {
+    }
 
     SPTR( SignalBase ) signal( const Signals::SignalKeyType & key ) const
     {
@@ -37,17 +41,24 @@ public:
     template< typename SignalType >
     SPTR( SignalType ) signal( const Signals::SignalKeyType & key ) const
     {
-        SPTR( SignalType ) Signal = ::boost::dynamic_pointer_cast< SignalType >( this->signal(key) );
+        SPTR( SignalType ) Signal = std::dynamic_pointer_cast< SignalType >( this->signal(key) );
         return Signal;
     }
 
+    template<typename SignalType>
+    SPTR( SignalType ) newSignal(const Signals::SignalKeyType & key)
+    {
+        SPTR( SignalType ) sig = std::make_shared< SignalType > ();
+        m_signals(key, sig);
+        return sig;
+    }
 
 protected:
 
     /// Copy constructor forbidden
     HasSignals( const HasSignals& );
 
-    /// Copy operator forbiden
+    /// Copy operator forbidden
     HasSignals& operator=( const HasSignals& );
 
     Signals m_signals;
@@ -55,4 +66,4 @@ protected:
 
 } // namespace fwCom
 
-#endif // __FWCOM_HASIGNALS_HPP__
+#endif // __FWCOM_HASSIGNALS_HPP__
