@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -12,10 +12,7 @@
 namespace fwCom
 {
 
-#ifdef COM_LOG
-size_t SignalBase::s_idCount = 0;
-::fwCore::mt::Mutex SignalBase::s_mutexCounter;
-#endif
+
 
 } // namespace fwCom
 
