@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -13,14 +13,9 @@
 namespace fwCom
 {
 
-#ifdef COM_LOG
-size_t SlotBase::s_idCount = 0;
-::fwCore::mt::Mutex SlotBase::s_mutexCounter;
-#endif
-
 void SlotBase::run() const
 {
-    typedef SlotRun< void() > SlotFuncType;
+    typedef SlotRun< void () > SlotFuncType;
     const SlotFuncType *fun = dynamic_cast< const SlotFuncType* >(this);
     if(fun)
     {
@@ -33,9 +28,11 @@ void SlotBase::run() const
     }
 }
 
+//-----------------------------------------------------------------------------
+
 SlotBase::VoidSharedFutureType SlotBase::asyncRun() const
 {
-    typedef SlotRun< void() > SlotFuncType;
+    typedef SlotRun< void () > SlotFuncType;
     const SlotFuncType *fun = dynamic_cast< const SlotFuncType* >(this);
     if(fun)
     {
