@@ -1,29 +1,23 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <string>
+#include "SignalTest.hpp"
 
-#include <boost/thread.hpp>
-#include <boost/date_time/posix_time/posix_time.hpp>
-#include <boost/chrono/duration.hpp>
-
-
-#include "fwCom/exception/BadSlot.hpp"
 #include "fwCom/exception/AlreadyConnected.hpp"
-
+#include "fwCom/exception/BadSlot.hpp"
 #include <fwCom/Signal.hpp>
 #include <fwCom/Signal.hxx>
-
 #include <fwCom/Slot.hpp>
 #include <fwCom/Slot.hxx>
 
 #include <fwThread/Worker.hpp>
 
-#include "SignalTest.hpp"
+#include <boost/date_time/posix_time/posix_time.hpp>
 
+#include <string>
 
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION( ::fwCom::ut::SignalTest );
@@ -33,11 +27,15 @@ namespace fwCom
 namespace ut
 {
 
+//------------------------------------------------------------------------------
+
 void SignalTest::setUp()
 {
     // Set up context before running a test.
 
 }
+//------------------------------------------------------------------------------
+
 void SignalTest::tearDown()
 {
     // Clean up after the test run.
@@ -48,25 +46,25 @@ void SignalTest::tearDown()
 void SignalTest::buildTest ()
 {
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
         CPPUNIT_ASSERT( sig );
     }
 
     {
-        typedef void Signature(int);
+        typedef void Signature (int);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
         CPPUNIT_ASSERT( sig );
     }
 
     {
-        typedef void Signature(char, float);
+        typedef void Signature (char, float);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
         CPPUNIT_ASSERT( sig );
     }
 
     {
-        typedef void Signature(short, double, std::string);
+        typedef void Signature (short, double, std::string);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
         CPPUNIT_ASSERT( sig );
     }
@@ -82,23 +80,43 @@ struct SignalTestClass
         m_method1(false),
         m_method2(false),
         m_method3(false)
-    {}
+    {
+    }
 
-    void method0(){ m_method0 = true; }
+    //------------------------------------------------------------------------------
 
-    void method00(){ m_method00 = true; }
+    void method0()
+    {
+        m_method0 = true;
+    }
 
-    float method1(float f){
+    //------------------------------------------------------------------------------
+
+    void method00()
+    {
+        m_method00 = true;
+    }
+
+    //------------------------------------------------------------------------------
+
+    float method1(float f)
+    {
         m_method1 = true;
         return 2*f;
     }
 
-    float method2(float f, int i){
+    //------------------------------------------------------------------------------
+
+    float method2(float f, int i)
+    {
         m_method2 = true;
         return 2*f;
     }
 
-    float method3(float f, double d, std::string s){
+    //------------------------------------------------------------------------------
+
+    float method3(float f, double d, std::string s)
+    {
         m_method3 = true;
         return 2*f;
     }
@@ -129,7 +147,7 @@ void SignalTest::connectTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot0);
@@ -140,7 +158,7 @@ void SignalTest::connectTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float);
+        typedef void Signature (float);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot1);
@@ -151,7 +169,7 @@ void SignalTest::connectTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, int);
+        typedef void Signature (float, int);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot2);
@@ -162,7 +180,7 @@ void SignalTest::connectTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, double, std::string);
+        typedef void Signature (float, double, std::string);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot3);
@@ -174,7 +192,7 @@ void SignalTest::connectTest()
 
     // Disconnect
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot0);
@@ -186,7 +204,7 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         sig->connect(slot0);
@@ -202,7 +220,7 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         connection = sig->connect(slot0);
@@ -214,13 +232,13 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         ::fwCom::Slot< void() >::sptr slot
             = ::fwCom::newSlot(&SignalTestClass::method0, &testObject);
 
-        connection = sig->connect(slot0);
+        connection                      = sig->connect(slot0);
         ::fwCom::Connection connection2 = sig->connect(slot);
 
         CPPUNIT_ASSERT(!connection.expired());
@@ -233,7 +251,7 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature(std::string);
+        typedef void Signature (std::string);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         CPPUNIT_ASSERT_THROW( sig->connect(slot1), fwCom::exception::BadSlot);
@@ -242,10 +260,9 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature(std::string);
+        typedef void Signature (std::string);
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
-
         CPPUNIT_ASSERT_THROW( sig->disconnect(slot1), fwCom::exception::BadSlot);
         CPPUNIT_ASSERT_THROW( sig->disconnect(slot2), fwCom::exception::BadSlot);
         CPPUNIT_ASSERT_THROW( sig->disconnect(slot3), fwCom::exception::BadSlot);
@@ -261,7 +278,7 @@ void SignalTest::connectTest()
     }
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
 
         sig->connect(slot0);
@@ -270,7 +287,6 @@ void SignalTest::connectTest()
         CPPUNIT_ASSERT_EQUAL((size_t)1, sig->getNumberOfConnections());
     }
 
-
 }
 
 //-----------------------------------------------------------------------------
@@ -280,7 +296,7 @@ void SignalTest::emitTest()
     ::fwCom::Connection connection;
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         SignalTestClass testObject;
 
         ::fwCom::Slot< Signature >::sptr slot
@@ -299,7 +315,7 @@ void SignalTest::emitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float);
+        typedef void Signature (float);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float) >::sptr slot
@@ -319,7 +335,7 @@ void SignalTest::emitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, int);
+        typedef void Signature (float, int);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float, int) >::sptr slot
@@ -339,7 +355,7 @@ void SignalTest::emitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, double, std::string);
+        typedef void Signature (float, double, std::string);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float, double, std::string) >::sptr slot
@@ -363,7 +379,7 @@ void SignalTest::emitTest()
 
 void SignalTest::autoSlotDisconnectTest()
 {
-    typedef void Signature(float);
+    typedef void Signature (float);
     SignalTestClass testObject;
 
     ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
@@ -405,7 +421,7 @@ void SignalTest::autoSlotDisconnectTest()
 
 void SignalTest::argumentLossTest()
 {
-    typedef void Signature(float, double, std::string);
+    typedef void Signature (float, double, std::string);
     SignalTestClass testObject;
 
     ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
@@ -436,13 +452,11 @@ void SignalTest::argumentLossTest()
     CPPUNIT_ASSERT_EQUAL((size_t)0, sig->getNumberOfConnections());
 }
 
-
-
 //-----------------------------------------------------------------------------
 
 void SignalTest::asyncArgumentLossTest()
 {
-    typedef void Signature(float, double, std::string);
+    typedef void Signature (float, double, std::string);
     SignalTestClass testObject;
 
     ::fwCom::Signal< Signature >::sptr sig = ::fwCom::Signal< Signature >::New();
@@ -470,13 +484,12 @@ void SignalTest::asyncArgumentLossTest()
 
     sig->asyncEmit(21.0f, 42.0, "asyncEmit");
 
-    ::boost::this_thread::sleep_for( ::boost::chrono::milliseconds(100));
+    std::this_thread::sleep_for( std::chrono::milliseconds(100));
 
     CPPUNIT_ASSERT(testObject.m_method0);
     CPPUNIT_ASSERT(testObject.m_method1);
     CPPUNIT_ASSERT(testObject.m_method3);
 
-
     sig->disconnectAll();
     CPPUNIT_ASSERT_EQUAL((size_t)0, sig->getNumberOfConnections());
 }
@@ -485,7 +498,7 @@ void SignalTest::asyncArgumentLossTest()
 
 void SignalTest::blockTest()
 {
-    typedef void Signature(float, double, std::string);
+    typedef void Signature (float, double, std::string);
     SignalTestClass testObject;
 
     ::fwCom::Connection connection;
@@ -520,7 +533,6 @@ void SignalTest::blockTest()
         sig->emit(21.0f, 42.0, "emit");
     }
 
-
     CPPUNIT_ASSERT(testObject.m_method0);
     CPPUNIT_ASSERT(!testObject.m_method1);
     CPPUNIT_ASSERT(testObject.m_method3);
@@ -535,7 +547,6 @@ void SignalTest::blockTest()
     CPPUNIT_ASSERT(testObject.m_method1);
     CPPUNIT_ASSERT(testObject.m_method3);
 
-
     testObject.m_method0 = false;
     testObject.m_method1 = false;
     testObject.m_method3 = false;
@@ -546,12 +557,10 @@ void SignalTest::blockTest()
         sig->emit(21.0f, 42.0, "emit");
     }
 
-
     CPPUNIT_ASSERT(testObject.m_method0);
     CPPUNIT_ASSERT(testObject.m_method1);
     CPPUNIT_ASSERT(testObject.m_method3);
 
-
 }
 
 //-----------------------------------------------------------------------------
@@ -562,7 +571,7 @@ void SignalTest::asyncEmitTest()
     ::fwThread::Worker::sptr worker = ::fwThread::Worker::New();
 
     {
-        typedef void Signature();
+        typedef void Signature ();
         SignalTestClass testObject;
 
         ::fwCom::Slot< Signature >::sptr slot
@@ -576,7 +585,7 @@ void SignalTest::asyncEmitTest()
 
         CPPUNIT_ASSERT_EQUAL((size_t)1, sig->getNumberOfConnections());
         sig->asyncEmit();
-        ::boost::this_thread::sleep_for( ::boost::chrono::seconds(1));
+        std::this_thread::sleep_for( std::chrono::seconds(1));
 
         CPPUNIT_ASSERT(testObject.m_method0);
     }
@@ -584,7 +593,7 @@ void SignalTest::asyncEmitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float);
+        typedef void Signature (float);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float) >::sptr slot
@@ -599,7 +608,7 @@ void SignalTest::asyncEmitTest()
         CPPUNIT_ASSERT_EQUAL((size_t)1, sig->getNumberOfConnections());
 
         sig->asyncEmit(21.0f);
-        ::boost::this_thread::sleep_for( ::boost::chrono::seconds(1));
+        std::this_thread::sleep_for( std::chrono::seconds(1));
 
         CPPUNIT_ASSERT(testObject.m_method1);
     }
@@ -607,7 +616,7 @@ void SignalTest::asyncEmitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, int);
+        typedef void Signature (float, int);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float, int) >::sptr slot
@@ -622,7 +631,7 @@ void SignalTest::asyncEmitTest()
         CPPUNIT_ASSERT_EQUAL((size_t)1, sig->getNumberOfConnections());
 
         sig->asyncEmit(21.0f, 42);
-        ::boost::this_thread::sleep_for( ::boost::chrono::seconds(1));
+        std::this_thread::sleep_for( std::chrono::seconds(1));
 
         CPPUNIT_ASSERT(testObject.m_method2);
     }
@@ -630,7 +639,7 @@ void SignalTest::asyncEmitTest()
     CPPUNIT_ASSERT(connection.expired());
 
     {
-        typedef void Signature(float, double, std::string);
+        typedef void Signature (float, double, std::string);
         SignalTestClass testObject;
 
         ::fwCom::Slot< float(float, double, std::string) >::sptr slot
@@ -645,7 +654,7 @@ void SignalTest::asyncEmitTest()
         CPPUNIT_ASSERT_EQUAL((size_t)1, sig->getNumberOfConnections());
 
         sig->asyncEmit(21.0f, 42.0, "emit");
-        ::boost::this_thread::sleep_for( ::boost::chrono::seconds(1));
+        std::this_thread::sleep_for( std::chrono::seconds(1));
 
         CPPUNIT_ASSERT(testObject.m_method3);
     }
