@@ -1,12 +1,12 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
 
-#ifndef _FWCORE_EXCEPTION_HPP_
-#define _FWCORE_EXCEPTION_HPP_
+#ifndef __FWCORE_EXCEPTION_HPP__
+#define __FWCORE_EXCEPTION_HPP__
 
 
 #include <stdexcept>
@@ -30,4 +30,4 @@ public:
 
 } //namespace fwCore
 
-#endif //_FWCORE_EXCEPTION_FWEXCEPTION_HPP_
+#endif //__FWCORE_EXCEPTION_HPP__
