@@ -1,21 +1,19 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-/** 
- * @file fwCore/base.hpp
+/**
  * @brief This file includes the minimal tools to work with FW4SPL.
- *
- * 
  */
-//#ifndef __FWCORE_BASE_HPP
-//#define __FWCORE_BASE_HPP
+
+#ifndef __FWCORE_BASE_HPP__
+#define __FWCORE_BASE_HPP__
 
 #include <fwCore/BaseObject.hpp>
+#include <fwCore/exceptionmacros.hpp>
 #include <fwCore/macros.hpp>
 #include <fwCore/spyLog.hpp>
-#include <fwCore/exceptionmacros.hpp>
 
-//#endif //__FWCORE_BASE_HPP
+#endif //__FWCORE_BASE_HPP__
