@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWCORE_UT_FATORYREGISTRYTEST_HPP__
-#define __FWCORE_UT_FATORYREGISTRYTEST_HPP__
+#ifndef __FWCORE_UT_FACTORYREGISTRYTEST_HPP__
+#define __FWCORE_UT_FACTORYREGISTRYTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,12 +16,12 @@ namespace ut
 
 class FactoryRegistryTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( FactoryRegistryTest );
-    CPPUNIT_TEST( pointerTest );
-    CPPUNIT_TEST( valueTest );
-    CPPUNIT_TEST( argTest );
-    CPPUNIT_TEST( threadSafetyTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( FactoryRegistryTest );
+CPPUNIT_TEST( pointerTest );
+CPPUNIT_TEST( valueTest );
+CPPUNIT_TEST( argTest );
+CPPUNIT_TEST( threadSafetyTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -37,4 +37,4 @@ public:
 
 } //namespace ut
 } //namespace fwCore
-#endif //__FWCORE_UT_FATORYREGISTRYTEST_HPP__
+#endif //__FWCORE_UT_FACTORYREGISTRYTEST_HPP__
