@@ -1,57 +1,53 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATA_BOOLEAN_HPP_
-#define _FWDATA_BOOLEAN_HPP_
+#ifndef __FWDATA_BOOLEAN_HPP__
+#define __FWDATA_BOOLEAN_HPP__
 
-#include "fwData/GenericField.hpp"
 #include "fwData/config.hpp"
-#include "fwData/Object.hpp"
 #include "fwData/factory/new.hpp"
+#include "fwData/GenericField.hpp"
+#include "fwData/Object.hpp"
 
 fwCampAutoDeclareDataMacro((fwData)(Boolean), FWDATA_API);
 namespace fwData
 {
 
 /**
- * @class   Boolean
- * @brief   This class contains a boolean value
+ * @brief This class contains a boolean value.
  *
  * Boolean object is essentially used as a field in other objects.
- *
- * 
- * @date    2007-2009.
  */
 class FWDATA_CLASS_API Boolean : public GenericField< bool >
 {
 public:
-    fwCoreClassDefinitionsWithFactoryMacro( (Boolean)(::fwData::Object),( ((const bool)(false)) ), GenericFieldFactory< Boolean >) ;
+    fwCoreClassDefinitionsWithFactoryMacro( (Boolean)(::fwData::Object), ( ((const bool)(false)) ),
+                                            GenericFieldFactory< Boolean >);
     fwCampMakeFriendDataMacro((fwData)(Boolean));
 
     /**
      * @brief Constructor
      * @param key Private construction key
      */
-    FWDATA_API Boolean( ::fwData::Object::Key key ) throw();
+    FWDATA_API Boolean( ::fwData::Object::Key key ) noexcept;
 
     /**
      * @brief Destructor.
      */
-    FWDATA_API virtual ~Boolean() throw();
+    FWDATA_API virtual ~Boolean() noexcept;
 
     /// Defines shallow copy
-    FWDATA_API void shallowCopy( const Object::csptr& _source );
+    FWDATA_API void shallowCopy( const Object::csptr& _source ) override;
 
     /// Defines deep copy
-    FWDATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType &cache);
-
-protected:
+    FWDATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
 
 };
 
 } // namespace fwData
 
-#endif // _FWDATA_BOOLEAN_HPP_
+#endif // __FWDATA_BOOLEAN_HPP__
+
