@@ -1,37 +1,36 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATA_OBJECTLOCK_HPP_
-#define _FWDATA_OBJECTLOCK_HPP_
+#ifndef __FWDATA_OBJECTLOCK_HPP__
+#define __FWDATA_OBJECTLOCK_HPP__
 
-#include <vector>
 
 #include "fwData/Image.hpp"
 #include "fwData/Array.hpp"
 #include "fwData/Mesh.hpp"
 #include "fwData/Reconstruction.hpp"
-
 #include "fwData/config.hpp"
 
+#include <vector>
+
 namespace fwData
 {
 
 
 /**
- * @class  ObjectLock
- * @brief  A simple helper to lock specific object, manages : Image, Mesh and Array.
- * 
- * @date   2007-2012.
+ * @brief A simple helper to lock specific object, manages : Image, Mesh and Array.
  */
 class FWDATA_CLASS_API ObjectLock
 {
 
-public :
+public:
 
-    ObjectLock(){}
+    ObjectLock()
+    {
+    }
 
     FWDATA_API ObjectLock( const ObjectLock & );
     FWDATA_API ObjectLock( ::fwData::Object::sptr obj );
@@ -39,7 +38,7 @@ public :
     FWDATA_API ~ObjectLock();
 
     FWDATA_API ObjectLock & operator=(const ObjectLock & );
-private :
+private:
 
 
     typedef std::vector< ::fwMemory::BufferObject::Lock > LocksType;
@@ -56,4 +55,4 @@ private :
 
 } // fwData
 
-#endif // _FWDATA_OBJECTLOCK_HPP_
+#endif // __FWDATA_OBJECTLOCK_HPP__
