@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,25 +7,21 @@
 #ifndef __FWDATA_STRUCTURETRAITSHELPER_HPP__
 #define __FWDATA_STRUCTURETRAITSHELPER_HPP__
 
-#include <boost/bimap/bimap.hpp>
-
-#include <fwData/StructureTraits.hpp>
-
 #include "fwData/config.hpp"
+#include "fwData/StructureTraits.hpp"
+
+#include <boost/bimap/bimap.hpp>
 
 namespace fwData
 {
-/**
- * @class   StructureTraitsHelper
- * @brief   This class defines some helper for the structure traits.
- * 
- * @date    2007-20011.
- */
 
+/**
+ * @brief This class defines some helper for the structure traits.
+ */
 class FWDATA_CLASS_API StructureTraitsHelper
 {
 
-public :
+public:
 
     typedef ::boost::bimaps::bimap< ::fwData::StructureTraits::StructureClass, std::string > ClassTranslatorType;
     /// Map to translate structure class (string vs enum)
