@@ -1,39 +1,35 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATA_MT_OBJECTREADLOCK_HPP_
-#define _FWDATA_MT_OBJECTREADLOCK_HPP_
-
-#include <fwCore/mt/types.hpp>
+#ifndef __FWDATA_MT_OBJECTREADLOCK_HPP__
+#define __FWDATA_MT_OBJECTREADLOCK_HPP__
 
 #include "fwData/Object.hpp"
-
 #include "fwData/config.hpp"
 
+#include <fwCore/mt/types.hpp>
+
 namespace fwData
 {
 namespace mt
 {
 
 /**
- * @class  ObjectReadLock
  * @brief  A helper to lock object on read mode.
- * 
- * @date   2012.
  */
 class FWDATA_CLASS_API ObjectReadLock
 {
 
-public :
+public:
 
     /**
      * @brief Constructor : owns an read lock on object mutex.
      * If adopt_lock==false : the mutex is not locked (call lock() to lock mutex)
      */
-    FWDATA_API ObjectReadLock( ::fwData::Object::sptr obj, bool lock=true );
+    FWDATA_API ObjectReadLock( ::fwData::Object::csptr obj, bool lock = true );
 
     /// Destructor. Does nothing
     FWDATA_API ~ObjectReadLock();
@@ -44,7 +40,7 @@ public :
     /// Releases lock on object mutex
     FWDATA_API void unlock();
 
-private :
+private:
 
     /// lock on object mutex
     ::fwCore::mt::ReadLock m_lock;
@@ -53,4 +49,4 @@ private :
 } // mt
 } // fwData
 
-#endif // _FWDATA_MT_OBJECTREADLOCK_HPP_
+#endif // __FWDATA_MT_OBJECTREADLOCK_HPP__
