@@ -1,39 +1,35 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATA_MT_OBJECTREADTOWRITELOCK_HPP_
-#define _FWDATA_MT_OBJECTREADTOWRITELOCK_HPP_
-
-#include <fwCore/mt/types.hpp>
+#ifndef __FWDATA_MT_OBJECTREADTOWRITELOCK_HPP__
+#define __FWDATA_MT_OBJECTREADTOWRITELOCK_HPP__
 
 #include "fwData/Object.hpp"
-
 #include "fwData/config.hpp"
 
+#include <fwCore/mt/types.hpp>
+
 namespace fwData
 {
 namespace mt
 {
 
 /**
- * @class  ObjectReadToWriteLock
  * @brief  A helper to lock object on upgradable mode.
- * 
- * @date   2012.
  */
 class FWDATA_CLASS_API ObjectReadToWriteLock
 {
 
-public :
+public:
 
     /**
      * @brief Constructor : owns an upgradable lock on object mutex.
      * If adopt_lock==false : the mutex is not locked (call lock() to lock mutex)
      */
-    FWDATA_API ObjectReadToWriteLock( ::fwData::Object::sptr obj, bool lock=true );
+    FWDATA_API ObjectReadToWriteLock( ::fwData::Object::sptr obj, bool lock = true );
 
     /// Destructor. Does nothing
     FWDATA_API ~ObjectReadToWriteLock();
@@ -50,7 +46,7 @@ public :
     /// Downgrade exclusive lock to upgradable lock
     FWDATA_API void downgrade();
 
-private :
+private:
 
     /// lock on object mutex
     ::fwCore::mt::ReadToWriteLock m_lock;
@@ -60,4 +56,4 @@ private :
 } // mt
 } // fwData
 
-#endif // _FWDATA_MT_OBJECTREADTOWRITELOCK_HPP_
+#endif // __FWDATA_MT_OBJECTREADTOWRITELOCK_HPP__
