@@ -1,13 +1,13 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/thread/locks.hpp>
-
 #include "fwData/mt/ObjectReadLock.hpp"
 
+#include <boost/thread/locks.hpp>
+
 namespace fwData
 {
 namespace mt
@@ -15,7 +15,7 @@ namespace mt
 
 //-----------------------------------------------------------------------------
 
-ObjectReadLock::ObjectReadLock(::fwData::Object::sptr obj, bool lock)
+ObjectReadLock::ObjectReadLock(::fwData::Object::csptr obj, bool lock)
 {
     if (lock)
     {
@@ -30,7 +30,8 @@ ObjectReadLock::ObjectReadLock(::fwData::Object::sptr obj, bool lock)
 //-----------------------------------------------------------------------------
 
 ObjectReadLock::~ObjectReadLock()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
