@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -16,10 +16,12 @@ namespace ut
 
 class MeshTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( MeshTest );
     CPPUNIT_TEST( allocation );
     CPPUNIT_TEST( insertion );
     CPPUNIT_TEST( colorsNormals );
+    CPPUNIT_TEST( texCoords );
     CPPUNIT_TEST( addingArray );
     CPPUNIT_TEST( copy );
     CPPUNIT_TEST_SUITE_END();
@@ -32,6 +34,7 @@ public:
     void allocation();
     void insertion();
     void colorsNormals();
+    void texCoords();
     void addingArray();
     void copy();
 };
