@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWDATA_UT_POINTLISTTEST_HPP__
-#define __FWDATA_UT_POINTLISTTEST_HPP__
+#pragma once
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -25,19 +24,23 @@ private:
     CPPUNIT_TEST( getterTest );
     CPPUNIT_TEST( setterTest );
     CPPUNIT_TEST( pushTest );
+    CPPUNIT_TEST( removeTest );
+    CPPUNIT_TEST( clearTest );
     CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
     void setUp();
     void tearDown();
+
     void copyTest();
     void getterTest();
     void setterTest();
     void pushTest();
+    void removeTest();
+    void clearTest();
 
 };
 
 } //namespace ut
 } //namespace fwData
-#endif //__FWDATA_UT_POINTLISTTEST_HPP__
