@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -16,14 +16,19 @@ namespace ut
 
 class ProcessObjectTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( ProcessObjectTest );
     CPPUNIT_TEST( constructeur );
     CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
-    void setUp(){};
-    void tearDown(){};
+    void setUp()
+    {
+    }
+    void tearDown()
+    {
+    }
 
     void constructeur();
 };
