@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWDATA_UT_TRANSFORMATION3DMATRIXTEST_HPP__
-#define __FWDATA_UT_TRANSFORMATION3DMATRIXTEST_HPP__
+#ifndef __FWDATA_UT_TRANSFORMATIONMATRIX3DTEST_HPP__
+#define __FWDATA_UT_TRANSFORMATIONMATRIX3DTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,9 +16,10 @@ namespace ut
 
 class TransformationMatrix3DTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( TransformationMatrix3DTest );
-    CPPUNIT_TEST( methode1 );
-    CPPUNIT_TEST( methode2 );
+    CPPUNIT_TEST( getterSetterByCoef );
+    CPPUNIT_TEST( getterSetterByArray );
     CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -26,10 +27,11 @@ public:
     void setUp();
     void tearDown();
 
-    void methode1();
-    void methode2();
+    void getterSetterByCoef();
+    void getterSetterByArray();
 };
 
 } //namespace ut
 } //namespace fwData
-#endif //__FWDATA_UT_TRANSFORMATION3DMATRIXTEST_HPP__
+
+#endif //__FWDATA_UT_TRANSFORMATIONMATRIX3DTEST_HPP__
