@@ -1,15 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/foreach.hpp>
-#include <limits>
+#include "IntegerTest.hpp"
 
 #include <fwData/Integer.hpp>
 
-#include "IntegerTest.hpp"
+#include <limits>
 
 
 // Registers the fixture into the 'registry'
@@ -32,21 +31,21 @@ void IntegerTest::tearDown()
 
 void IntegerTest::methode1()
 {
-    const int VALUES[]  = {
+    const int VALUES[] = {
         std::numeric_limits< int >::min(),
         -1654, 0, 123456,
         std::numeric_limits< int >::max()
     };
 
-    BOOST_FOREACH ( int VALUE, VALUES )
+    for ( int VALUE : VALUES )
     {
         ::fwData::Integer::sptr i0 = ::fwData::Integer::New();
-        i0->value() = VALUE;
+        i0->value()                = VALUE;
         ::fwData::Integer::sptr i1 = ::fwData::Integer::New( VALUE );
 
-        CPPUNIT_ASSERT_EQUAL( VALUE , i0->value() );
-        CPPUNIT_ASSERT_EQUAL( VALUE , i1->value() );
-        CPPUNIT_ASSERT_EQUAL( VALUE , ::fwData::Integer::New( VALUE )->value() );
+        CPPUNIT_ASSERT_EQUAL( VALUE, i0->value() );
+        CPPUNIT_ASSERT_EQUAL( VALUE, i1->value() );
+        CPPUNIT_ASSERT_EQUAL( VALUE, ::fwData::Integer::New( VALUE )->value() );
     }
 }
 
