@@ -1,19 +1,19 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef  __FWDATACAMP_VISITOR_RECURSIVELOCK_HPP__
-#define  __FWDATACAMP_VISITOR_RECURSIVELOCK_HPP__
+#pragma once
 
-#include <vector>
-
-#include <fwCore/mt/types.hpp>
+#include "fwDataCamp/config.hpp"
 
 #include <fwCamp/camp/ExtendedClassVisitor.hpp>
 
-#include "fwDataCamp/config.hpp"
+#include <fwCore/macros.hpp>
+#include <fwCore/mt/types.hpp>
+
+#include <vector>
 
 namespace fwData
 {
@@ -25,7 +25,6 @@ class ObjectReadLock;
 }
 }
 
-
 namespace fwDataCamp
 {
 
@@ -33,10 +32,7 @@ namespace visitor
 {
 
 /**
- * @class   RecursiveLock
  * @brief   This class is an helper to lock an object and all its children recursively.
- *
- * @date    2013.
  */
 class FWDATACAMP_CLASS_API RecursiveLock : public ::camp::ExtendedClassVisitor
 {
@@ -56,7 +52,7 @@ public:
      * @param object data object (containing child data objects) to lock recursively
      * @param locks container of previously acquired locks
      */
-    FWDATACAMP_API RecursiveLock( SPTR(::fwData::Object)object,
+    FWDATACAMP_API RecursiveLock( CSPTR(::fwData::Object)object,
                                   SPTR(LockVectType)locks = SPTR(LockVectType)(new LockVectType()));
 
     FWDATACAMP_API virtual ~RecursiveLock();
@@ -78,7 +74,7 @@ private:
     void lock();
 
     /// Object given in constructor which will introspected
-    SPTR(::fwData::Object) m_object;
+    CSPTR(::fwData::Object) m_object;
 
     /// Container of acquired locks.
     SPTR(LockVectType) m_locks;
@@ -86,12 +82,8 @@ private:
     /// Reflection in camp world of m_object
     ::camp::UserObject m_campObj;
 
-
 };
 
 } // namespace visitor
 
 } // namespace fwDataCamp
-
-#endif // __FWDATACAMP_VISITOR_RECURSIVELOCK_HPP__
-
