@@ -1,19 +1,12 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
 #include "fwDataCamp/autoload.hpp"
-#include "fwMedDataCamp/autoload.hpp"
-
 
 namespace fwDataCamp
 {
 runner runner::r;
 }
-
-namespace fwMedDataCamp
-{
-runner runner::r;
-}
