@@ -1,18 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <fwData/Object.hpp>
-
 #include <fwCamp/UserObject.hpp>
 
+#include <fwData/Object.hpp>
+
 fwCampImplementDataMacro((fwData)(Object))
 {
     builder
-        .property("fields", &::fwData::Object::m_fields)
-        .function("classname", (std::string (fwData::Object::*)() const) &::fwData::Object::className)
-        .function("is_a", (bool (fwData::Object::*)(const std::string &) const) &::fwData::Object::isA)
-        ;
+    .property("fields", &::fwData::Object::m_fields)
+    .function("classname", (const std::string& (fwData::Object::*)() const) &::fwData::Object::getClassname)
+    .function("is_a", (bool (fwData::Object::*)(const std::string&) const) &::fwData::Object::isA)
+    ;
 }
