@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -11,10 +11,10 @@
 fwCampImplementDataMacro((fwData)(ProcessObject))
 {
     builder
-        .tag("object_version", "1")
-        .tag("lib_name", "fwData")
-        .base< ::fwData::Object >()
-        .property("inputs", &fwData::ProcessObject::m_attrInputs)
-        .property("outputs", &fwData::ProcessObject::m_attrOutputs)
-        ;
+    .tag("object_version", "1")
+    .tag("lib_name", "fwData")
+    .base< ::fwData::Object >()
+    .property("inputs", &fwData::ProcessObject::m_inputs)
+    .property("outputs", &fwData::ProcessObject::m_outputs)
+    ;
 }
