@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -16,13 +16,13 @@
 namespace fwDataCamp
 {
 
-::fwData::Object::sptr getObject( ::fwData::Object::sptr object,
-                                     const std::string &path,
-                                     bool raiseException )
+::fwData::Object::sptr getObject( ::fwData::Object::csptr object,
+                                  const std::string& path,
+                                  bool raiseException )
 {
     SLM_FATAL_IF( "Path for desired object is empty.", path.empty() );
     SLM_FATAL_IF( "Path for desired object doesn't start with '@'.", path[0] != '@' );
-    const std::string objectPath =  path.substr( 1 );
+    const std::string objectPath = path.substr( 1 );
     ::fwDataCamp::visitor::GetObject visitor( object, objectPath );
     ::fwData::Object::sptr subObject;
     try
@@ -35,8 +35,8 @@ namespace fwDataCamp
     }
 
     FW_RAISE_EXCEPTION_IF(
-            ::fwDataCamp::exception::ObjectNotFound("Object '" + path + "' not found."),
-            !visitor.objectsFound() && raiseException);
+        ::fwDataCamp::exception::ObjectNotFound("Object '" + path + "' not found."),
+        !visitor.objectsFound() && raiseException);
 
     return subObject;
 }
