@@ -1,22 +1,20 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-
-#include <fwCore/mt/types.hpp>
-
-#include <fwMemory/BufferObject.hpp>
-
-#include <fwData/Object.hpp>
-#include <fwData/camp/mapper.hpp>
+#include "fwDataCamp/visitor/RecursiveLock.hpp"
 
 #include "fwDataCamp/exception/NullPointer.hpp"
 #include "fwDataCamp/exception/ObjectNotFound.hpp"
 
-#include "fwDataCamp/visitor/RecursiveLock.hpp"
+#include <fwCore/mt/types.hpp>
 
+#include <fwData/camp/mapper.hpp>
+#include <fwData/Object.hpp>
+
+#include <fwMemory/BufferObject.hpp>
 
 namespace fwDataCamp
 {
@@ -28,34 +26,49 @@ struct LockVisitor : public camp::ValueVisitor< void >
 {
     SPTR(RecursiveLock::LockVectType) m_locks;
 
-    LockVisitor(SPTR(RecursiveLock::LockVectType)locks) : m_locks(locks)
+    LockVisitor(SPTR(RecursiveLock::LockVectType)locks) :
+        m_locks(locks)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(camp::NoType value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(bool value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(long value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(double value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(const std::string& value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(const camp::EnumObject& value)
     {
     }
 
+    //------------------------------------------------------------------------------
+
     void operator()(const camp::UserObject& value)
     {
         const camp::Class& metaclass = value.getClass();
@@ -66,13 +79,13 @@ struct LockVisitor : public camp::ValueVisitor< void >
             {
                 if( value.call("is_a", ::camp::Args("::fwData::Object")).to<bool>() )
                 {
-                    ::fwData::Object * ptr     = value.get< ::fwData::Object * >();
+                    ::fwData::Object* ptr      = value.get< ::fwData::Object* >();
                     ::fwData::Object::sptr obj = ptr->getSptr();
                     ::fwDataCamp::visitor::RecursiveLock visitor( obj, m_locks );
                 }
                 else if( value.call("is_a", ::camp::Args("::fwMemory::BufferObject")).to<bool>() )
                 {
-                    ::fwMemory::BufferObject * ptr    = value.get< ::fwMemory::BufferObject * >();
+                    ::fwMemory::BufferObject* ptr     = value.get< ::fwMemory::BufferObject* >();
                     ::fwMemory::BufferObject::sptr bo = ptr->getSptr();
                     SPTR(::fwCore::mt::ReadLock) lock
                         = SPTR(::fwCore::mt::ReadLock)(new ::fwCore::mt::ReadLock(bo->getMutex()));
@@ -85,13 +98,14 @@ struct LockVisitor : public camp::ValueVisitor< void >
 
 //-----------------------------------------------------------------------------
 
-RecursiveLock::RecursiveLock( ::fwData::Object::sptr object, SPTR(LockVectType)locks ) :
-    m_object(object), m_locks(locks)
+RecursiveLock::RecursiveLock( ::fwData::Object::csptr object, SPTR(LockVectType)locks ) :
+    m_object(object),
+    m_locks(locks)
 {
     SPTR(::fwCore::mt::ReadLock) lock
         = SPTR(::fwCore::mt::ReadLock)(new ::fwCore::mt::ReadLock(m_object->getMutex()));
     m_locks->push_back(lock);
-    m_campObj = camp::UserObject( object.get() );
+    m_campObj = camp::UserObject( *object );
     this->lock();
 }
 
@@ -117,7 +131,7 @@ void RecursiveLock::visit(const camp::EnumProperty& property)
 
 void RecursiveLock::visit(const camp::MapProperty& property)
 {
-    const std::string name ( property.name() );
+    const std::string name( property.name() );
     const size_t size = property.getSize( m_campObj );
 
     std::pair< ::camp::Value, ::camp::Value > value;
@@ -148,7 +162,7 @@ void RecursiveLock::visit(const camp::MapProperty& property)
 
 void RecursiveLock::visit(const camp::ArrayProperty& property)
 {
-    const std::string name ( property.name() );
+    const std::string name( property.name() );
     const size_t size = property.size( m_campObj );
 
     ::camp::Value value;
@@ -170,7 +184,7 @@ void RecursiveLock::visit(const camp::ArrayProperty& property)
 void RecursiveLock::visit(const camp::UserProperty& property)
 {
     SLM_TRACE_FUNC();
-    const std::string name ( property.name() );
+    const std::string name( property.name() );
 
     ::camp::Value elemValue = property.get( m_campObj );
     LockVisitor visitor(m_locks);
@@ -196,4 +210,3 @@ void RecursiveLock::lock()
 } // visitor
 
 } // fwDataCamp
-
