@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2010.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,16 +7,11 @@
 #ifndef __FWDATAIO_WRITER_FACTORY_NEW_HPP__
 #define __FWDATAIO_WRITER_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-#include <fwTools/DynamicAttributes.hxx>
-
 #include "fwDataIO/config.hpp"
 #include "fwDataIO/writer/registry/detail.hpp"
 
+#include <string>
+
 namespace fwDataIO
 {
 namespace writer
@@ -27,7 +22,6 @@ class IObjectWriter;
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -36,19 +30,19 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwDataIO::writer::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwDataIO::writer::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
-
 FWDATAIO_API SPTR( ::fwDataIO::writer::IObjectWriter ) New( const ::fwDataIO::writer::registry::KeyType & classname );
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) obj = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) obj = std::make_shared< CLASSNAME >( Key() );
 
     return obj;
 }
@@ -61,4 +55,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWDATAIO_WRITER_FACTORY_NEW_HPP__ */
 
-
