@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -17,12 +17,14 @@ namespace reader
 //------------------------------------------------------------------------------
 
 IObjectReader::IObjectReader()
-{}
+{
+}
 
 //------------------------------------------------------------------------------
 
 IObjectReader::~IObjectReader()
-{}
+{
+}
 
 //------------------------------------------------------------------------------
 
@@ -35,8 +37,9 @@ void IObjectReader::setObject( ::fwTools::Object::sptr _pObject )
 
 ::fwTools::Object::sptr IObjectReader::getObject()
 {
-    assert( !m_object.expired() );
-    return m_object.lock();
+    auto object = m_object.lock();
+    SLM_ASSERT( "Object is null", object );
+    return object;
 }
 
 //------------------------------------------------------------------------------
@@ -53,6 +56,18 @@ void IObjectReader::setLocation( const ::fwData::location::ILocation::sptr _loca
     return m_location;
 }
 
+//------------------------------------------------------------------------------
+
+void IObjectReader::cancel()
+{
+    auto job = this->getJob();
+    if ( job )
+    {
+        job->cancel();
+    }
+}
+
+
 //------------------------------------------------------------------------------
 
 } // namespace reader
