@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATAIO_TEST_TU_DICTIONARYREADERTEST_HPP_
-#define _FWDATAIO_TEST_TU_DICTIONARYREADERTEST_HPP_
+#ifndef __FWDATAIO_UT_DICTIONARYREADERTEST_HPP__
+#define __FWDATAIO_UT_DICTIONARYREADERTEST_HPP__
 
 #include <boost/filesystem/operations.hpp>
 
@@ -21,13 +21,13 @@ namespace ut
  */
 class DictionaryReaderTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( DictionaryReaderTest );
-    CPPUNIT_TEST( test_1 );
-    CPPUNIT_TEST( test_2 );
-    CPPUNIT_TEST( test_3 );
-    CPPUNIT_TEST( test_4 );
-    CPPUNIT_TEST( test_5 );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( DictionaryReaderTest );
+CPPUNIT_TEST( test_1 );
+CPPUNIT_TEST( test_2 );
+CPPUNIT_TEST( test_3 );
+CPPUNIT_TEST( test_4 );
+CPPUNIT_TEST( test_5 );
+CPPUNIT_TEST_SUITE_END();
 
 
 public:
@@ -53,4 +53,4 @@ protected:
 } //namespace ut
 } //namespace fwDataIO
 
-#endif //_FWDATAIO_TEST_TU_DICTIONARYREADERTEST_HPP_
+#endif //__FWDATAIO_UT_DICTIONARYREADERTEST_HPP__
