@@ -1,17 +1,17 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATATOOLS_TRANSFERFUNCTION_HPP_
-#define _FWDATATOOLS_TRANSFERFUNCTION_HPP_
+#ifndef __FWDATATOOLS_TRANSFERFUNCTION_HPP__
+#define __FWDATATOOLS_TRANSFERFUNCTION_HPP__
 
 #include <fwCore/base.hpp>
 
 #include <fwData/TransferFunction.hpp>
 
-#include "fwDataTools/export.hpp"
+#include "fwDataTools/config.hpp"
 
 namespace fwDataTools
 {
@@ -24,7 +24,7 @@ namespace fwDataTools
 class TransferFunction
 {
 
-public :
+public:
 
     /**
      * @brief Generate a drawing tf with value between 0 and 255.
@@ -42,4 +42,4 @@ protected:
 
 } // namespace fwDataTools
 
-#endif // _FWDATATOOLS_TRANSFERFUNCTION_HPP_
+#endif // __FWDATATOOLS_TRANSFERFUNCTION_HPP__
