@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWDATATOOLS_TEST_TU_IMAGETEST_HPP_
-#define _FWDATATOOLS_TEST_TU_IMAGETEST_HPP_
+#ifndef __FWDATATOOLS_UT_IMAGETEST_HPP__
+#define __FWDATATOOLS_UT_IMAGETEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -22,9 +22,9 @@ namespace ut
  */
 class ImageTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ImageTest );
-    CPPUNIT_TEST( roiApplyTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( ImageTest );
+CPPUNIT_TEST( roiApplyTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -39,4 +39,4 @@ public:
 } //namespace ut
 } //namespace fwDataTools
 
-#endif //_FWDATATOOLS_TEST_TU_IMAGETEST_HPP_
+#endif //__FWDATATOOLS_UT_IMAGETEST_HPP__
