@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -41,22 +41,6 @@ void TransformationMatrix3DTest::tearDown()
 
 //------------------------------------------------------------------------------
 
-bool isIdentity(::fwData::TransformationMatrix3D::sptr tm)
-{
-    bool isIdentity = true;
-
-    for (size_t i = 0; i<4; ++i)
-    {
-        for (size_t j = 0; j<4; ++j)
-        {
-            isIdentity &= (i==j ? 1. : 0.) == tm->getCoefficient(i,j);
-        }
-    }
-    return isIdentity;
-}
-
-//------------------------------------------------------------------------------
-
 void TransformationMatrix3DTest::identityMatrixTest()
 {
     ::fwData::TransformationMatrix3D::sptr tm1 = ::fwData::TransformationMatrix3D::New();
@@ -67,12 +51,33 @@ void TransformationMatrix3DTest::identityMatrixTest()
     ::fwData::Point::sptr p1 = ::fwData::Point::New(1.0f, 2.3f, 5.1f);
     ::fwData::Point::sptr p2 = ::fwData::Point::New();
 
+    //test identity
+    bool shouldBeTrue = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should be identity", true, shouldBeTrue);
+    // dummy precision
+    shouldBeTrue = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1, 1);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should be identity", true, shouldBeTrue);
+    // high precision
+    shouldBeTrue = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1, 1e-17);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should be identity", true, shouldBeTrue);
+
     tm1->setCoefficient(0, 2, 3.4);
     tm1->setCoefficient(1, 3, 18);
+
+    bool shouldBeFalse = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should not be identity", false, shouldBeFalse);
+    //Test with dummy precision
+    shouldBeTrue = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1, 20);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should be identity with a precision of 20", true,
+                                 shouldBeTrue);
+    //Test with nice precision
+    shouldBeFalse = ::fwDataTools::TransformationMatrix3D::isIdentity(tm1, 1e-14);
+    CPPUNIT_ASSERT_EQUAL_MESSAGE("TransformationMatrix3D should not be identity", false, shouldBeFalse);
+
     ::fwDataTools::TransformationMatrix3D::identity(tm1);
     ::fwDataTools::TransformationMatrix3D::identity(tm2);
-    CPPUNIT_ASSERT(isIdentity(tm1));
-    CPPUNIT_ASSERT(isIdentity(tm2));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm1));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm2));
 
 #ifndef FW_PROFILING_DISABLED
     {
@@ -85,7 +90,7 @@ void TransformationMatrix3DTest::identityMatrixTest()
 #else
     ::fwDataTools::TransformationMatrix3D::multiply(tm1, tm2, tm3);
 #endif
-    CPPUNIT_ASSERT(isIdentity(tm3));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm3));
 
 #ifndef FW_PROFILING_DISABLED
     {
@@ -98,7 +103,7 @@ void TransformationMatrix3DTest::identityMatrixTest()
 #else
     ::fwDataTools::TransformationMatrix3D::invert(tm1, tm4);
 #endif
-    CPPUNIT_ASSERT(isIdentity(tm4));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm4));
 
 #ifndef FW_PROFILING_DISABLED
     {
@@ -128,16 +133,16 @@ void TransformationMatrix3DTest::matrixTest()
     ::fwDataTools::TransformationMatrix3D::identity(tm2);
 
     ::fwData::TransformationMatrix3D::TMCoefArray tm1Coefs;
-    for (int i = 0; i<16; ++i)
+    for (int i = 0; i < 16; ++i)
     {
         tm1Coefs[i] = i+1;
     }
 
-    for (int i = 0; i<4; ++i)
+    for (int i = 0; i < 4; ++i)
     {
-        for (int j = 0; j<4; ++j)
+        for (int j = 0; j < 4; ++j)
         {
-            tm2->setCoefficient(i,j, fabs(static_cast<double>(i-j)) + 1);
+            tm2->setCoefficient(i, j, fabs(static_cast<double>(i-j)) + 1);
         }
     }
     tm1->setCoefficients(tm1Coefs);
@@ -145,37 +150,37 @@ void TransformationMatrix3DTest::matrixTest()
 
     // Test matrix-matrix multiplication
     ::fwDataTools::TransformationMatrix3D::multiply(tm1, tm2, tm3);
-    for (size_t i = 0; i<4; ++i)
+    for (size_t i = 0; i < 4; ++i)
     {
-        for (size_t j = 0; j<4; ++j)
+        for (size_t j = 0; j < 4; ++j)
         {
             double val = 0;
-            for (size_t k = 0; k<4; ++k)
+            for (size_t k = 0; k < 4; ++k)
             {
-                val += tm1->getCoefficient(i,k)*tm2->getCoefficient(k,j);
+                val += tm1->getCoefficient(i, k)*tm2->getCoefficient(k, j);
             }
-            CPPUNIT_ASSERT_EQUAL(val, tm3->getCoefficient(i,j));
+            CPPUNIT_ASSERT_EQUAL(val, tm3->getCoefficient(i, j));
         }
     }
 
     // Test invert
     ::fwDataTools::TransformationMatrix3D::invert(tm2, tm4);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.4, tm4->getCoefficient(0,0), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(0,1), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(0,2), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.1,  tm4->getCoefficient(0,3), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(1,0), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-1.,  tm4->getCoefficient(1,1), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(1,2), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(1,3), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(2,0), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(2,1), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-1.,  tm4->getCoefficient(2,2), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(2,3), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.1,  tm4->getCoefficient(3,0), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(3,1), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(3,2), 0.00001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.4, tm4->getCoefficient(3,3), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.4, tm4->getCoefficient(0, 0), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(0, 1), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(0, 2), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.1,  tm4->getCoefficient(0, 3), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(1, 0), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-1.,  tm4->getCoefficient(1, 1), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(1, 2), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(1, 3), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(2, 0), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(2, 1), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-1.,  tm4->getCoefficient(2, 2), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(2, 3), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.1,  tm4->getCoefficient(3, 0), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.,   tm4->getCoefficient(3, 1), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.5,  tm4->getCoefficient(3, 2), 0.00001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.4, tm4->getCoefficient(3, 3), 0.00001);
 
     ::fwData::TransformationMatrix3D::TMCoefArray tm2Coefs = { 3.1, 1., -7.9689, 4.9,
                                                                5., -21., -1.3646, 14.4,
@@ -184,25 +189,25 @@ void TransformationMatrix3DTest::matrixTest()
     tm2->setCoefficients(tm2Coefs);
     ::fwDataTools::TransformationMatrix3D::invert(tm2, tm4);
 
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.885131908604589, tm4->getCoefficient(0,0), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.190212289294002, tm4->getCoefficient(0,1), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.29581348830958, tm4->getCoefficient(0,2), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.326489683580158, tm4->getCoefficient(0,3), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.885131908604589, tm4->getCoefficient(0, 0), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.190212289294002, tm4->getCoefficient(0, 1), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.29581348830958, tm4->getCoefficient(0, 2), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.326489683580158, tm4->getCoefficient(0, 3), 0.0001);
 
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.185258037237573, tm4->getCoefficient(1,0), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.00768780306376934, tm4->getCoefficient(1,1), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0586854220133396, tm4->getCoefficient(1,2), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0769210199757416, tm4->getCoefficient(1,3), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.185258037237573, tm4->getCoefficient(1, 0), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.00768780306376934, tm4->getCoefficient(1, 1), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0586854220133396, tm4->getCoefficient(1, 2), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0769210199757416, tm4->getCoefficient(1, 3), 0.0001);
 
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.232796743379289, tm4->getCoefficient(2,0), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.0724476129133489, tm4->getCoefficient(2,1), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.118830425964518, tm4->getCoefficient(2,2), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.144341353618837, tm4->getCoefficient(2,3), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.232796743379289, tm4->getCoefficient(2, 0), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.0724476129133489, tm4->getCoefficient(2, 1), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.118830425964518, tm4->getCoefficient(2, 2), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.144341353618837, tm4->getCoefficient(2, 3), 0.0001);
 
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.015108772570731, tm4->getCoefficient(3,0), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.000947451265806253, tm4->getCoefficient(3,1), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.00586927638865189, tm4->getCoefficient(3,2), 0.0001);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0124903619956978, tm4->getCoefficient(3,3), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.015108772570731, tm4->getCoefficient(3, 0), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.000947451265806253, tm4->getCoefficient(3, 1), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(0.00586927638865189, tm4->getCoefficient(3, 2), 0.0001);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(-0.0124903619956978, tm4->getCoefficient(3, 3), 0.0001);
 
     // Test matrix-vector multiplication
     ::fwData::Point::sptr p1 = ::fwData::Point::New(1.0f, 2.3f, 5.1f);
@@ -215,8 +220,8 @@ void TransformationMatrix3DTest::matrixTest()
 
     ::fwDataTools::TransformationMatrix3D::identity(tm1);
     ::fwDataTools::TransformationMatrix3D::identity(tm2);
-    CPPUNIT_ASSERT(isIdentity(tm1));
-    CPPUNIT_ASSERT(isIdentity(tm2));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm1));
+    CPPUNIT_ASSERT( ::fwDataTools::TransformationMatrix3D::isIdentity(tm2));
 }
 
 //------------------------------------------------------------------------------
