@@ -239,7 +239,7 @@ void PointListTest::transform()
         pl2->pushBack(::fwData::Point::New(-1.0f, -1.0f, 1.0f));
         pl2->pushBack(::fwData::Point::New(0.0f, -1.0f, 1.0f));
 
-        // Perform a 180° rotation around Z
+        // Perform a 180 degrees rotation around Z
         const ::fwData::TransformationMatrix3D::sptr tf1 = ::fwData::TransformationMatrix3D::New();
         tf1->setCoefficient(0, 0, -1.0f);
         tf1->setCoefficient(0, 1, 0.0f);
@@ -369,7 +369,7 @@ void PointListTest::associate()
         // Shift the points in Z
         tf1->setCoefficient(2, 3, 4.2);
 
-        // Add a 90° rotation around Y
+        // Add a 90 degrees rotation around Y
         tf1->setCoefficient(0, 0, 0.0f);
         tf1->setCoefficient(0, 2, 1.0f);
         tf1->setCoefficient(2, 0, 1.0f);
@@ -381,7 +381,7 @@ void PointListTest::associate()
         ::fwDataTools::helper::PointList::associate(pl1, pl2);
 
         // Check that the two lists are equal
-        // The second one corresponds to a Z translation + a 90° Y translation of the first one
+        // The second one corresponds to a Z translation + a 90 degrees Y translation of the first one
         const ::fwData::PointList::PointListContainer points1 = pl1->getPoints();
         const ::fwData::PointList::PointListContainer points2 = pl2->getPoints();
 
@@ -403,5 +403,89 @@ void PointListTest::associate()
     }
 }
 
+//------------------------------------------------------------------------------
+
+void PointListTest::removeClosestPointNominal()
+{
+    const size_t nbPoints = 42;
+    ::fwData::PointList::sptr pl = ::fwData::PointList::New();
+
+    // Remove points in an empty list
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p = ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        CPPUNIT_ASSERT( ::fwDataTools::helper::PointList::removeClosestPoint(pl, p,
+                                                                             std::numeric_limits<float>::min()) ==
+                        nullptr );
+    }
+
+    // Build a list
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p = ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        pl->pushBack(p);
+    }
+
+    // Remove points with an unmatched delta
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p = ::fwData::Point::New(static_cast< float >(nbPoints+1), static_cast< float >(nbPoints+1),
+                                            static_cast< float >(nbPoints+1));
+        CPPUNIT_ASSERT( ::fwDataTools::helper::PointList::removeClosestPoint(pl, p,
+                                                                             std::numeric_limits<float>::min()) ==
+                        nullptr );
+    }
+
+    // Remove points
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p =
+            ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        const auto pRes =
+            ::fwDataTools::helper::PointList::removeClosestPoint(pl, p, std::numeric_limits<float>::max());
+        CPPUNIT_ASSERT(pRes != nullptr);
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[0], p->getCoord()[0], std::numeric_limits<float>::min());
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[1], p->getCoord()[1], std::numeric_limits<float>::min());
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[2], p->getCoord()[2], std::numeric_limits<float>::min());
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void PointListTest::removeClosestPointExtreme()
+{
+    const size_t nbPoints = 42;
+    ::fwData::PointList::sptr pl = ::fwData::PointList::New();
+
+    // Build a list
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p = ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        pl->pushBack(p);
+    }
+
+    // Remove points with negative delta
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p = ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        CPPUNIT_ASSERT(::fwDataTools::helper::PointList::removeClosestPoint(pl, p,
+                                                                            -std::numeric_limits<float>::max()) ==
+                       nullptr);
+    }
+
+    // Remove points with biggest delta
+    for(size_t i = 0; i < nbPoints; ++i)
+    {
+        const auto p =
+            ::fwData::Point::New(static_cast< float >(i), static_cast< float >(i), static_cast< float >(i));
+        const auto pRes =
+            ::fwDataTools::helper::PointList::removeClosestPoint(pl, p, std::numeric_limits<float>::max());
+        CPPUNIT_ASSERT(pRes != nullptr);
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[0], p->getCoord()[0], i + std::numeric_limits<float>::max());
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[1], p->getCoord()[1], i + std::numeric_limits<float>::max());
+        CPPUNIT_ASSERT_DOUBLES_EQUAL(pRes->getCoord()[2], p->getCoord()[2], i + std::numeric_limits<float>::max());
+    }
+}
+
 } //namespace ut
 } //namespace fwDataTools
