@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWDICOMTOOLS_SERIES_HPP__
-#define __FWDICOMTOOLS_SERIES_HPP__
+#pragma once
 
 #include "fwDicomTools/config.hpp"
 
@@ -36,19 +35,15 @@ public:
      * @param[in] series DicomSeries that must be converted
      */
     FWDICOMTOOLS_API static SPTR(::fwMedData::ImageSeries) convertToImageSeries(
-        const SPTR(::fwMedData::DicomSeries)& series);
+        const CSPTR(::fwMedData::DicomSeries)& series);
 
     /**
      * @brief Convert a DicomSeries to a ModelSeries
      * @param[in] series DicomSeries that must be converted
      */
     FWDICOMTOOLS_API static SPTR(::fwMedData::ModelSeries) convertToModelSeries(
-        const SPTR(::fwMedData::DicomSeries)& series);
-
+        const CSPTR(::fwMedData::DicomSeries)& series);
 
 };
 
 } //fwDicomTools
-
-
-#endif /* __FWDICOMTOOLS_SERIES_HPP__ */
