@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUI_APPLICATION_HPP_
-#define _FWGUI_APPLICATION_HPP_
+#ifndef __FWGUI_APPLICATION_HPP__
+#define __FWGUI_APPLICATION_HPP__
 
 #include <fwCore/base.hpp>
 
@@ -18,7 +18,7 @@ namespace fwGui
 /**
  * @brief   Gives access to the underlayed application part
  * @class   Application
- * 
+ *
  * @date    2009-2010.
  *
  */
@@ -36,14 +36,18 @@ protected:
     /// Application factory, returning the registered instance of Application. Manage a Singleton.
     FWGUI_API static Application::sptr factory();
 
-    Application(){};
-    virtual ~Application(){};
+    Application()
+    {
+    }
+    virtual ~Application()
+    {
+    }
 
 
 };
 
 } // namespace fwGui
 
-#endif /*_FWGUI_APPLICATION_HPP_*/
+#endif /*__FWGUI_APPLICATION_HPP__*/
 
 
