@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,9 +7,6 @@
 #ifndef __FWGUI_GUIBASEOBJECT_HPP__
 #define __FWGUI_GUIBASEOBJECT_HPP__
 
-
-#include <boost/enable_shared_from_this.hpp>
-
 #include <fwCore/base.hpp>
 
 #include "fwGui/factory/new.hpp"
@@ -25,7 +22,7 @@ namespace fwGui
 class FWGUI_CLASS_API GuiBaseObject : public ::fwCore::BaseObject
 {
 
-public :
+public:
 
     typedef ::fwGui::factory::Key Key;
 
@@ -47,13 +44,17 @@ public :
 
     fwCoreNonInstanciableClassDefinitionsMacro( (GuiBaseObject)(::fwCore::BaseObject) );
 
-protected :
+protected:
     /**
      * @name Constructor/Destructor
      * @{ */
 
-    GuiBaseObject(){};
-    virtual ~GuiBaseObject(){};
+    GuiBaseObject()
+    {
+    }
+    virtual ~GuiBaseObject()
+    {
+    }
 
     /**  @} */
 
