@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUI_IINPUTDIALOG_HPP_
-#define _FWGUI_IINPUTDIALOG_HPP_
+#ifndef __FWGUI_DIALOG_IINPUTDIALOG_HPP__
+#define __FWGUI_DIALOG_IINPUTDIALOG_HPP__
 
 #include <string>
 
@@ -19,7 +19,7 @@ namespace dialog
 /**
  * @brief   Defines the generic input dialog box for IHM.
  * @class   IInputDialog
- * 
+ *
  * @date    2009-2010.
  *
  */
@@ -55,6 +55,6 @@ public:
 } //namespace dialog
 } // namespace fwGui
 
-#endif /*_FWGUI_IINPUTDIALOG_HPP_*/
+#endif /*__FWGUI_DIALOG_IINPUTDIALOG_HPP__*/
 
 
