@@ -1,27 +1,22 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWGUI_DIALOG_IMESSAGEDIALOG_HPP__
-#define __FWGUI_DIALOG_IMESSAGEDIALOG_HPP__
+#pragma once
+
+#include "fwGui/config.hpp"
+#include "fwGui/GuiBaseObject.hpp"
 
 #include <string>
 
-#include "fwGui/GuiBaseObject.hpp"
-#include "fwGui/config.hpp"
-
 namespace fwGui
 {
 namespace dialog
 {
 /**
  * @brief   Defines the generic message box for IHM.
- * @class   IMessageDialog
- *
- * @date    2009-2010.
- *
  */
 class FWGUI_CLASS_API IMessageDialog : public ::fwGui::GuiBaseObject
 {
@@ -45,12 +40,12 @@ public:
     {
         NOBUTTON = 0, // invalid
 
-        OK         = 1 << 1,
-            YES    = 1 << 2,
-            NO     = 1 << 3,
-            CANCEL = 1 << 4,
+        OK     = 1 << 1,
+        YES    = 1 << 2,
+        NO     = 1 << 3,
+        CANCEL = 1 << 4,
 
-            YES_NO = YES | NO
+        YES_NO = YES | NO
     } Buttons;
 
     /// Constructor. Do nothing.
@@ -58,15 +53,14 @@ public:
     /// Destructor. Do nothing.
     FWGUI_API virtual ~IMessageDialog();
 
-
     typedef std::string FactoryRegistryKeyType;
     FWGUI_API static const FactoryRegistryKeyType REGISTRY_KEY;
 
     /// Set the title of the message box
-    FWGUI_API virtual void setTitle(const std::string &title) = 0;
+    FWGUI_API virtual void setTitle(const std::string& title) = 0;
 
     /// Set the message
-    FWGUI_API virtual void setMessage(const std::string &msg) = 0;
+    FWGUI_API virtual void setMessage(const std::string& msg) = 0;
 
     /// Set the icon (CRITICAL, WARNING, INFO or QUESTION)
     FWGUI_API virtual void setIcon( Icons icon) = 0;
@@ -77,6 +71,9 @@ public:
     /// Set the default button
     FWGUI_API virtual void setDefaultButton(Buttons button) = 0;
 
+    /// Add a custom button to this dialog
+    FWGUI_API virtual void addCustomButton(const std::string& label, std::function<void()> clickedFn) = 0;
+
     /// Show the message box and return the clicked button.
     FWGUI_API virtual Buttons show() = 0;
 
@@ -84,7 +81,3 @@ public:
 
 } //namespace dialog
 } // namespace fwGui
-
-#endif /*__FWGUI_DIALOG_IMESSAGEDIALOG_HPP__*/
-
-
