@@ -1,17 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWGUI_DIALOG_SELECTORDIALOG_HPP__
-#define __FWGUI_DIALOG_SELECTORDIALOG_HPP__
+#pragma once
 
 #include "fwGui/config.hpp"
 #include "fwGui/dialog/ISelectorDialog.hpp"
 
-#include <fwCore/base.hpp>
-
 namespace fwGui
 {
 namespace dialog
@@ -68,6 +65,9 @@ public:
     /// Set the message
     FWGUI_API virtual void setMessage(const std::string& msg) override;
 
+    /// Add a custom button to this dialog
+    FWGUI_API virtual void addCustomButton(const std::string& label, std::function<void()> clickedFn) override;
+
 protected:
 
     ::fwGui::dialog::ISelectorDialog::sptr m_implementation;
@@ -76,6 +76,3 @@ protected:
 
 } //namespace dialog
 } // namespace fwGui
-
-#endif /*__FWGUI_DIALOG_SELECTORDIALOG_HPP__*/
-
