@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,11 @@
 #ifndef __FWGUI_FACTORY_NEW_HPP__
 #define __FWGUI_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwGui/config.hpp"
 #include "fwGui/registry/detail.hpp"
 
+#include <string>
+
 namespace fwGui
 {
 
@@ -24,7 +20,6 @@ class GuiBaseObject;
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -33,17 +28,19 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwGui::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwGui::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
 FWGUI_API SPTR( ::fwGui::GuiBaseObject ) New( const ::fwGui::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) guiObj = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) guiObj = std::make_shared< CLASSNAME >( Key() );
     return guiObj;
 }
 
@@ -53,4 +50,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWGUI_FACTORY_NEW_HPP__ */
 
-
