@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -10,17 +10,19 @@
 namespace fwGui
 {
 
-const IApplication::FactoryRegistryKeyType IApplication::REGISTRY_KEY =  "::fwGui::Application";
+const IApplication::FactoryRegistryKeyType IApplication::REGISTRY_KEY = "::fwGui::Application";
 
 //-----------------------------------------------------------------------------
 
-IApplication::IApplication()
-{}
+IApplication::IApplication() : m_confirm(false)
+{
+}
 
 //-----------------------------------------------------------------------------
 
 IApplication::~IApplication()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
