@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -8,12 +8,10 @@
  * @file fwGui/builder/IContainerBuilder.cpp
  * @brief This file defines the implementation of the interface class  for the menubar builder.
  *
- * 
+ *
  * @date 2009-2010
  */
 
-#include <boost/foreach.hpp>
-
 #include "fwGui/builder/IContainerBuilder.hpp"
 
 namespace fwGui
@@ -26,17 +24,20 @@ const IContainerBuilder::RegistryKeyType IContainerBuilder::REGISTRY_KEY = "::fw
 //-----------------------------------------------------------------------------
 
 IContainerBuilder::IContainerBuilder()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 IContainerBuilder::~IContainerBuilder()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 void IContainerBuilder::initialize( ::fwRuntime::ConfigurationElement::sptr configuration)
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
