@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -8,12 +8,10 @@
  * @file fwGui/builder/IMenuBarBuilder.cpp
  * @brief This file defines the implementation of the interface class  for the menubar builder.
  *
- * 
+ *
  * @date 2009-2010
  */
 
-#include <boost/foreach.hpp>
-
 #include "fwGui/builder/IMenuBarBuilder.hpp"
 
 namespace fwGui
@@ -26,12 +24,14 @@ const IMenuBarBuilder::RegistryKeyType IMenuBarBuilder::REGISTRY_KEY = "::fwGui:
 //-----------------------------------------------------------------------------
 
 IMenuBarBuilder::IMenuBarBuilder()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 IMenuBarBuilder::~IMenuBarBuilder()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
