@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -12,13 +12,16 @@ namespace fwGui
 namespace dialog
 {
 
-const IMultiSelectorDialog::FactoryRegistryKeyType IMultiSelectorDialog::REGISTRY_KEY =  "::fwGui::dialog::MultiSelectorDialog";
+const IMultiSelectorDialog::FactoryRegistryKeyType IMultiSelectorDialog::REGISTRY_KEY =
+    "::fwGui::dialog::MultiSelectorDialog";
 
 IMultiSelectorDialog::IMultiSelectorDialog()
-{}
+{
+}
 
 IMultiSelectorDialog::~IMultiSelectorDialog()
-{}
+{
+}
 
 } // namespace dialog
 } // namespace fwGui
