@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -12,15 +12,18 @@ namespace fwGui
 namespace dialog
 {
 
-const IPulseProgressDialog::FactoryRegistryKeyType IPulseProgressDialog::REGISTRY_KEY =  "::fwGui::dialog::PulseProgressDialog";
+const IPulseProgressDialog::FactoryRegistryKeyType IPulseProgressDialog::REGISTRY_KEY =
+    "::fwGui::dialog::PulseProgressDialog";
 
 IPulseProgressDialog::IPulseProgressDialog()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 IPulseProgressDialog::~IPulseProgressDialog()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
