@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2014.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -8,12 +8,8 @@
  * @file fwGui/layoutManager/IViewLayoutManager.cpp
  * @brief This file defines the implementation of the base class for managing a layout geometry.
  *
- *
- * @date 2009-2010
  */
 
-#include <boost/foreach.hpp>
-
 #include "fwGui/layoutManager/IViewLayoutManager.hpp"
 
 namespace fwGui
@@ -24,20 +20,21 @@ namespace layoutManager
 //-----------------------------------------------------------------------------
 
 IViewLayoutManager::IViewLayoutManager()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 IViewLayoutManager::~IViewLayoutManager()
-{}
+{
+}
 
 //-----------------------------------------------------------------------------
 
 void IViewLayoutManager::destroySubViews()
 {
-    BOOST_FOREACH( ::fwGui::container::fwContainer::sptr container, m_subViews)
+    for( ::fwGui::container::fwContainer::sptr container :  m_subViews)
     {
-        container->clean();
         container->destroyContainer();
     }
     m_subViews.clear();
@@ -55,5 +52,3 @@ std::vector< ::fwGui::container::fwContainer::sptr > IViewLayoutManager::getSubV
 } // namespace layoutManager
 } // namespace fwGui
 
-
-
