@@ -1,20 +1,20 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include "fwGui/GuiRegistry.hpp"
-#include "fwGui/IActionSrv.hpp"
 #include "fwGui/registrar/ToolBarRegistrar.hpp"
 
-#include <fwTools/fwID.hpp>
+#include "fwGui/GuiRegistry.hpp"
+#include "fwGui/IActionSrv.hpp"
 
 #include <fwServices/macros.hpp>
 #include <fwServices/op/Get.hpp>
 
-#include <utility>
+#include <fwTools/fwID.hpp>
 
+#include <utility>
 
 namespace fwGui
 {
@@ -23,7 +23,8 @@ namespace registrar
 
 //-----------------------------------------------------------------------------
 
-ToolBarRegistrar::ToolBarRegistrar(const std::string& sid) : m_sid(sid)
+ToolBarRegistrar::ToolBarRegistrar(const std::string& sid) :
+    m_sid(sid)
 {
 }
 
@@ -73,7 +74,7 @@ void ToolBarRegistrar::initialize( ::fwRuntime::ConfigurationElement::sptr confi
                 std::string startValue = menuItem->getAttributeValue("start");
                 SLM_ASSERT("Wrong value '"<< startValue <<"' for 'start' attribute (require yes or no)",
                            startValue == "yes" || startValue == "no");
-                start = (startValue=="yes");
+                start = (startValue == "yes");
             }
             std::string sid = menuItem->getAttributeValue("sid");
             OSLM_ASSERT("Action " << sid << " already exists for this toolBar", m_actionSids.find(
@@ -104,7 +105,7 @@ void ToolBarRegistrar::initialize( ::fwRuntime::ConfigurationElement::sptr confi
                 std::string startValue = menu->getAttributeValue("start");
                 SLM_ASSERT("Wrong value '"<< startValue <<"' for 'start' attribute (require yes or no)",
                            startValue == "yes" || startValue == "no");
-                start = (startValue=="yes");
+                start = (startValue == "yes");
             }
             std::string sid = menu->getAttributeValue("sid");
             OSLM_ASSERT("Action " << sid << " already exists for this toolBar",
@@ -128,7 +129,7 @@ void ToolBarRegistrar::initialize( ::fwRuntime::ConfigurationElement::sptr confi
                 std::string startValue = editor->getAttributeValue("start");
                 SLM_ASSERT("Wrong value '"<< startValue <<"' for 'start' attribute (require yes or no)",
                            startValue == "yes" || startValue == "no");
-                start = (startValue=="yes");
+                start = (startValue == "yes");
             }
             std::string sid = editor->getAttributeValue("sid");
             OSLM_ASSERT("Action " << sid << " already exists for this toolBar", m_editorSids.find(
@@ -157,7 +158,7 @@ void ToolBarRegistrar::manage(std::vector< ::fwGui::container::fwMenuItem::sptr
         ::fwGui::GuiRegistry::registerActionSIDToParentSID(sid.first, m_sid);
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             OSLM_ASSERT("Service "<<sid.first <<" must be stopped.", service->isStopped() );
             service->start();
@@ -190,7 +191,7 @@ void ToolBarRegistrar::manage(std::vector< ::fwGui::container::fwMenu::sptr > me
         ::fwGui::GuiRegistry::registerSIDMenu(sid.first, menu);
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             OSLM_ASSERT("Service "<<sid.first <<" must be stopped.", service->isStopped() );
             service->start();
@@ -211,7 +212,7 @@ void ToolBarRegistrar::manage(std::vector< ::fwGui::container::fwContainer::sptr
         ::fwGui::GuiRegistry::registerSIDContainer(sid.first, container);
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             OSLM_ASSERT("Service "<<sid.first <<" must be stopped.", service->isStopped() );
             service->start();
@@ -234,7 +235,7 @@ void ToolBarRegistrar::unmanage()
     {
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             service->stop();
         }
@@ -244,7 +245,7 @@ void ToolBarRegistrar::unmanage()
     {
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             service->stop();
         }
@@ -254,7 +255,7 @@ void ToolBarRegistrar::unmanage()
     {
         if(sid.second.second) //service is auto started?
         {
-            OSLM_ASSERT("Service "<<sid.first <<" not exists.", ::fwTools::fwID::exist(sid.first ) );
+            OSLM_ASSERT("Service "<<sid.first <<" does not exist.", ::fwTools::fwID::exist(sid.first ) );
             ::fwServices::IService::sptr service = ::fwServices::get( sid.first );
             service->stop();
         }
