@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUIQT_ACTIONCALLBACK_HPP_
-#define _FWGUIQT_ACTIONCALLBACK_HPP_
+#ifndef __FWGUIQT_ACTIONCALLBACK_HPP__
+#define __FWGUIQT_ACTIONCALLBACK_HPP__
 
 
 #include <QObject>
@@ -21,24 +21,25 @@ namespace fwGuiQt
 /**
  * @brief   Defines the menu item callback.
  * @class   ActionCallback
- * 
+ *
  * @date    2009-2010.
  *
  */
-class FWGUIQT_CLASS_API ActionCallback :  public QObject, public ::fwGui::ActionCallbackBase
+class FWGUIQT_CLASS_API ActionCallback :  public QObject,
+                                          public ::fwGui::ActionCallbackBase
 {
 
-    Q_OBJECT
+Q_OBJECT
 
-public :
+public:
 
     fwCoreClassDefinitionsWithFactoryMacro( (ActionCallback)(::fwGui::ActionCallbackBase),
                                             (()),
                                             ::fwGui::factory::New< ActionCallback > );
 
-    FWGUIQT_API ActionCallback(::fwGui::GuiBaseObject::Key key) ;
+    FWGUIQT_API ActionCallback(::fwGui::GuiBaseObject::Key key);
 
-    FWGUIQT_API virtual ~ActionCallback() ;
+    FWGUIQT_API virtual ~ActionCallback();
 
     /**
      * @brief  Qt slot.
@@ -51,6 +52,6 @@ public Q_SLOTS:
 
 } // namespace fwGuiQt
 
-#endif /*_FWGUIQT_ACTIONCALLBACK_HPP_*/
+#endif /*__FWGUIQT_ACTIONCALLBACK_HPP__*/
 
 
