@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUIQT_APPLICATION_HPP_
-#define _FWGUIQT_APPLICATION_HPP_
+#ifndef __FWGUIQT_APPLICATION_HPP__
+#define __FWGUIQT_APPLICATION_HPP__
 
 #include <fwCore/base.hpp>
 
@@ -19,7 +19,7 @@ namespace fwGuiQt
 /**
  * @brief   Gives access to the qt application part
  * @class   Application
- * 
+ *
  * @date    2009-2010.
  *
  */
@@ -28,9 +28,13 @@ class FWGUIQT_CLASS_API Application : public ::fwGui::Application
 
 public:
 
-    Application(::fwGui::GuiBaseObject::Key key){};
+    Application(::fwGui::GuiBaseObject::Key key)
+    {
+    }
 
-    virtual ~Application(){};
+    virtual ~Application()
+    {
+    }
 
     /// Tells the application to exit with a returncode
     FWGUIQT_API virtual void exit( int returncode = 0);
@@ -39,6 +43,6 @@ public:
 
 } // namespace fwGuiQt
 
-#endif /*_FWGUIQT_APPLICATION_HPP_*/
+#endif /*__FWGUIQT_APPLICATION_HPP__*/
 
 
