@@ -1,16 +1,16 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWGUIQTNAMESPACE_HPP_
-#define FWGUIQTNAMESPACE_HPP_
+#ifndef __FWGUIQT_NAMESPACE_HPP__
+#define __FWGUIQT_NAMESPACE_HPP__
 
 /**
  * @brief       The namespace fwGuiQt contains classes which provide the implementation of the Gui using Qt library.
  * @namespace   fwGuiQt
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -18,4 +18,4 @@
 namespace fwGuiQt
 {
 }
-#endif /* FWGUIQTNAMESPACE_HPP_ */
+#endif /* __FWGUIQT_NAMESPACE_HPP__ */
