@@ -1,48 +1,45 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUIQT_MAINFRAME_HPP_
-#define _FWGUIQT_MAINFRAME_HPP_
-
-
-#include <QPointer>
-#include <QMainWindow>
-
-#include <boost/function.hpp>
+#ifndef __FWGUIQT_QTMAINFRAME_HPP__
+#define __FWGUIQT_QTMAINFRAME_HPP__
 
 #include "fwGuiQt/config.hpp"
 
+#include <QMainWindow>
+#include <QPointer>
+
+#include <functional>
+
 namespace fwGuiQt
 {
 
 /**
  * @brief A qt panel used to control a VTK 2D Negatoscope view.
- * 
+ *
  */
 class QtMainFrame : public QMainWindow
 {
 
-    Q_OBJECT
+Q_OBJECT
 
 public:
     /**
      * @brief Constructor.
      */
-    FWGUIQT_API QtMainFrame() throw();
-
+    FWGUIQT_API QtMainFrame() noexcept;
 
     /// @brief Destructor.
-    FWGUIQT_API virtual ~QtMainFrame() throw();
+    FWGUIQT_API virtual ~QtMainFrame() noexcept;
 
-    typedef ::boost::function0<void> CloseCallback;
+    typedef std::function<void ()> CloseCallback;
     FWGUIQT_API void setCloseCallback(CloseCallback fct);
 
-
 protected:
-    void closeEvent(QCloseEvent *event);
+    void closeEvent(QCloseEvent* event);
 
 private:
     CloseCallback m_fctCloseCallback;
@@ -50,4 +47,4 @@ private:
 
 } // fwGuiQt
 
-#endif // _FWGUIQT_MAINFRAME_HPP_
+#endif // __FWGUIQT_QTMAINFRAME_HPP__
