@@ -1,18 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWGUIQTCONTAINERNAMESPACE_HPP_
-#define FWGUIQTCONTAINERNAMESPACE_HPP_
+#ifndef __FWGUIQT_CONTAINER_NAMESPACE_HPP__
+#define __FWGUIQT_CONTAINER_NAMESPACE_HPP__
 
 namespace fwGuiQt
 {
 /**
  * @brief       The namespace fwGuiQt::container contains the classes used for container implementation with Qt Library.
  * @namespace   fwGuiQt::container
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -21,4 +21,4 @@ namespace container
 
 }
 }
-#endif /* FWGUIQTCONTAINERNAMESPACE_HPP_ */
+#endif /* __FWGUIQT_CONTAINER_NAMESPACE_HPP__ */
