@@ -1,27 +1,26 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP_
-#define _FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP_
-
-#include <QPointer>
-
-#include <fwCore/base.hpp>
-#include <fwTools/Object.hpp>
-
-#include <fwGui/container/fwMenu.hpp>
+#ifndef __FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP__
+#define __FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP__
 
 #include "fwGuiQt/config.hpp"
 
+#include <fwCore/base.hpp>
+
+#include <fwGui/container/fwMenu.hpp>
+
+#include <fwTools/Object.hpp>
+
+#include <QPointer>
 
 QT_BEGIN_NAMESPACE
 class QMenu;
 QT_END_NAMESPACE
 
-
 namespace fwGuiQt
 {
 namespace container
@@ -29,9 +28,6 @@ namespace container
 
 /**
  * @brief   Defines the Qt menu bar container for IHM.
- * @class   QtMenuContainer
- * 
- * @date    2009-2010.
  *
  */
 class FWGUIQT_CLASS_API QtMenuContainer : public ::fwGui::container::fwMenu
@@ -43,18 +39,17 @@ public:
                                             (()),
                                             ::fwGui::factory::New< QtMenuContainer > );
 
-    FWGUIQT_API QtMenuContainer(::fwGui::GuiBaseObject::Key key) throw() ;
+    FWGUIQT_API QtMenuContainer(::fwGui::GuiBaseObject::Key key) noexcept;
 
-    FWGUIQT_API virtual ~QtMenuContainer() throw() ;
+    FWGUIQT_API virtual ~QtMenuContainer() noexcept;
 
+    FWGUIQT_API virtual void clean() override;
+    FWGUIQT_API virtual void destroyContainer() override;
 
-    FWGUIQT_API virtual void clean();
-    FWGUIQT_API virtual void destroyContainer();
-
-    FWGUIQT_API virtual void setQtMenu(QMenu *menu);
+    FWGUIQT_API virtual void setQtMenu(QMenu* menu);
     FWGUIQT_API virtual QMenu* getQtMenu();
 
-private :
+private:
 
     QPointer<QMenu> m_menu;
 };
@@ -62,6 +57,5 @@ private :
 } // namespace container
 } // namespace fwGuiQt
 
-#endif /*_FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP_*/
-
+#endif /*__FWGUIQT_CONTAINER_QTMENUCONTAINER_HPP__*/
 
