@@ -1,16 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWGUIQT_DIALOG_SELECTORDIALOG_HPP__
-#define __FWGUIQT_DIALOG_SELECTORDIALOG_HPP__
+#pragma once
 
 #include "fwGuiQt/config.hpp"
 
 #include <fwGui/dialog/ISelectorDialog.hpp>
 
+#include <QPushButton>
+#include <QVector>
+
 #include <vector>
 
 namespace fwGuiQt
@@ -52,6 +54,9 @@ public:
     /// Set the message
     FWGUIQT_API virtual void setMessage(const std::string& msg) override;
 
+    /// Add a custom button to this dialog
+    FWGUIQT_API virtual void addCustomButton(const std::string& label, std::function<void()> clickedFn) override;
+
 private:
 
     std::vector< std::string > m_selections;
@@ -59,9 +64,10 @@ private:
     /// Dialog box message
     std::string m_message;
     std::string m_title;
+
+    /// Stores custom buttons
+    QVector< QPushButton* > m_customButtons;
 };
 
 } // namespace dialog
 } // namespace fwGuiQt
-
-#endif /*__FWGUIQT_DIALOG_SELECTORDIALOG_HPP__*/
