@@ -1,32 +1,34 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <QApplication>
-#include <QMainWindow>
-#include <QCloseEvent>
-
-#include <boost/bind.hpp>
-#include <boost/lambda/lambda.hpp>
+#include "fwGuiQt/QtMainFrame.hpp"
 
 #include <fwCore/base.hpp>
 
-#include "fwGuiQt/QtMainFrame.hpp"
+#include <fwGui/dialog/IMessageDialog.hpp>
+#include <fwGui/dialog/MessageDialog.hpp>
+
+#include <boost/lambda/lambda.hpp>
+
+#include <QCloseEvent>
+#include <QMainWindow>
 
 namespace fwGuiQt
 {
 
+//------------------------------------------------------------------------------
+
+QtMainFrame::QtMainFrame() noexcept :
+    QMainWindow()
+{
+}
 
 //------------------------------------------------------------------------------
 
-QtMainFrame::QtMainFrame() throw(): QMainWindow()
-{}
-
-//------------------------------------------------------------------------------
-
-QtMainFrame::~QtMainFrame() throw()
+QtMainFrame::~QtMainFrame() noexcept
 {
 }
 
@@ -39,14 +41,13 @@ void QtMainFrame::setCloseCallback(CloseCallback fct)
 
 //------------------------------------------------------------------------------
 
-void QtMainFrame::closeEvent(QCloseEvent *event)
+void QtMainFrame::closeEvent(QCloseEvent* event)
 {
     SLM_TRACE_FUNC();
-//    event->ignore();
     m_fctCloseCallback();
+    event->ignore();
 }
 
-
 //------------------------------------------------------------------------------
 
 } // fwGuiQt
