@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -9,18 +9,19 @@
 
 #include <fwCore/base.hpp>
 
+#include <fwThread/Worker.hpp>
+
 #include <cppunit/extensions/HelperMacros.h>
 
 namespace fwGuiQt
 {
 
-struct WorkerQtInstanciator;
-
 namespace ut
 {
 
 class WorkerQtTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( WorkerQtTest );
 
     CPPUNIT_TEST(initTest);
