@@ -1,21 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWMATHNAMESPACE_HPP_
-#define FWMATHNAMESPACE_HPP_
+#ifndef __FWMATH_NAMESPACE_HPP__
+#define __FWMATH_NAMESPACE_HPP__
 
 /**
  * @brief       The namespace fwMath contains classes which provide the implementation of several mathematic functions and objects (plane, line, point).
  * @namespace   fwMath
- * 
- * @date        2009-2010.
- *
  */
 
 namespace fwMath
 {
 }
-#endif /* FWMATHNAMESPACE_HPP_ */
+#endif /* __FWMATH_NAMESPACE_HPP__ */
