@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMATH_TU_COMPARETEST_HPP__
-#define __FWMATH_TU_COMPARETEST_HPP__
+#ifndef __FWMATH_UT_COMPARETEST_HPP__
+#define __FWMATH_UT_COMPARETEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,6 +16,7 @@ namespace ut
 
 class CompareTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( CompareTest );
     CPPUNIT_TEST( checkEquality);
     CPPUNIT_TEST( checkContainerEquality);
@@ -26,7 +27,6 @@ public:
     void setUp();
     void tearDown();
 
-    // fonctions de tests
     void checkEquality();
     void checkContainerEquality();
 };
@@ -34,4 +34,4 @@ public:
 } //namespace ut
 } //namespace fwMath
 
-#endif //__FWMATH_TU_COMPARETEST_HPP__
+#endif //__FWMATH_UT_COMPARETEST_HPP__
