@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMATH_TU_MATRIXFUNCTIONSTEST_HPP__
-#define __FWMATH_TU_MATRIXFUNCTIONSTEST_HPP__
+#ifndef __FWMATH_UT_MATRIXFUNCTIONSTEST_HPP__
+#define __FWMATH_UT_MATRIXFUNCTIONSTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,20 +16,24 @@ namespace ut
 
 class MatrixFunctionsTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( MatrixFunctionsTest );
     CPPUNIT_TEST( checkMultVecMatrix);
+    CPPUNIT_TEST( checkRotationMatrix);
+    CPPUNIT_TEST( checkInverse);
     CPPUNIT_TEST_SUITE_END();
 
 public:
-    // interface
+
     void setUp();
     void tearDown();
-    // fonctions de tests
+
     void checkMultVecMatrix();
     void checkRotationMatrix();
+    void checkInverse();
 };
 
 } //namespace ut
 } //namespace fwMath
 
-#endif //__FWMATH_TU_MATRIXFUNCTIONSTEST_HPP__
+#endif //__FWMATH_UT_MATRIXFUNCTIONSTEST_HPP__
