@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMATH_TU_PLANEFUNCTIONSTEST_HPP__
-#define __FWMATH_TU_PLANEFUNCTIONSTEST_HPP__
+#ifndef __FWMATH_UT_PLANEFUNCTIONSTEST_HPP__
+#define __FWMATH_UT_PLANEFUNCTIONSTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,14 +16,17 @@ namespace ut
 
 class PlaneFunctionsTest : public CPPUNIT_NS::TestFixture
 {
+private:
     CPPUNIT_TEST_SUITE( PlaneFunctionsTest );
+    CPPUNIT_TEST( checkGetPlane );
+    CPPUNIT_TEST( checkSetValues );
     CPPUNIT_TEST( checkDistance );
     CPPUNIT_TEST( checkNormal );
-//  CPPUNIT_TEST( checkIntersect );
-    CPPUNIT_TEST( checkIsInHalfSpace_fwMath_SoLib );
+//    CPPUNIT_TEST( checkIntersect );
+    CPPUNIT_TEST( checkIsInHalfSpace );
     CPPUNIT_TEST( checkOffset );
     CPPUNIT_TEST( checkTransform );
-    CPPUNIT_TEST( checkIntersect_fwMath_SoLib);
+    CPPUNIT_TEST( checkOperator);
     CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -32,16 +35,18 @@ public:
     void tearDown();
 
     // fonctions de tests
+    void checkSetValues();
+    void checkGetPlane();
     void checkDistance();
     void checkNormal();
     void checkIntersect();
-    void checkIsInHalfSpace_fwMath_SoLib();
+    void checkIsInHalfSpace();
     void checkOffset();
     void checkTransform();
-    void checkIntersect_fwMath_SoLib();
+    void checkOperator();
 };
 
 } //namespace ut
 } //namespace fwMath
 
-#endif //__FWMATH_TU_PLANEFUNCTIONSTEST_HPP__
+#endif //__FWMATH_UT_PLANEFUNCTIONSTEST_HPP__
