@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2014.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -16,9 +16,11 @@ namespace ut
 
 class ModelSeriesTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ModelSeriesTest );
-    CPPUNIT_TEST(modelTest);
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( ModelSeriesTest );
+CPPUNIT_TEST(modelTest);
+CPPUNIT_TEST(deepCopyTest);
+CPPUNIT_TEST(shallowCopyTest);
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -26,6 +28,8 @@ public:
     void tearDown();
 
     void modelTest();
+    void deepCopyTest();
+    void shallowCopyTest();
 
 private:
     ModelSeries::sptr m_series;
