@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2014.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,22 +7,23 @@
 #ifndef __FWMEDDATA_UT_SERIESDBTEST_HPP__
 #define __FWMEDDATA_UT_SERIESDBTEST_HPP__
 
+#include "fwMedData/SeriesDB.hpp"
+
 #include <cppunit/extensions/HelperMacros.h>
 
 namespace fwMedData
 {
-    class SeriesDB;
 
 namespace ut
 {
 
 class SeriesDBTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( SeriesDBTest );
+CPPUNIT_TEST_SUITE( SeriesDBTest );
 
-    CPPUNIT_TEST(containerTest);
+CPPUNIT_TEST(containerTest);
 
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
