@@ -1,11 +1,12 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2014.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMEDDATA_UT_STUDYTEST_HPP__
-#define __FWMEDDATA_UT_STUDYTEST_HPP__
+#pragma once
+
+#include "fwMedData/Study.hpp"
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,14 +17,14 @@ namespace ut
 
 class StudyTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( StudyTest );
-    CPPUNIT_TEST(instanceUIDTest);
-    CPPUNIT_TEST(dateTest);
-    CPPUNIT_TEST(timeTest);
-    CPPUNIT_TEST(referringPhysicianNameTest);
-    CPPUNIT_TEST(descriptionTest);
-    CPPUNIT_TEST(patientAgeTest);
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( StudyTest );
+CPPUNIT_TEST(instanceUIDTest);
+CPPUNIT_TEST(dateTest);
+CPPUNIT_TEST(timeTest);
+CPPUNIT_TEST(referringPhysicianNameTest);
+CPPUNIT_TEST(descriptionTest);
+CPPUNIT_TEST(patientAgeTest);
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -43,6 +44,3 @@ private:
 
 } //namespace ut
 } //namespace fwMedData
-
-#endif //__FWMEDDATA_UT_STUDYTEST_HPP__
-
