@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,8 +7,7 @@
 #ifndef __FWMEMORY_CAMP_DECLARE_HPP__
 #define __FWMEMORY_CAMP_DECLARE_HPP__
 
-#include <fwCamp/macros.hpp>
-
+#define CAMP_COMPILATION
 #include "fwMemory/BufferObject.hpp"
 
 namespace fwMemory
