@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -22,7 +22,9 @@ namespace exception
  */
 struct FWMEMORY_CLASS_API BadCast : ::fwCore::Exception
 {
-    BadCast( const std::string &err ) : ::fwCore::Exception(err) {}
+    BadCast( const std::string &err ) : ::fwCore::Exception(err)
+    {
+    }
 };
 
 } // namespace exception
