@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,11 @@
 #ifndef __FWMEMORY_POLICY_FACTORY_NEW_HPP__
 #define __FWMEMORY_POLICY_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwMemory/config.hpp"
 #include "fwMemory/policy/registry/detail.hpp"
 
+#include <string>
+
 namespace fwMemory
 {
 
@@ -28,12 +24,11 @@ namespace factory
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
-
 FWMEMORY_API SPTR( ::fwMemory::IPolicy ) New( const ::fwMemory::policy::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) policy = ::boost::make_shared< CLASSNAME >();
+    SPTR(CLASSNAME) policy = std::make_shared< CLASSNAME >();
     return policy;
 }
 
@@ -43,4 +38,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWMEMORY_POLICY_FACTORY_NEW_HPP__ */
 
-
