@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,12 +7,12 @@
 #ifndef __FWMEMORY_STREAM_IN_BUFFER_HPP__
 #define __FWMEMORY_STREAM_IN_BUFFER_HPP__
 
-#include <boost/function.hpp>
+#include "fwMemory/config.hpp"
+#include "fwMemory/stream/in/IFactory.hpp"
 
 #include <fwCore/macros.hpp>
 
-#include "fwMemory/stream/in/IFactory.hpp"
-#include "fwMemory/config.hpp"
+#include <functional>
 
 namespace fwMemory
 {
@@ -24,8 +24,8 @@ namespace in
 class FWMEMORY_CLASS_API Buffer : public IFactory
 {
 public:
-    typedef SPTR(void) LockType;
-    typedef ::boost::function< LockType () > CounterFactoryType;
+    typedef SPTR (void) LockType;
+    typedef std::function< LockType() > CounterFactoryType;
 
     Buffer(void* buf, size_t size);
     Buffer(void* buf, size_t size, CounterFactoryType counterFactory);
@@ -39,12 +39,9 @@ protected:
     CounterFactoryType m_counterFactory;
 };
 
-
-
 } // namespace in
 } // namespace stream
 } // namespace fwMemory
 
 #endif // __FWMEMORY_STREAM_IN_BUFFER_HPP__
 
-
