@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,10 +7,11 @@
 #ifndef __FWMEMORY_STREAM_IN_IFACTORY_HPP__
 #define __FWMEMORY_STREAM_IN_IFACTORY_HPP__
 
-#include <istream>
+#include "fwMemory/config.hpp"
+
 #include <fwCore/macros.hpp>
 
-#include "fwMemory/config.hpp"
+#include <istream>
 
 namespace fwMemory
 {
@@ -22,9 +23,14 @@ namespace in
 class FWMEMORY_CLASS_API IFactory
 {
 public:
-    virtual ~IFactory(){};
+    virtual ~IFactory()
+    {
+    }
 
-    SPTR(std::istream) operator()(){ return this->get(); }
+    SPTR(std::istream) operator()()
+    {
+        return this->get();
+    }
 
 protected:
 
