@@ -1,19 +1,19 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWMEMORY_DARWINMEMORYMONITORTOOLS_HPP_
-#define _FWMEMORY_DARWINMEMORYMONITORTOOLS_HPP_
+#ifndef __FWMEMORY_TOOLS_DARWINMEMORYMONITORTOOLS_HPP__
+#define __FWMEMORY_TOOLS_DARWINMEMORYMONITORTOOLS_HPP__
 
 #ifdef __MACOSX__
 
-#include <boost/cstdint.hpp>
-#include <string>
-
 #include "fwMemory/config.hpp"
 
+#include <cstdint>
+#include <string>
+
 namespace fwMemory
 {
 namespace tools
@@ -29,11 +29,7 @@ public:
 
     FWMEMORY_API ~DarwinMemoryMonitorTools();
 
-
-
-    FWMEMORY_API static ::boost::uint64_t estimateFreeMem();
-
-
+    FWMEMORY_API static std::uint64_t estimateFreeMem();
 
     FWMEMORY_API static void printProcessMemoryInformation();
 
@@ -41,17 +37,13 @@ public:
 
     FWMEMORY_API static void printMemoryInformation();
 
+    FWMEMORY_API static std::uint64_t getTotalSystemMemory();
 
+    FWMEMORY_API static std::uint64_t getUsedSystemMemory();
 
-    FWMEMORY_API static ::boost::uint64_t getTotalSystemMemory();
+    FWMEMORY_API static std::uint64_t getFreeSystemMemory();
 
-    FWMEMORY_API static ::boost::uint64_t getUsedSystemMemory();
-
-    FWMEMORY_API static ::boost::uint64_t getFreeSystemMemory();
-
-
-
-    FWMEMORY_API static ::boost::uint64_t getUsedProcessMemory();
+    FWMEMORY_API static std::uint64_t getUsedProcessMemory();
 
 };
 
@@ -60,4 +52,4 @@ public:
 
 #endif
 
-#endif // _FWMEMORY_DARWINMEMORYMONITORTOOLS_HPP_
+#endif // __FWMEMORY_TOOLS_DARWINMEMORYMONITORTOOLS_HPP__
