@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMEMORY_UT_BUFFERMANAGER_HPP__
-#define __FWMEMORY_UT_BUFFERMANAGER_HPP__
+#ifndef __FWMEMORY_UT_BUFFERMANAGERTEST_HPP__
+#define __FWMEMORY_UT_BUFFERMANAGERTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,10 +16,10 @@ namespace ut
 
 class BufferManagerTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( BufferManagerTest );
-    CPPUNIT_TEST( allocateTest );
-    CPPUNIT_TEST( memoryInfoTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( BufferManagerTest );
+CPPUNIT_TEST( allocateTest );
+CPPUNIT_TEST( memoryInfoTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -33,4 +33,4 @@ public:
 } // namespace ut
 } // namespace fwMemory
 
-#endif //__FWMEMORY_UT_BUFFERMANAGER_HPP__
+#endif //__FWMEMORY_UT_BUFFERMANAGERTEST_HPP__
