@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMEMORY_UT_BUFFEROBJECT_HPP__
-#define __FWMEMORY_UT_BUFFEROBJECT_HPP__
+#ifndef __FWMEMORY_UT_BUFFEROBJECTTEST_HPP__
+#define __FWMEMORY_UT_BUFFEROBJECTTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,11 +16,11 @@ namespace ut
 
 class BufferObjectTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( BufferObjectTest );
-    CPPUNIT_TEST( allocateTest );
-    CPPUNIT_TEST( allocateZeroTest );
-    CPPUNIT_TEST( lockThreadedStressTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( BufferObjectTest );
+CPPUNIT_TEST( allocateTest );
+CPPUNIT_TEST( allocateZeroTest );
+CPPUNIT_TEST( lockThreadedStressTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -35,4 +35,4 @@ public:
 } // namespace ut
 } // namespace fwMemory
 
-#endif //__FWMEMORY_UT_BUFFEROBJECT_HPP__
+#endif //__FWMEMORY_UT_BUFFEROBJECTTEST_HPP__
