@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMEMORY_UT_BYTESIZE_HPP__
-#define __FWMEMORY_UT_BYTESIZE_HPP__
+#ifndef __FWMEMORY_UT_BYTESIZETEST_HPP__
+#define __FWMEMORY_UT_BYTESIZETEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,9 +16,9 @@ namespace ut
 
 class ByteSizeTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ByteSizeTest );
-    CPPUNIT_TEST( byteSizeTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( ByteSizeTest );
+CPPUNIT_TEST( byteSizeTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -31,5 +31,5 @@ public:
 } // namespace ut
 } // namespace fwMemory
 
-#endif //__FWMEMORY_UT_BYTESIZE_HPP__
+#endif //__FWMEMORY_UT_BYTESIZETEST_HPP__
 
