@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -10,10 +10,14 @@
 #include <fwMemory/BufferObject.hpp>
 #include <fwMemory/exception/Memory.hpp>
 
+#include <fwTest/helper/wait.hpp>
+
 #include <boost/thread/thread.hpp>
 
+#include <chrono>
 #include <functional>
 #include <limits>
+#include <thread>
 #include <type_traits>
 
 // Registers the fixture into the 'registry'
@@ -61,10 +65,14 @@ void BufferObjectTest::allocateTest()
     CPPUNIT_ASSERT_EQUAL( static_cast< ::fwMemory::BufferObject::SizeType>(SIZE), bo->getSize() );
     CPPUNIT_ASSERT( bo->lock().getBuffer() != NULL );
 
+    // We need to wait before checking that the buffer was unlocked because all buffer operations are done on a worker.
+    // The actual buffer ref count might still be owned (as a std::promise) by the worker task when we reach this point.
+    fwTestWaitMacro(bo->lockCount() == 0);
     CPPUNIT_ASSERT_EQUAL( static_cast<long>(0), bo->lockCount() );
 
     {
         ::fwMemory::BufferObject::Lock lock(bo->lock());
+        fwTestWaitMacro(bo->lockCount() == 1);
         CPPUNIT_ASSERT_EQUAL( static_cast<long>(1), bo->lockCount() );
         char* buf = static_cast<char*>(lock.getBuffer());
 
@@ -84,20 +92,26 @@ void BufferObjectTest::allocateTest()
         }
     }
 
+    fwTestWaitMacro(bo->lockCount() == 0);
     CPPUNIT_ASSERT_EQUAL( static_cast<long>(0), bo->lockCount() );
 
     {
         ::fwMemory::BufferObject::Lock lock(bo->lock());
+
+        fwTestWaitMacro(bo->lockCount() == 1);
         CPPUNIT_ASSERT_EQUAL( static_cast<long>(1), bo->lockCount() );
         ::fwMemory::BufferObject::Lock lock2(bo->lock());
+        fwTestWaitMacro(bo->lockCount() == 2);
         CPPUNIT_ASSERT_EQUAL( static_cast<long>(2), bo->lockCount() );
         ::fwMemory::BufferObject::csptr cbo = bo;
         ::fwMemory::BufferObject::ConstLock clock(cbo->lock());
+        fwTestWaitMacro(bo->lockCount() == 3);
         CPPUNIT_ASSERT_EQUAL( static_cast<long>(3), bo->lockCount() );
         CPPUNIT_ASSERT( isPointedValueConst( clock.getBuffer() ) );
         CPPUNIT_ASSERT( isPointedValueConst( cbo->lock().getBuffer() ) );
     }
 
+    fwTestWaitMacro(bo->lockCount() == 0);
     CPPUNIT_ASSERT_EQUAL( static_cast<long>(0), bo->lockCount() );
 
     bo->destroy();
@@ -194,6 +208,7 @@ void BufferObjectTest::allocateZeroTest()
     CPPUNIT_ASSERT_EQUAL( static_cast< ::fwMemory::BufferObject::SizeType>(SIZE), bo->getSize() );
     CPPUNIT_ASSERT( bo->lock().getBuffer() != NULL );
 
+    bo->destroy();
 }
 
 //------------------------------------------------------------------------------
@@ -209,6 +224,7 @@ void stressLock(::fwMemory::BufferObject::sptr bo, int nbLocks, int nbTest)
             m_locks.push_back(bo->lock());
         }
 
+        fwTestWaitMacro(bo->lockCount() >= 3);
         CPPUNIT_ASSERT( bo->lockCount() >= static_cast<long>(3) );
 
         m_locks.clear();
@@ -231,10 +247,10 @@ void BufferObjectTest::lockThreadedStressTest()
 
     group.join_all();
 
+    fwTestWaitMacro(bo->lockCount() == 0);
     CPPUNIT_ASSERT_EQUAL( static_cast<long>(0), bo->lockCount() );
 
 }
 
 } // namespace ut
 } // namespace fwMemory
-
