@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2014-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2014-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWPREFERENCES_IPREFERENCES_HPP__
-#define __FWPREFERENCES_IPREFERENCES_HPP__
+#pragma once
 
 #include "fwPreferences/config.hpp"
 
@@ -18,11 +17,11 @@ namespace fwPreferences
  * @brief Preferences service API.
  * This class represents the base interface for preferences services.
  */
-class PREFERENCES_CLASS_API IPreferences : public fwServices::IService
+class FWPREFERENCES_CLASS_API IPreferences : public fwServices::IService
 {
 
 public:
-    fwCoreServiceClassDefinitionsMacro ( (IPreferences)(::fwServices::IService) );
+    fwCoreServiceClassDefinitionsMacro( (IPreferences)(::fwServices::IService) );
 
     /// Constructor
     IPreferences() noexcept
@@ -36,7 +35,3 @@ public:
 };
 
 } // namespace fwPreferences
-
-#endif /*__FWPREFERENCES_IPREFERENCES_HPP__*/
-
-
