@@ -1,20 +1,20 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWRENDERNAMESPACE_HPP_
-#define FWRENDERNAMESPACE_HPP_
+#ifndef __FWRENDER_NAMESPACE_HPP__
+#define __FWRENDER_NAMESPACE_HPP__
 
 /**
  * @brief       The namespace fwRender contains the base interface for rendering services.
  * @namespace   fwRender
- * 
+ *
  * @date        2009-2010.
  *
  */
 namespace fwRender
 {
 }
-#endif /* FWRENDERNAMESPACE_HPP_ */
+#endif /* __FWRENDER_NAMESPACE_HPP__ */
