@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -11,7 +11,7 @@
 #include <fwRuntime/ConfigurationElement.hpp>
 #include <fwRuntime/operations.hpp>
 
-#include <fwServices/Base.hpp>
+#include <fwServices/macros.hpp>
 
 
 #include "fwRender/IRender.hpp"
@@ -21,13 +21,15 @@ namespace fwRender
 
 //-----------------------------------------------------------------------------
 
-IRender::IRender() throw()
-{}
+IRender::IRender() noexcept
+{
+}
 
 //-----------------------------------------------------------------------------
 
-IRender::~IRender() throw()
-{}
+IRender::~IRender() noexcept
+{
+}
 
 //-----------------------------------------------------------------------------
 
