@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_EMPTYPLUGIN_HPP_
-#define _FWRUNTIME_EMPTYPLUGIN_HPP_
+#ifndef __FWRUNTIME_EMPTYPLUGIN_HPP__
+#define __FWRUNTIME_EMPTYPLUGIN_HPP__
 
 
 #include "fwRuntime/config.hpp"
@@ -27,7 +27,7 @@ namespace fwRuntime
  *          it-self.
  *
  * @date    2004-2005
- * 
+ *
  */
 struct EmptyPlugin : public Plugin
 {
@@ -35,14 +35,16 @@ struct EmptyPlugin : public Plugin
     /**
      * @brief   Destructor : does nothing.
      */
-    virtual ~EmptyPlugin() throw() {}
+    virtual ~EmptyPlugin() noexcept
+    {
+    }
 
 
     // Overrides
-    virtual void start() throw(::fwRuntime::RuntimeException);
+    virtual void start();
 
     // Overrides
-    virtual void stop() throw();
+    virtual void stop() noexcept;
 
 };
 
@@ -50,4 +52,4 @@ struct EmptyPlugin : public Plugin
 } // namespace fwRuntime
 
 
-#endif //_FWRUNTIME_EMPTYPLUGIN_HPP_
+#endif //__FWRUNTIME_EMPTYPLUGIN_HPP__
