@@ -1,17 +1,16 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP_
-#define _FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP_
+#ifndef __FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP__
+#define __FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP__
 
-#include <boost/shared_ptr.hpp>
 
 #include "fwRuntime/config.hpp"
 
-
+#include <memory>
 
 namespace fwRuntime
 {
@@ -32,7 +31,7 @@ struct ExecutableFactory;
  * That's why this class is design to be instanciated as static object.
  *
  * @date    2004-2009
- * 
+ *
  */
 struct ExecutableFactoryRegistrar
 {
@@ -43,7 +42,7 @@ struct ExecutableFactoryRegistrar
      * @param[in]   factory a shared pointer to an executable factory instance to manage
      * @pre         Loading bundle exists.
      */
-    FWRUNTIME_API ExecutableFactoryRegistrar( ::boost::shared_ptr< ExecutableFactory > factory );
+    FWRUNTIME_API ExecutableFactoryRegistrar( std::shared_ptr< ExecutableFactory > factory );
 
 };
 
@@ -52,4 +51,4 @@ struct ExecutableFactoryRegistrar
 
 
 
-#endif //_FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP_
+#endif //__FWRUNTIME_EXECUTABLEFACTORYREGISTRAR_HPP__
