@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_PLUGIN_HPP
-#define _FWRUNTIME_PLUGIN_HPP
+#ifndef __FWRUNTIME_IPLUGIN_HPP__
+#define __FWRUNTIME_IPLUGIN_HPP__
 
 #include <string>
 
@@ -24,7 +24,7 @@ namespace fwRuntime
  * @brief   Defines the plugin interface.
  * @struct  IPlugin
  * @date    2004-2009
- * 
+ *
  */
 struct FWRUNTIME_CLASS_API IPlugin : public IExecutable
 {
@@ -37,22 +37,22 @@ struct FWRUNTIME_CLASS_API IPlugin : public IExecutable
     /**
      * @brief   Notifies the plugin about its start.
      */
-    virtual void start() throw(::fwRuntime::RuntimeException) = 0;
+    virtual void start() = 0;
 
     /**
      * @brief   Notifies the plugin about its initialisation.
      */
-    FWRUNTIME_API virtual void initialize() throw(::fwRuntime::RuntimeException);
+    FWRUNTIME_API virtual void initialize();
 
     /**
      * @brief   Notifies the plugin about its uninitialisation.
      */
-    FWRUNTIME_API virtual void uninitialize() throw(::fwRuntime::RuntimeException);
+    FWRUNTIME_API virtual void uninitialize();
 
     /**
      * @brief   Notifies the plugin about its stop.
      */
-    virtual void stop() throw() = 0;
+    virtual void stop() noexcept = 0;
 
 };
 
@@ -60,4 +60,4 @@ struct FWRUNTIME_CLASS_API IPlugin : public IExecutable
 
 } // namespace fwRuntime
 
-#endif // #define _FWRUNTIME_PLUGIN_HPP
+#endif // __FWRUNTIME_IPLUGIN_HPP__
