@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWRUNTIMEDLNAMESPACE_HPP_
-#define FWRUNTIMEDLNAMESPACE_HPP_
+#ifndef __FWRUNTIME_DL_NAMESPACE_HPP__
+#define __FWRUNTIME_DL_NAMESPACE_HPP__
 
 
 namespace fwRuntime
@@ -13,7 +13,7 @@ namespace fwRuntime
 /**
  * @brief       The namespace fwRuntime::dl contains classes to manage library module.
  * @namespace   fwRuntime::dl
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -22,4 +22,4 @@ namespace dl
 
 }
 }
-#endif /* FWRUNTIMEDLNAMESPACE_HPP_ */
+#endif /* __FWRUNTIME_DL_NAMESPACE_HPP__ */
