@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWRUNTIMEIONAMESPACE_HPP_
-#define FWRUNTIMEIONAMESPACE_HPP_
+#ifndef __FWRUNTIME_IO_NAMESPACE_HPP__
+#define __FWRUNTIME_IO_NAMESPACE_HPP__
 
 
 namespace fwRuntime
@@ -13,7 +13,7 @@ namespace fwRuntime
 /**
  * @brief       The namespace fwRuntime::io contains classes to read and perform profile file  .
  * @namespace   fwRuntime::io
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -22,4 +22,4 @@ namespace io
 
 }
 }
-#endif /* FWRUNTIMEIONAMESPACE_HPP_ */
+#endif /* __FWRUNTIME_IO_NAMESPACE_HPP__ */
