@@ -1,19 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWRUNTIME_PROFILE_STOPPER_HPP_
-#define _FWRUNTIME_PROFILE_STOPPER_HPP_
+#ifndef __FWRUNTIME_PROFILE_STOPPER_HPP__
+#define __FWRUNTIME_PROFILE_STOPPER_HPP__
+
+#include "fwRuntime/config.hpp"
+#include "fwRuntime/Version.hpp"
+
+#include <boost/utility.hpp>
 
 #include <string>
-#include <boost/utility.hpp>
-#include <boost/shared_ptr.hpp>
-
-#include "fwRuntime/profile/Starter.hpp"
-#include "fwRuntime/config.hpp"
-
 
 namespace fwRuntime
 {
@@ -21,13 +20,8 @@ namespace fwRuntime
 namespace profile
 {
 
-
-
 /**
  * @brief   Stops a given bundle.
- * @class  Stopper
- * @date    2007-2009
- * 
  */
 class Stopper :  public boost::noncopyable
 {
@@ -39,7 +33,7 @@ public:
      *
      * @param[in]   _identifier  a string containing a bundle identifier
      */
-    FWRUNTIME_API Stopper( const std::string   & _identifier );
+    FWRUNTIME_API Stopper( const std::string& _identifier, const Version& version = Version() );
 
     /**
      * @brief   Applies the Stopper on the system.
@@ -48,17 +42,14 @@ public:
      */
     void apply();
 
-private :
+private:
 
-    const std::string   m_identifier;   ///< a bundle identifier
+    const std::string m_identifier;     ///< the bundle identifier
+    const Version m_version;            ///< the bundle version
 };
 
-
-
 } // namespace profile
 
 } // namespace fwRuntime
 
-
-
-#endif /*_FWRUNTIME_PROFILE_STOPPER_HPP_*/
+#endif /*__FWRUNTIME_PROFILE_STOPPER_HPP__*/
