@@ -1,18 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWRUNTIMEUTILSNAMESPACE_HPP_
-#define FWRUNTIMEUTILSNAMESPACE_HPP_
+#ifndef __FWRUNTIME_UTILS_NAMESPACE_HPP__
+#define __FWRUNTIME_UTILS_NAMESPACE_HPP__
 
 namespace fwRuntime
 {
 /**
  * @brief       The namespace fwRuntime::utils contains template executable factory classes
  * @namespace   fwRuntime::utils
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -21,4 +21,4 @@ namespace utils
 
 }
 }
-#endif /* FWRUNTIMEUTILSNAMESPACE_HPP_ */
+#endif /* __FWRUNTIME_UTILS_NAMESPACE_HPP__ */
