@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -12,12 +12,14 @@ namespace fwRuntime
 {
 
 
-void EmptyPlugin::start() throw(::fwRuntime::RuntimeException)
-{}
+void EmptyPlugin::start()
+{
+}
 
 
-void EmptyPlugin::stop() throw()
-{}
+void EmptyPlugin::stop() noexcept
+{
+}
 
 
 } // namespace fwRuntime
