@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -16,13 +16,13 @@ namespace fwRuntime
 
 
 
-ExecutableFactoryRegistrar::ExecutableFactoryRegistrar( ::boost::shared_ptr< ExecutableFactory > factory )
+ExecutableFactoryRegistrar::ExecutableFactoryRegistrar( std::shared_ptr< ExecutableFactory > factory )
 {
     // Pre-condition
     SLM_ASSERT("No bundle bundle currently loaded", Bundle::getLoadingBundle() != 0 );
 
     // Retrieves the bundle that is currently loading.
-    ::boost::shared_ptr< Bundle >  loadingBundle( Bundle::getLoadingBundle() );
+    std::shared_ptr< Bundle >  loadingBundle( Bundle::getLoadingBundle() );
     Runtime* runtime( Runtime::getDefault() );
 
     // Stores the factory into that bundle and the default runtime instance.
