@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -14,14 +14,15 @@ namespace fwRuntime
 
 
 IPlugin::~IPlugin()
-{}
-
-
-void IPlugin::initialize() throw(::fwRuntime::RuntimeException)
 {
 }
 
-void IPlugin::uninitialize() throw(::fwRuntime::RuntimeException)
+
+void IPlugin::initialize()
+{
+}
+
+void IPlugin::uninitialize()
 {
 }
 
