@@ -1,10 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
 #include "fwRuntime/Plugin.hpp"
+
 #include "fwRuntime/ConfigurationElement.hpp"
 
 namespace fwRuntime
@@ -14,7 +15,7 @@ namespace fwRuntime
 
 std::shared_ptr<Bundle> Plugin::getBundle() const noexcept
 {
-    return m_bundle;
+    return m_bundle.lock();
 }
 
 //------------------------------------------------------------------------------
@@ -27,7 +28,7 @@ void Plugin::setInitializationData(const ConfigurationElement::sptr) noexcept
 
 void Plugin::setBundle( std::shared_ptr<Bundle> bundle) noexcept
 {
-    m_bundle = bundle;
+    m_bundle = std::weak_ptr<Bundle>(bundle);
 }
 
 //------------------------------------------------------------------------------
