@@ -1,25 +1,28 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <iostream>
-#include <sstream>
-#include <string>
-#include <boost/filesystem/operations.hpp>
-#include <boost/filesystem/path.hpp>
-#include <libxml/parser.h>
-#include <libxml/xinclude.h>
+#include "fwRuntime/io/BundleDescriptorReader.hpp"
 
 #include "fwRuntime/Bundle.hpp"
 #include "fwRuntime/ConfigurationElement.hpp"
+#include "fwRuntime/dl/Library.hpp"
 #include "fwRuntime/Extension.hpp"
 #include "fwRuntime/ExtensionPoint.hpp"
-#include "fwRuntime/dl/Library.hpp"
-#include "fwRuntime/io/BundleDescriptorReader.hpp"
 #include "fwRuntime/io/Validator.hpp"
+#include "fwRuntime/operations.hpp"
 
+#include <boost/filesystem/operations.hpp>
+#include <boost/filesystem/path.hpp>
+
+#include <libxml/parser.h>
+#include <libxml/xinclude.h>
+
+#include <iostream>
+#include <sstream>
+#include <string>
 namespace fwRuntime
 {
 
@@ -41,22 +44,24 @@ std::string BundleDescriptorReader::POINT("point");
 
 //------------------------------------------------------------------------------
 
-const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBundles(const ::boost::filesystem::path& location) throw(RuntimeException)
+const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBundles(
+    const ::boost::filesystem::path& location)
 {
     // Normalizes the path.
     ::boost::filesystem::path normalizedPath(location);
     normalizedPath.normalize();
 
     // Asserts that the repository is a valid directory path.
-    if(::boost::filesystem::exists(normalizedPath) == false || ::boost::filesystem::is_directory(normalizedPath) == false)
+    if(::boost::filesystem::exists(normalizedPath) == false ||
+       ::boost::filesystem::is_directory(normalizedPath) == false)
     {
         throw RuntimeException("'" + normalizedPath.string() + "': not a directory.");
     }
 
     // Walk through the repository entries.
     BundleContainer bundles;
-    ::boost::filesystem::directory_iterator   currentEntry(normalizedPath);
-    ::boost::filesystem::directory_iterator   endEntry;
+    ::boost::filesystem::directory_iterator currentEntry(normalizedPath);
+    ::boost::filesystem::directory_iterator endEntry;
     for(; currentEntry != endEntry; ++currentEntry)
     {
         ::boost::filesystem::path entryPath = *currentEntry;
@@ -75,6 +80,10 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
             {
                 OSLM_INFO( "'"<< entryPath.string() << "': skipped. " << runtimeException.what() );
             }
+            catch(const ::fwCore::Exception& exception)
+            {
+                OSLM_INFO( "'"<< entryPath.string() << "': skipped. " << exception.what() );
+            }
         }
     }
     return bundles;
@@ -82,119 +91,18 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
 
 //------------------------------------------------------------------------------
 
-::boost::shared_ptr<Bundle> BundleDescriptorReader::createBundle(const ::boost::filesystem::path& location) throw(RuntimeException)
+std::shared_ptr<Bundle> BundleDescriptorReader::createBundle(const ::boost::filesystem::path& location)
 {
-    ::boost::shared_ptr<Bundle> bundle;
-    // Get the descriptor location.
-    ::boost::filesystem::path completeLocation = location;
-
-    if(!completeLocation.is_complete())
-    {
-#ifdef SPECIALINSTALL
-	completeLocation = BUNDLEPATH / location;
-#else
-	completeLocation = ::boost::filesystem::current_path() / location;
-#endif
-    }
+    std::shared_ptr<Bundle> bundle;
 
     ::boost::filesystem::path descriptorLocation(location / "plugin.xml");
     if(::boost::filesystem::exists(descriptorLocation) == false)
     {
-        throw RuntimeException("'plugin.xml': file not found.");
+        throw ::fwCore::Exception(std::string("'plugin.xml': file not found in ") + location.string());
     }
 
     // Validation
-    std::ostringstream fileLocation;
-#ifdef SPECIALINSTALL
-	fileLocation << SHAREPATH << "fwRuntime_" <<  FWRUNTIME_VER << "/plugin.xsd";
-	const ::boost::filesystem::path pluginXSDLocation(fileLocation.str() );
-#else
-	fileLocation << "share/fwRuntime_" <<  FWRUNTIME_VER << "/plugin.xsd";
-	const ::boost::filesystem::path pluginXSDLocation(::boost::filesystem::current_path() / fileLocation.str() );
-#endif
-
-    Validator   validator(pluginXSDLocation);
-    if( validator.validate(descriptorLocation) == false )
-    {
-        throw RuntimeException("Invalid bundle descriptor file. " + validator.getErrorLog());
-    }
-
-    // Get the document.
-#if BOOST_FILESYSTEM_VERSION > 2
-    xmlDocPtr document = xmlParseFile(  descriptorLocation.string().c_str() );
-#else
-    xmlDocPtr document = xmlParseFile(  descriptorLocation.native_file_string().c_str() );
-#endif
-    if(document == 0)
-    {
-        throw RuntimeException("Unable to read the bundle descriptor file.");
-    }
-
-
-    try
-    {
-        // Get the root node.
-        xmlNodePtr rootNode = xmlDocGetRootElement(document);
-
-        if (xmlXIncludeProcessTreeFlags (rootNode, XML_PARSE_NOBASEFIX) == -1)
-        {
-            throw RuntimeException("Unable to manage xinclude !");
-        }
-
-        if(xmlStrcmp(rootNode->name, (const xmlChar*) PLUGIN.c_str()) != 0)
-        {
-            throw RuntimeException("Unexpected XML element");
-        }
-
-        // Creates and process the plugin element.
-        bundle = processPlugin(rootNode, completeLocation);
-
-        // Job's done!
-        xmlFreeDoc(document);
-
-    }
-    catch(std::exception& exception)
-    {
-        xmlFreeDoc(document);
-        throw ;
-    }
-    return bundle;
-}
-
-//-----------------------------------------------------------------------------
-
-::boost::shared_ptr<Bundle> BundleDescriptorReader::createBundleFromXmlPlugin( const ::boost::filesystem::path & location ) throw ( RuntimeException )
-{
-    ::boost::shared_ptr<Bundle> bundle;
-    // Get the descriptor location.
-    ::boost::filesystem::path tmpCompleteLocation = location;
-    if(!tmpCompleteLocation.is_complete())
-    {
-#ifdef SPECIALINSTALL
-	tmpCompleteLocation = BUNDLEPATH / location;
-#else
-	tmpCompleteLocation = ::boost::filesystem::current_path() / location;
-#endif
-    }
-    tmpCompleteLocation.normalize();
-
-    const ::boost::filesystem::path completeLocation ( tmpCompleteLocation.parent_path() );
-
-    ::boost::filesystem::path descriptorLocation ( tmpCompleteLocation );
-    if( ::boost::filesystem::exists(descriptorLocation) == false )
-    {
-        throw RuntimeException("'plugin.xml': file not found.");
-    }
-
-    // Validation
-    std::ostringstream fileLocation;
-#ifdef SPECIALINSTALL
-	fileLocation << SHAREPATH << "fwRuntime_" <<  FWRUNTIME_VER << "/plugin.xsd";
-	const ::boost::filesystem::path pluginXSDLocation(fileLocation.str() );
-#else
-	fileLocation << "share/fwRuntime_" <<  FWRUNTIME_VER << "/plugin.xsd";
-	const ::boost::filesystem::path pluginXSDLocation(::boost::filesystem::current_path() / fileLocation.str() );
-#endif
+    auto pluginXSDLocation = ::fwRuntime::getLibraryResourceFilePath("fwRuntime-" FWRUNTIME_VER "/plugin.xsd");
 
     Validator validator(pluginXSDLocation);
     if( validator.validate(descriptorLocation) == false )
@@ -203,11 +111,7 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
     }
 
     // Get the document.
-#if BOOST_FILESYSTEM_VERSION > 2
-    xmlDocPtr document = xmlParseFile(  descriptorLocation.string().c_str() );
-#else
-    xmlDocPtr document = xmlParseFile(  descriptorLocation.native_file_string().c_str() );
-#endif
+    xmlDocPtr document = xmlParseFile( descriptorLocation.string().c_str() );
     if(document == 0)
     {
         throw RuntimeException("Unable to read the bundle descriptor file.");
@@ -217,7 +121,8 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
     {
         // Get the root node.
         xmlNodePtr rootNode = xmlDocGetRootElement(document);
-        if (xmlXIncludeProcessTreeFlags (rootNode, XML_PARSE_NOBASEFIX) == -1)
+
+        if (xmlXIncludeProcessTreeFlags(rootNode, XML_PARSE_NOBASEFIX) == -1)
         {
             throw RuntimeException("Unable to manage xinclude !");
         }
@@ -228,6 +133,14 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
         }
 
         // Creates and process the plugin element.
+        // Get the descriptor location.
+        ::boost::filesystem::path completeLocation(location);
+
+        if(!completeLocation.is_complete())
+        {
+            completeLocation = ::fwRuntime::Runtime::getDefault()->getWorkingPath() / location;
+        }
+
         bundle = processPlugin(rootNode, completeLocation);
 
         // Job's done!
@@ -236,14 +149,16 @@ const BundleDescriptorReader::BundleContainer BundleDescriptorReader::createBund
     catch(std::exception& exception)
     {
         xmlFreeDoc(document);
-        throw ;
+        throw;
     }
     return bundle;
 }
 
 //-----------------------------------------------------------------------------
 
-ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(xmlNodePtr node, const ::boost::shared_ptr<Bundle> bundle) throw(RuntimeException)
+ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(xmlNodePtr node,
+                                                                               const std::shared_ptr<Bundle> bundle)
+
 {
     //xmlKeepBlanksDefault(0);
     // Creates the configuration element.
@@ -268,8 +183,9 @@ ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(x
         {
             std::string value((const char*) curChild->content);
             // Even whitespace (non XML_TEXT_NODE) are considered as valid XML_TEXT_NODE
-            OSLM_WARN_IF("Bundle : " << ( bundle ? bundle->getIdentifier() : "<None>" ) << ", node: " << name << ", blanks in xml nodes can result in unexpected behaviour. Consider using <![CDATA[ ... ]]>.",
-                    (value.find("\n")!=std::string::npos || value.find("\t")!=std::string::npos));
+            OSLM_WARN_IF(
+                "Bundle : " << ( bundle ? bundle->getIdentifier() : "<None>" ) << ", node: " << name << ", blanks in xml nodes can result in unexpected behaviour. Consider using <![CDATA[ ... ]]>.",
+                (value.find("\n") != std::string::npos || value.find("\t") != std::string::npos));
 
             configurationElement->setValue( configurationElement->getValue() + value );
             continue;
@@ -295,7 +211,8 @@ ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(x
 
 //------------------------------------------------------------------------------
 
-::boost::shared_ptr<Extension> BundleDescriptorReader::processExtension(xmlNodePtr node, const ::boost::shared_ptr<Bundle> bundle) throw(RuntimeException)
+std::shared_ptr<Extension> BundleDescriptorReader::processExtension(xmlNodePtr node,
+                                                                    const std::shared_ptr<Bundle> bundle)
 {
     // Processes all extension attributes.
     xmlAttrPtr curAttr;
@@ -317,7 +234,7 @@ ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(x
     }
 
     // Creates the extension instance.
-    ::boost::shared_ptr<Extension> extension(new Extension(bundle, identifier, point, node));
+    std::shared_ptr<Extension> extension(new Extension(bundle, identifier, point, node));
 
     // Processes child nodes which are configuration elements.
     xmlNodePtr curChild;
@@ -336,7 +253,8 @@ ConfigurationElement::sptr BundleDescriptorReader::processConfigurationElement(x
 
 //------------------------------------------------------------------------------
 
-BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processPoint(xmlNodePtr node, const ::boost::shared_ptr<Bundle> bundle) throw(RuntimeException)
+BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processPoint(xmlNodePtr node,
+                                                                                     const std::shared_ptr<Bundle> bundle)
 {
     // Creates the extension instance.
     xmlAttrPtr curAttr;
@@ -356,10 +274,10 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
             continue;
         }
     }
-    ::boost::shared_ptr<ExtensionPoint> extensionPoint(new ExtensionPoint(bundle, identifier, schema));
+    std::shared_ptr<ExtensionPoint> extensionPoint(new ExtensionPoint(bundle, identifier, schema));
 
     // Processes child nodes which declare identifier as extensions.
-    std::vector< ::boost::shared_ptr<Extension> > extensionContainer ;
+    std::vector< std::shared_ptr<Extension> > extensionContainer;
     xmlNodePtr curChild;
     for(curChild = node->children; curChild != 0; curChild = curChild->next)
     {
@@ -367,22 +285,24 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         {
             if( xmlStrcmp(curChild->name, (const xmlChar*) IMPLEMENTS.c_str()) == 0 )
             {
-                std::string extensionId =  (const char*) curChild->children->content ;
-                ::boost::shared_ptr<Extension> extension(new Extension(bundle, identifier , extensionId, curChild));
-                extensionContainer.push_back( extension ) ;
+                std::string extensionId = (const char*) curChild->children->content;
+                std::shared_ptr<Extension> extension(new Extension(bundle, identifier, extensionId, curChild));
+                extensionContainer.push_back( extension );
             }
         }
     }
 
-    return PointExtensionsPairType( extensionPoint, extensionContainer ) ;
+    return PointExtensionsPairType( extensionPoint, extensionContainer );
 }
 
 //------------------------------------------------------------------------------
 
-::boost::shared_ptr<ExtensionPoint> BundleDescriptorReader::processExtensionPoint(xmlNodePtr node, const ::boost::shared_ptr<Bundle> bundle) throw(RuntimeException)
+std::shared_ptr<ExtensionPoint> BundleDescriptorReader::processExtensionPoint(xmlNodePtr node,
+                                                                              const std::shared_ptr<Bundle> bundle)
+
 {
     // Processes all extension attributes.
-    xmlAttrPtr  curAttr;
+    xmlAttrPtr curAttr;
     std::string identifier;
     std::string schema;
     for(curAttr = node->properties; curAttr != 0; curAttr = curAttr->next)
@@ -400,7 +320,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         }
     }
     // Creates the extension instance.
-    ::boost::shared_ptr<ExtensionPoint> point(new ExtensionPoint(bundle, identifier, schema));
+    std::shared_ptr<ExtensionPoint> point(new ExtensionPoint(bundle, identifier, schema));
 
     // Job's done.
     return point;
@@ -408,7 +328,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
 
 //------------------------------------------------------------------------------
 
-::boost::shared_ptr<dl::Library> BundleDescriptorReader::processLibrary(xmlNodePtr node) throw(RuntimeException)
+std::shared_ptr<dl::Library> BundleDescriptorReader::processLibrary(xmlNodePtr node)
 {
     // Processes all plugin attributes.
     xmlAttrPtr curAttr;
@@ -423,18 +343,19 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
     }
 
     // Creates the library
-    ::boost::shared_ptr<dl::Library> library( new dl::Library(name) );
+    std::shared_ptr<dl::Library> library( new dl::Library(name) );
     return library;
 }
 
 //------------------------------------------------------------------------------
 
-::boost::shared_ptr<Bundle> BundleDescriptorReader::processPlugin(xmlNodePtr node, const ::boost::filesystem::path& location) throw(RuntimeException)
+std::shared_ptr<Bundle> BundleDescriptorReader::processPlugin(xmlNodePtr node,
+                                                              const ::boost::filesystem::path& location)
 {
     // Creates the bundle.
-    ::boost::shared_ptr<Bundle> bundle;
+    std::shared_ptr<Bundle> bundle;
     // Processes all plugin attributes.
-    xmlAttrPtr  curAttr;
+    xmlAttrPtr curAttr;
     std::string bundleIdentifier;
     std::string version;
     std::string pluginClass;
@@ -466,11 +387,11 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
     }
     if(pluginClass.empty() == true)
     {
-        bundle = ::boost::shared_ptr<Bundle>( new Bundle(location, bundleIdentifier, version) );
+        bundle = std::shared_ptr<Bundle>( new Bundle(location, bundleIdentifier, version) );
     }
     else
     {
-        bundle = ::boost::shared_ptr<Bundle>( new Bundle(location, bundleIdentifier, version, pluginClass) );
+        bundle = std::shared_ptr<Bundle>( new Bundle(location, bundleIdentifier, version, pluginClass) );
     }
 
     // Processes all child nodes.
@@ -486,7 +407,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         // Extension declaration.
         if(xmlStrcmp(curChild->name, (const xmlChar*) EXTENSION.c_str()) == 0)
         {
-            ::boost::shared_ptr<Extension> extension(processExtension(curChild, bundle));
+            std::shared_ptr<Extension> extension(processExtension(curChild, bundle));
             bundle->addExtension(extension);
             continue;
         }
@@ -494,7 +415,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         // Extension point declaration.
         if(xmlStrcmp(curChild->name, (const xmlChar*) EXTENSION_POINT.c_str()) == 0)
         {
-            ::boost::shared_ptr<ExtensionPoint> point(processExtensionPoint(curChild, bundle));
+            std::shared_ptr<ExtensionPoint> point(processExtensionPoint(curChild, bundle));
             bundle->addExtensionPoint(point);
             continue;
         }
@@ -502,7 +423,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         // Library declaration.
         if(xmlStrcmp(curChild->name, (const xmlChar*) LIBRARY.c_str()) == 0)
         {
-            ::boost::shared_ptr<dl::Library> library(processLibrary(curChild));
+            std::shared_ptr<dl::Library> library(processLibrary(curChild));
             bundle->addLibrary(library);
             continue;
         }
@@ -510,14 +431,14 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
         // Requirement declaration.
         if(xmlStrcmp(curChild->name, (const xmlChar*) REQUIREMENT.c_str()) == 0)
         {
-            const std::string   requirement(processRequirement(curChild));
+            const std::string requirement(processRequirement(curChild));
             bundle->addRequirement(requirement);
         }
 
         // Point declaration.
         if(xmlStrcmp(curChild->name, (const xmlChar*) POINT.c_str()) == 0)
         {
-            SLM_FATAL("Sorry, this xml element  ( <point ... > </point> ) is depreciated (" + location.string() + ")" );
+            SLM_FATAL("This xml element  ( <point ... > </point> ) is deprecated (" + location.string() + ")" );
         }
     }
 
@@ -527,7 +448,7 @@ BundleDescriptorReader::PointExtensionsPairType BundleDescriptorReader::processP
 
 //------------------------------------------------------------------------------
 
-const std::string BundleDescriptorReader::processRequirement(xmlNodePtr node) throw(RuntimeException)
+const std::string BundleDescriptorReader::processRequirement(xmlNodePtr node)
 {
     // Processes all requirement attributes.
     xmlAttrPtr curAttr;
