@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP_
-#define __FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP_
+#ifndef __FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP__
+#define __FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -19,9 +19,9 @@ namespace ut
  */
 class EConfigurationElementTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( EConfigurationElementTest );
-    CPPUNIT_TEST( testConfiguration );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( EConfigurationElementTest );
+CPPUNIT_TEST( testConfiguration );
+CPPUNIT_TEST_SUITE_END();
 
 protected:
 
@@ -36,4 +36,4 @@ public:
 } // namespace ut
 } // namespace fwTools
 
-#endif //__FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP_
+#endif //__FWRUNTIME_UT_ECONFIGURATIONELEMENTTEST_HPP__
