@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWSERVICES_ICONTROLLER_HPP_
-#define FWSERVICES_ICONTROLLER_HPP_
+#ifndef __FWSERVICES_ICONTROLLER_HPP__
+#define __FWSERVICES_ICONTROLLER_HPP__
 
 #include "fwServices/config.hpp"
 #include "fwServices/IService.hpp"
@@ -17,7 +17,7 @@ namespace fwServices
  * @brief   This interface defines control service API. Does nothing particularly, can be considered as a default service type to be implemented by unclassified services.
  *
  * @class   IController
- * 
+ *
  * @date    2007-2009.
  */
 class FWSERVICES_CLASS_API IController : public ::fwServices::IService
@@ -25,7 +25,7 @@ class FWSERVICES_CLASS_API IController : public ::fwServices::IService
 
 public:
 
-    fwCoreServiceClassDefinitionsMacro ( (IController)(::fwServices::IService) ) ;
+    fwCoreServiceClassDefinitionsMacro ( (IController)(::fwServices::IService) );
 
 protected:
 
@@ -39,4 +39,4 @@ protected:
 
 }
 
-#endif // FWSERVICES_ICONTROLLER_HPP_
+#endif // __FWSERVICES_ICONTROLLER_HPP__
