@@ -1,18 +1,18 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWSERVICESREGISTRYNAMESPACE_HPP_
-#define FWSERVICESREGISTRYNAMESPACE_HPP_
+#ifndef __FWSERVICES_REGISTRY_NAMESPACE_HPP__
+#define __FWSERVICES_REGISTRY_NAMESPACE_HPP__
 
 namespace fwServices
 {
 /**
  * @brief       The namespace fwServices::registry contains class to manage services, object and config.
  * @namespace   fwServices::registry
- * 
+ *
  * @date        2009-2010.
  *
  */
@@ -21,4 +21,4 @@ namespace registry
 
 }
 }
-#endif /* FWSERVICESREGISTRYNAMESPACE_HPP_ */
+#endif /* __FWSERVICES_REGISTRY_NAMESPACE_HPP__ */
