@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSERVICES_REGISTRY_OBJECTSERVICE_HPP__
-#define __FWSERVICES_REGISTRY_OBJECTSERVICE_HPP__
+#pragma once
 
 #include "fwServices/config.hpp"
 #include "fwServices/IService.hpp"
@@ -195,8 +194,9 @@ public:
      * @param access Access (INPUT, INOUT, OUTPUT) of this key
      * @param service Service where to look for the key
      */
-    ::fwData::Object::csptr getRegistered(const ::fwServices::IService::KeyType& objKey,
-                                          ::fwServices::IService::AccessType access, IService::sptr service) const;
+    FWSERVICES_API ::fwData::Object::csptr getRegistered(const ::fwServices::IService::KeyType& objKey,
+                                                         ::fwServices::IService::AccessType access,
+                                                         IService::sptr service) const;
     //@}
 
     /**
@@ -214,6 +214,7 @@ public:
 
     /**
      * @brief Return a container with all services of type SERVICE associated to obj in m_container
+     * @deprecated This method will be removed in 20.0
      */
     template<class SERVICE>
     std::set< SPTR(SERVICE) > getServices(::fwData::Object::sptr obj) const;
@@ -228,13 +229,13 @@ public:
 
     /**
      * @brief Return a container of services of type serviceType which are attached to obj
-     *
+     * @deprecated This method will be removed in 20.0
      */
     FWSERVICES_API ServiceVectorType getServices( ::fwData::Object::sptr obj, const std::string& serviceType ) const;
 
     /**
      * @brief return a vector containing all services associated with the object obj
-     *
+     * @deprecated This method will be removed in 20.0
      */
     FWSERVICES_API ServiceVectorType getServices( ::fwData::Object::sptr obj ) const;
 
@@ -274,7 +275,7 @@ public:
 
     /**
      * @brief Move service (service) to object objDst in the m_container
-     *
+     * @deprecated Use service->swapKey(key, object)
      */
     FWSERVICES_API void swapService( ::fwData::Object::sptr objDst, ::fwServices::IService::sptr service );
 
@@ -376,6 +377,7 @@ FWSERVICES_API ::fwServices::registry::ObjectService::ServiceVectorType getServi
  *
  * @param obj Object to add to the OSR
  * @param srvType Type of the service
+ * @deprecated This method is deprecated
  */
 FWSERVICES_API bool has( ::fwData::Object::sptr obj, const std::string& srvType);
 
@@ -393,6 +395,9 @@ FWSERVICES_API void registerService( ::fwServices::IService::sptr service );
  *
  * @param object Object to register
  * @param service Service whose key should be added
+ * @deprecated Use the new API:
+ *      registerService(::fwData::Object::sptr obj, const ::fwServices::IService::KeyType& objKey,
+ *                      ::fwServices::IService::AccessType access, ::fwServices::IService::sptr service)
  */
 FWSERVICES_API void registerService( ::fwData::Object::sptr obj, ::fwServices::IService::sptr service );
 
@@ -433,6 +438,7 @@ FWSERVICES_API void registerServiceOutput(::fwData::Object::sptr obj, const ::fw
 
 /**
  * @brief Wraps ObjectService::swapService
+ * @deprecated
  */
 FWSERVICES_API void swapService( ::fwData::Object::sptr objDst, ::fwServices::IService::sptr service );
 
@@ -493,6 +499,3 @@ FWSERVICES_API SPTR( ::fwServices::registry::ObjectService::RegisterSignalType )
 } // namespace fwServices
 
 #include "fwServices/registry/ObjectService.hxx"
-
-#endif // __FWSERVICES_REGISTRY_OBJECTSERVICE_HPP__
-
