@@ -100,6 +100,8 @@ void IService::setOutput(const IService::KeyType& key, const fwData::Object::spt
 
 ::fwData::Object::sptr IService::getObject()
 {
+    FW_DEPRECATED("getObject()", "getInput() or getInOut()", "20.0");
+
     // Handle compatibility with new behavior
     if(m_associatedObject.expired())
     {
@@ -115,7 +117,7 @@ void IService::setOutput(const IService::KeyType& key, const fwData::Object::spt
         }
         else if(!m_outputsMap.empty())
         {
-            return m_outputsMap.begin()->second.lock();
+            return m_outputsMap.begin()->second;
         }
         else
         {
@@ -159,10 +161,18 @@ void IService::registerInOut(const ::fwData::Object::sptr& obj, const std::strin
 
 //-----------------------------------------------------------------------------
 
+bool IService::hasObjectId(const KeyType& _key) const
+{
+    auto it = m_idsMap.find(_key);
+    return (it != m_idsMap.end());
+}
+
+//-----------------------------------------------------------------------------
+
 IService::IdType IService::getObjectId(const IService::KeyType& _key) const
 {
     auto it = m_idsMap.find(_key);
-    SLM_ASSERT("Object key '" + _key + "' not found in service " + this->getID() + ".", it != m_idsMap.end());
+    FW_RAISE_IF("Object key '" + _key + "' not found in service " + this->getID() + ".", it == m_idsMap.end());
     return it->second;
 }
 
@@ -640,8 +650,12 @@ IService::SharedFutureType IService::updateSlot()
 
 IService::SharedFutureType IService::internalUpdate(bool _async)
 {
-    OSLM_ASSERT("INVOKING update WHILE STOPPED ("<<m_globalState<<") on service '" << this->getID() <<
-                "' of type '" << this->getClassname() << "'", m_globalState == STARTED );
+    if(m_globalState != STARTED)
+    {
+        OSLM_WARN("INVOKING update WHILE STOPPED ("<<m_globalState<<") on service '" << this->getID() <<
+                  "' of type '" << this->getClassname() << "': update is discarded." );
+        return SharedFutureType();
+    }
     OSLM_ASSERT("INVOKING update WHILE NOT IDLE ("<<m_updatingState<<") on service '" << this->getID() <<
                 "' of type '" << this->getClassname() << "'", m_updatingState == NOTUPDATING );
 
@@ -693,7 +707,16 @@ void IService::connectToConfig()
 
             ::fwCom::SignalBase::sptr sig = this->signal(signalCfg.second);
             SLM_ASSERT("Signal '" + signalCfg.second + "' not found in source '" + signalCfg.first + "'.", sig);
-            proxy->connect(proxyCfg.second.m_channel, sig);
+            try
+            {
+                proxy->connect(proxyCfg.second.m_channel, sig);
+
+            }
+            catch (const std::exception& e)
+            {
+                SLM_ERROR("Signal '" + signalCfg.second + "' from '" + signalCfg.first + "' can not be connected to the"
+                          " channel '" + proxyCfg.second.m_channel + "': " + std::string(e.what()));
+            }
         }
 
         for(const auto& slotCfg : proxyCfg.second.m_slots)
@@ -702,7 +725,16 @@ void IService::connectToConfig()
 
             ::fwCom::SlotBase::sptr slot = this->slot(slotCfg.second);
             SLM_ASSERT("Slot '" + slotCfg.second + "' not found in source '" + slotCfg.first + "'.", slot);
-            proxy->connect(proxyCfg.second.m_channel, slot);
+
+            try
+            {
+                proxy->connect(proxyCfg.second.m_channel, slot);
+            }
+            catch (const std::exception& e)
+            {
+                SLM_ERROR("Slot '" + slotCfg.second + "' from '" + slotCfg.first + "' can not be connected to the "
+                          "channel '" + proxyCfg.second.m_channel + "': " + std::string(e.what()));
+            }
         }
     }
 }
@@ -713,6 +745,10 @@ void IService::autoConnect()
 {
     ::fwServices::IService::KeyConnectionsMap connectionMap = this->getAutoConnections();
 
+    SLM_ERROR_IF("The service '" + this->getID() + "'(" + this->getClassname() +
+                 ") is set to 'autoConnect=\"yes\"' but is has no object to connect",
+                 m_serviceConfig.m_globalAutoConnect && m_serviceConfig.m_objects.empty());
+
     // For compatibility with V1, we allow services to connect explicitly with the default object
     // For these services we will ignore all auto connections with any other data
     // This is intended notably for managers-like services
@@ -746,6 +782,9 @@ void IService::autoConnect()
                         }
                     }
                 }
+                SLM_ERROR_IF("Object '" + objectCfg.m_key + "' of '" + this->getID() + "'(" + this->getClassname() +
+                             ") is set to 'autoConnect=\"yes\"' but there is no connection available.",
+                             connections.empty() && objectCfg.m_autoConnect);
             }
             else
             {
@@ -753,6 +792,7 @@ void IService::autoConnect()
                 // This also allows to get the default connection with the s_UPDATE_SLOT. When we remove this
                 // function, we will have to implement this behavior with getAutoConnections()
                 connections = this->getObjSrvConnections();
+                FW_DEPRECATED_IF("getObjSrvConnections()", "getAutoConnections()", "20.0", !connections.empty());
             }
 
             ::fwData::Object::csptr obj;
@@ -783,7 +823,7 @@ void IService::autoConnect()
                     auto itObj = m_outputsMap.find(objectCfg.m_key);
                     if(itObj != m_outputsMap.end())
                     {
-                        obj = itObj->second.lock();
+                        obj = itObj->second;
                     }
                     break;
                 }
@@ -834,14 +874,31 @@ void IService::disconnectFromConfig()
             SLM_ASSERT("Invalid signal source", signalCfg.first == this->getID());
 
             ::fwCom::SignalBase::sptr sig = this->signal(signalCfg.second);
-            proxy->disconnect(proxyCfg.second.m_channel, sig);
+
+            try
+            {
+                proxy->disconnect(proxyCfg.second.m_channel, sig);
+            }
+            catch (const std::exception& e)
+            {
+                SLM_ERROR("Signal '" + signalCfg.second + "' from '" + signalCfg.first + "' can not be disconnected "
+                          "from the channel '" + proxyCfg.second.m_channel + "': " + std::string(e.what()));
+            }
         }
         for(const auto& slotCfg : proxyCfg.second.m_slots)
         {
             SLM_ASSERT("Invalid slot destination", slotCfg.first == this->getID());
 
             ::fwCom::SlotBase::sptr slot = this->slot(slotCfg.second);
-            proxy->disconnect(proxyCfg.second.m_channel, slot);
+            try
+            {
+                proxy->disconnect(proxyCfg.second.m_channel, slot);
+            }
+            catch (const std::exception& e)
+            {
+                SLM_ERROR("Slot '" + slotCfg.second + "' from '" + slotCfg.first + "' can not be disconnected from the "
+                          "channel '" + proxyCfg.second.m_channel + "': " + std::string(e.what()));
+            }
         }
     }
 }
