@@ -1,16 +1,17 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSERVICES_UT_OBJECTSERVICETEST_HPP__
-#define __FWSERVICES_UT_OBJECTSERVICETEST_HPP__
+#pragma once
 
 #include <fwData/Object.hpp>
+
 #include <fwRuntime/EConfigurationElement.hpp>
 
 #include <cppunit/extensions/HelperMacros.h>
+
 #include <condition_variable>
 #include <mutex>
 
@@ -31,13 +32,14 @@ CPPUNIT_TEST( registerKeyTest );
 CPPUNIT_TEST( registerConnectionTest );
 CPPUNIT_TEST_SUITE_END();
 
-
 public:
     // interface
     void setUp();
     void tearDown();
 
+    // @deprecated should be removed in 20.0
     void swapTest();
+    // @deprecated should be removed in 20.0
     void registerTest();
     void registerKeyTest();
     void registerConnectionTest();
@@ -56,5 +58,3 @@ private:
 
 } //namespace ut
 } //namespace fwServices
-
-#endif //__FWSERVICES_UT_OBJECTSERVICETEST_HPP__
