@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWSERVICES_TEST_TU_PROXYTEST_HPP_
-#define _FWSERVICES_TEST_TU_PROXYTEST_HPP_
+#ifndef __FWSERVICES_UT_PROXYTEST_HPP__
+#define __FWSERVICES_UT_PROXYTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -17,9 +17,9 @@ namespace ut
 /// Test ActiveWorkers API
 class ProxyTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ProxyTest );
-    CPPUNIT_TEST( basicTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( ProxyTest );
+CPPUNIT_TEST( basicTest );
+CPPUNIT_TEST_SUITE_END();
 
 
 public:
@@ -35,4 +35,4 @@ public:
 } //namespace ut
 } //namespace fwServices
 
-#endif // _FWSERVICES_TEST_TU_PROXYTEST_HPP_
+#endif // __FWSERVICES_UT_PROXYTEST_HPP__
