@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2016.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWSERVICES_TEST_TU_SIGSLOTCONNECTIONTEST_HPP_
-#define _FWSERVICES_TEST_TU_SIGSLOTCONNECTIONTEST_HPP_
+#ifndef __FWSERVICES_UT_SIGSLOTCONNECTIONTEST_HPP__
+#define __FWSERVICES_UT_SIGSLOTCONNECTIONTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -16,9 +16,9 @@ namespace ut
 
 class SigSlotConnectionTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( SigSlotConnectionTest );
-    CPPUNIT_TEST( basicTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( SigSlotConnectionTest );
+CPPUNIT_TEST( basicTest );
+CPPUNIT_TEST_SUITE_END();
 
 
 public:
@@ -32,4 +32,4 @@ public:
 } //namespace ut
 } //namespace fwServices
 
-#endif // _FWSERVICES_TEST_TU_SIGSLOTCONNECTIONTEST_HPP_
+#endif // __FWSERVICES_UT_SIGSLOTCONNECTIONTEST_HPP__
