@@ -12,8 +12,6 @@
 #include <fwRuntime/Bundle.hpp>
 #include <fwRuntime/Runtime.hpp>
 
-#include <fwTest/helper/Thread.hpp>
-
 #include <boost/filesystem/operations.hpp>
 #include <boost/filesystem/path.hpp>
 
@@ -86,23 +84,19 @@ void AppConfigParametersTest::appConfigParametersTest()
 
 void AppConfigParametersTest::concurentAccessToAppConfigParametersTest()
 {
-    const unsigned int nbThreads = 20;
-    std::vector< SPTR(::fwTest::helper::Thread) > threads;
-    for (int i = 0; i < nbThreads; ++i)
+    const auto fn = std::bind(&AppConfigParametersTest::appConfigParametersTest, this);
+    std::vector< std::future<void> > futures;
+    for (unsigned int i = 0; i < 20; ++i)
     {
-        SPTR(::fwTest::helper::Thread) thread;
-        thread = std::shared_ptr< ::fwTest::helper::Thread >(
-            new ::fwTest::helper::Thread(std::bind(&AppConfigParametersTest::appConfigParametersTest, this)));
-        threads.push_back(thread);
+        futures.push_back( std::async(std::launch::async, fn) );
     }
 
-    for (int i = 0; i < nbThreads; ++i)
+    for (auto& future : futures)
     {
-        std::stringstream str;
-        str << "thread " << i;
-        CPPUNIT_ASSERT_MESSAGE(str.str(), threads[i]->timedJoin(1000));
+        const auto status = future.wait_for(std::chrono::seconds(1));
+        CPPUNIT_ASSERT(status == std::future_status::ready);
+        future.get(); // Trigger exceptions
     }
-
 }
 
 //------------------------------------------------------------------------------
