@@ -13,6 +13,7 @@
 #include <fwServices/registry/ActiveWorkers.hpp>
 
 #include <fwCom/helper/SigSlotConnection.hpp>
+#include <fwCom/Slots.hxx>
 
 #include <fwCore/TimeStamp.hpp>
 
@@ -24,6 +25,8 @@
 #include <fwRuntime/EConfigurationElement.hpp>
 #include <fwRuntime/helper.hpp>
 
+#include <fwTest/helper/wait.hpp>
+
 #include <fwThread/Worker.hpp>
 
 #include <thread>
@@ -56,6 +59,7 @@ void ServiceTest::tearDown()
 
 void ServiceTest::testServiceCreation()
 {
+    FW_DEPRECATED_MSG("Deprecated test", "20.0");
     ::fwData::Integer::sptr obj = ::fwData::Integer::New();
     ::fwServices::IService::sptr service;
 
@@ -63,7 +67,7 @@ void ServiceTest::testServiceCreation()
     CPPUNIT_ASSERT( ::fwServices::registry::ServiceFactory::getDefault()->support(obj->getClassname(),
                                                                                   "::fwServices::ut::TestService") );
 
-    // Test adding service
+    // deprecated: Test adding service
     ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation");
     CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
 
@@ -81,50 +85,52 @@ void ServiceTest::testServiceCreation()
 
 void ServiceTest::testServiceCreationWithMultipleData()
 {
+    const std::string dataKey = "data";
     ::fwData::Integer::sptr obj = ::fwData::Integer::New();
-    ::fwServices::IService::sptr service;
 
     // Test if the object support the service
     CPPUNIT_ASSERT( ::fwServices::registry::ServiceFactory::getDefault()->support(obj->getClassname(),
                                                                                   "::fwServices::ut::TestService") );
 
     // Test adding service
-    ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation");
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
+    ::fwServices::IService::sptr srv = ::fwServices::add("::fwServices::ut::TestServiceImplementation");
+    srv->registerInOut(obj, dataKey);
+    CPPUNIT_ASSERT(::fwServices::OSR::isRegistered(dataKey, ::fwServices::IService::AccessType::INOUT, srv));
+    CPPUNIT_ASSERT(obj == ::fwServices::OSR::getRegistered(dataKey, ::fwServices::IService::AccessType::INOUT, srv));
 
-    // Test getting the service its object
-    service = ::fwServices::get(obj, "::fwServices::ut::TestService");
-    CPPUNIT_ASSERT(service);
-    CPPUNIT_ASSERT_EQUAL(obj, service->getObject< ::fwData::Integer >());
+    // Test getting the service object
+    CPPUNIT_ASSERT_EQUAL(srv, srv);
+    CPPUNIT_ASSERT_EQUAL(obj, srv->getInOut< ::fwData::Integer >(dataKey));
 
     // Test erasing service
-    ::fwServices::OSR::unregisterService(service);
-    CPPUNIT_ASSERT( ::fwServices::OSR::has(obj, "::fwServices::ut::TestService") == false );
+    ::fwServices::OSR::unregisterService(srv);
+    CPPUNIT_ASSERT_EQUAL(false,
+                         ::fwServices::OSR::isRegistered(dataKey, ::fwServices::IService::AccessType::INOUT, srv));
 }
 
 //------------------------------------------------------------------------------
 
 void ServiceTest::testServiceCreationWithTemplateMethods()
 {
+    const std::string dataKey = "data";
     ::fwData::Integer::sptr obj = ::fwData::Integer::New();
-    ::fwServices::ut::TestService::sptr service;
 
     // Test if the object support the service
     CPPUNIT_ASSERT( ::fwServices::registry::ServiceFactory::getDefault()->support(obj->getClassname(),
                                                                                   "::fwServices::ut::TestService") );
 
     // Test adding service
-    ::fwServices::add< ::fwServices::ut::TestService >(obj, "::fwServices::ut::TestServiceImplementation");
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
+    ::fwServices::ut::TestService::sptr srv =
+        ::fwServices::add< ::fwServices::ut::TestService > ("::fwServices::ut::TestServiceImplementation");
+    srv->registerInOut(obj, dataKey);
+    CPPUNIT_ASSERT(::fwServices::OSR::isRegistered(dataKey, ::fwServices::IService::AccessType::INOUT, srv));
+    CPPUNIT_ASSERT(obj == ::fwServices::OSR::getRegistered(dataKey, ::fwServices::IService::AccessType::INOUT, srv));
 
     // Test getting the service its object
-    service = ::fwServices::get< ::fwServices::ut::TestService >(obj);
-    CPPUNIT_ASSERT(service);
-    CPPUNIT_ASSERT_EQUAL(obj, service->getObject< ::fwData::Integer >());
+    CPPUNIT_ASSERT_EQUAL(obj, srv->getInOut< ::fwData::Integer >(dataKey));
 
     // Test erasing service
-    ::fwServices::OSR::unregisterService(service);
-    CPPUNIT_ASSERT( ::fwServices::OSR::has(obj, "::fwServices::ut::TestService") == false );
+    ::fwServices::OSR::unregisterService(srv);
 }
 
 //------------------------------------------------------------------------------
@@ -134,6 +140,7 @@ void ServiceTest::testServiceCreationWithUUID()
     const std::string myUUID  = "myUUID";
     const std::string myUUID2 = "myUUID2";
     const std::string myUUID3 = "myUUID3";
+    const std::string dataKey = "data";
     size_t nbServices         = 0;
 
     ::fwData::Integer::sptr obj = ::fwData::Integer::New();
@@ -145,27 +152,30 @@ void ServiceTest::testServiceCreationWithUUID()
                                                                                   "::fwServices::ut::TestService") );
 
     // Test adding service
-    service = ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation",
-                                myUUID);
-    ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation", myUUID2);
+    service = ::fwServices::add("::fwServices::ut::TestServiceImplementation", myUUID);
+    CPPUNIT_ASSERT(service);
+    service->registerInOut(obj, dataKey);
+
+    service2 = ::fwServices::add("::fwServices::ut::TestServiceImplementation", myUUID2);
+    CPPUNIT_ASSERT(service2);
+    service2->registerInOut(obj, dataKey);
+
     nbServices = 2;
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
     CPPUNIT_ASSERT(::fwTools::fwID::exist(myUUID) );
     CPPUNIT_ASSERT(::fwTools::fwID::exist(myUUID2));
 
     // Test getting the service its object
-    service2 = ::fwServices::get(myUUID2);
-    CPPUNIT_ASSERT(service);
-    CPPUNIT_ASSERT(service2);
-    CPPUNIT_ASSERT_EQUAL(obj, service2->getObject< ::fwData::Integer >());
-    CPPUNIT_ASSERT_EQUAL(myUUID2, service2->getID());
+    ::fwServices::IService::sptr service2bis = ::fwServices::get(myUUID2);
+    CPPUNIT_ASSERT(service2bis);
+    CPPUNIT_ASSERT_EQUAL(obj, service2bis->getInOut< ::fwData::Integer >(dataKey));
+    CPPUNIT_ASSERT_EQUAL(myUUID2, service2bis->getID());
     CPPUNIT_ASSERT( !::fwTools::fwID::exist(myUUID3) );
-    CPPUNIT_ASSERT_EQUAL( nbServices, ::fwServices::OSR::getServices(obj, "::fwServices::ut::TestService").size() );
+    CPPUNIT_ASSERT_EQUAL( nbServices, ::fwServices::OSR::getServices("::fwServices::ut::TestService").size() );
 
     // Test erasing service
     ::fwServices::OSR::unregisterService(service);
     nbServices--;
-    CPPUNIT_ASSERT_EQUAL( nbServices, ::fwServices::OSR::getServices(obj, "::fwServices::ut::TestService").size() );
+    CPPUNIT_ASSERT_EQUAL( nbServices, ::fwServices::OSR::getServices("::fwServices::ut::TestService").size() );
     ::fwServices::OSR::unregisterService(service2);
 }
 
@@ -181,11 +191,7 @@ void ServiceTest::testStartStopUpdate()
     // Add service
     CPPUNIT_ASSERT( ::fwServices::registry::ServiceFactory::getDefault()->support(obj->getClassname(),
                                                                                   "::fwServices::ut::TestService") );
-    ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation", myUUID);
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
-
-    // Get service
-    service = ::fwServices::ut::TestService::dynamicCast( ::fwServices::get(myUUID) );
+    service = ::fwServices::add< ::fwServices::ut::TestService >("::fwServices::ut::TestServiceImplementation", myUUID);
     CPPUNIT_ASSERT(service);
 
     // Service must be stop when it is created
@@ -208,7 +214,6 @@ void ServiceTest::testStartStopUpdate()
 
     // Erase Service
     ::fwServices::OSR::unregisterService(service);
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") == false );
 }
 
 //------------------------------------------------------------------------------
@@ -282,16 +287,6 @@ TestServiceSignals::~TestServiceSignals()
 {
 }
 
-// Wait at worst 1s for a given condition
-#define WAIT(cond) \
-    ::fwCore::TimeStamp BOOST_PP_CAT(timeStamp, __LINE__); \
-    BOOST_PP_CAT(timeStamp, __LINE__).setLifePeriod(1000); \
-    BOOST_PP_CAT(timeStamp, __LINE__).modified(); \
-    while(!(cond) && !BOOST_PP_CAT(timeStamp, __LINE__).periodExpired()) \
-    { \
-        std::this_thread::sleep_for( std::chrono::milliseconds(10)); \
-    }
-
 //------------------------------------------------------------------------------
 
 void ServiceTest::testCommunication()
@@ -300,6 +295,7 @@ void ServiceTest::testCommunication()
     activeWorkers->initRegistry();
 
     const std::string EVENT        = "EVENT";
+    const std::string dataKey      = "data";
     const std::string service1UUID = "service1UUID";
     const std::string service2UUID = "service2UUID";
 
@@ -308,18 +304,15 @@ void ServiceTest::testCommunication()
     ::fwServices::ut::TestService::sptr service2;
 
     // Add services
-    CPPUNIT_ASSERT( ::fwServices::registry::ServiceFactory::getDefault()->support(obj->getClassname(),
-                                                                                  "::fwServices::ut::TestService") );
-    ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation",
-                      service1UUID);
-    CPPUNIT_ASSERT(::fwServices::OSR::has(obj, "::fwServices::ut::TestService") );
+    ::fwServices::add("::fwServices::ut::TestServiceImplementation", service1UUID);
     service1 = ::fwServices::ut::TestService::dynamicCast( ::fwServices::get(service1UUID) );
     CPPUNIT_ASSERT(service1);
+    service1->registerInput(obj, dataKey, true);
 
-    ::fwServices::add(obj, "::fwServices::ut::TestService", "::fwServices::ut::TestServiceImplementation",
-                      service2UUID);
-    service2 = ::fwServices::ut::TestService::dynamicCast( ::fwServices::get(service2UUID) );
+    service2 = ::fwServices::add< ::fwServices::ut::TestService >("::fwServices::ut::TestServiceImplementation",
+                                                                  service2UUID);
     CPPUNIT_ASSERT(service2);
+    service2->registerInput(obj, dataKey, true);
 
     // Object used to check service signals
     TestServiceSignals::sptr receiver1 = std::make_shared< TestServiceSignals>();
@@ -348,7 +341,7 @@ void ServiceTest::testCommunication()
     CPPUNIT_ASSERT(service1->isStarted());
     CPPUNIT_ASSERT(service2->isStarted());
 
-    WAIT(receiver1->m_started && receiver2->m_started)
+    fwTestWaitMacro(receiver1->m_started && receiver2->m_started)
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_started);
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_updated);
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_stopped);
@@ -357,8 +350,6 @@ void ServiceTest::testCommunication()
     CPPUNIT_ASSERT_EQUAL(false, receiver2->m_stopped);
 
     // Register communication channel
-    comHelper.connect( obj, service1, service1->getObjSrvConnections() );
-    comHelper.connect( obj, service2, service2->getObjSrvConnections() );
     comHelper.connect( service1, ::fwServices::ut::TestServiceImplementation::s_MSG_SENT_SIG,
                        service2, ::fwServices::ut::TestServiceImplementation::s_UPDATE2_SLOT );
 
@@ -379,7 +370,7 @@ void ServiceTest::testCommunication()
     service2->update().wait();
     CPPUNIT_ASSERT(service2->getIsUpdated2());
 
-    WAIT(receiver1->m_updated && receiver2->m_updated)
+    fwTestWaitMacro(receiver1->m_updated && receiver2->m_updated)
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_started);
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_updated);
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_stopped);
@@ -391,7 +382,7 @@ void ServiceTest::testCommunication()
     service1->stop().wait();
     service2->stop().wait();
 
-    WAIT(receiver1->m_stopped && receiver2->m_stopped)
+    fwTestWaitMacro(receiver1->m_stopped && receiver2->m_stopped)
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_started);
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_updated);
     CPPUNIT_ASSERT_EQUAL(true, receiver1->m_stopped);
@@ -505,5 +496,48 @@ void ServiceTest::startStopUpdateExceptions(TestService::sptr _service)
 
 //------------------------------------------------------------------------------
 
+void ServiceTest::testWithInAndOut()
+{
+    ::fwData::Integer::sptr obj          = ::fwData::Integer::New(18);
+    ::fwServices::IService::sptr service = ::fwServices::add("::fwServices::ut::TestServiceWithData");
+
+    CPPUNIT_ASSERT(service);
+    service->registerInput(obj, ::fwServices::ut::TestServiceWithData::s_INPUT);
+
+    service->start();
+    CPPUNIT_ASSERT(service->isStarted());
+    CPPUNIT_ASSERT_EQUAL(true, ::fwServices::OSR::isRegistered(::fwServices::ut::TestServiceWithData::s_INPUT,
+                                                               ::fwServices::IService::AccessType::INPUT, service));
+    service->update();
+    CPPUNIT_ASSERT_EQUAL(true, ::fwServices::OSR::isRegistered(::fwServices::ut::TestServiceWithData::s_OUTPUT,
+                                                               ::fwServices::IService::AccessType::OUTPUT, service));
+    ::fwData::Object::csptr output =
+        ::fwServices::OSR::getRegistered(::fwServices::ut::TestServiceWithData::s_OUTPUT,
+                                         ::fwServices::IService::AccessType::OUTPUT, service);
+    CPPUNIT_ASSERT(output);
+    ::fwData::Integer::csptr outInteger = ::fwData::Integer::dynamicCast(output);
+    CPPUNIT_ASSERT(outInteger);
+
+    CPPUNIT_ASSERT_EQUAL(obj->value(), outInteger->value());
+
+    ::fwData::Integer::csptr outInteger2 = service->getOutput< ::fwData::Integer >(
+        ::fwServices::ut::TestServiceWithData::s_OUTPUT);
+    CPPUNIT_ASSERT(outInteger2);
+
+    CPPUNIT_ASSERT_EQUAL(obj->value(), outInteger2->value());
+
+    service->stop();
+
+    ::fwData::Integer::csptr nullInteger = service->getOutput< ::fwData::Integer >(
+        ::fwServices::ut::TestServiceWithData::s_OUTPUT);
+    CPPUNIT_ASSERT(nullptr == nullInteger);
+
+    CPPUNIT_ASSERT_EQUAL(false, ::fwServices::OSR::isRegistered(::fwServices::ut::TestServiceWithData::s_OUTPUT,
+                                                                ::fwServices::IService::AccessType::OUTPUT, service));
+    ::fwServices::OSR::unregisterService(service);
+}
+
+//------------------------------------------------------------------------------
+
 } //namespace ut
 } //namespace fwServices
