@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,23 +7,19 @@
 #ifndef __FWTHREAD_TASKHANDLER_HPP__
 #define __FWTHREAD_TASKHANDLER_HPP__
 
-#include <boost/thread/future.hpp>
+#include <future>
 
 namespace fwThread
 {
 
 /**
- * @class   TaskHandler
  * @brief   This class encapsulates packaged task and provides a copy constructor.
- *
- * 
- * @date   2012.
  */
 template <typename R>
 struct TaskHandler
 {
     /// Constructor, moves task.
-    TaskHandler(::boost::packaged_task<R>& task);
+    TaskHandler(std::packaged_task<R>& task);
 
     /// Copy constructor, moves task.
     TaskHandler(const TaskHandler& that);
@@ -31,19 +27,21 @@ struct TaskHandler
     /// Executes intern packaged task.
     void operator ()() const;
 
-protected:
+    protected:
 
-    /// Copy constructor forbidden.
-    TaskHandler& operator=( const TaskHandler& ){};
+        /// Copy constructor forbidden.
+        TaskHandler& operator=( const TaskHandler& )
+        {
+        }
 
-private:
-    /// Encapsulated packaged task.
-    mutable ::boost::packaged_task<R> m_task;
+    private:
+        /// Encapsulated packaged task.
+        mutable std::packaged_task<R> m_task;
 };
 
 /// Encapsulate a packaged_task into a boost function to be easily posted on a worker.
 template <typename R>
-inline ::boost::function< void() > moveTaskIntoFunction(::boost::packaged_task<R>& task);
+inline std::function< void() > moveTaskIntoFunction(std::packaged_task<R>& task);
 
 } //namespace fwThread
 
