@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWTOOLS_EXCEPTION_HPP_
-#define _FWTOOLS_EXCEPTION_HPP_
+#ifndef __FWTOOLS_EXCEPTION_HPP__
+#define __FWTOOLS_EXCEPTION_HPP__
 
 #include <exception>
 #include <string>
@@ -19,7 +19,7 @@ namespace fwTools
 /**
  * @brief   Implements fwTools exception class
  * @class   Exception
- * 
+ *
  * @date    2007-2009.
  */
 struct FWTOOLS_CLASS_API Exception : public ::fwCore::Exception
@@ -30,17 +30,17 @@ struct FWTOOLS_CLASS_API Exception : public ::fwCore::Exception
      *
      * @param[in]   message a string containing the failure message
      */
-    FWTOOLS_API Exception(const std::string &message) throw();
+    FWTOOLS_API Exception(const std::string &message) noexcept;
 
     /**
      * @brief   Destructor : do nothing.
      */
-    FWTOOLS_API ~Exception() throw();
+    FWTOOLS_API ~Exception() noexcept;
 
 
 };
 
 } // namespace fwTools
 
-#endif // _FWTOOLS_EXCEPTION_HPP_
+#endif // __FWTOOLS_EXCEPTION_HPP__
 
