@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWTOOLS_FAILED_HPP_
-#define _FWTOOLS_FAILED_HPP_
+#ifndef __FWTOOLS_FAILED_HPP__
+#define __FWTOOLS_FAILED_HPP__
 
 #include <exception>
 #include <string>
@@ -19,7 +19,7 @@ namespace fwTools
 /**
  * @brief   Implements a failed exception class
  * @class   Failed
- * 
+ *
  * @date    2007-2009.
  */
 struct FWTOOLS_CLASS_API Failed : public ::fwCore::Exception
@@ -30,16 +30,16 @@ struct FWTOOLS_CLASS_API Failed : public ::fwCore::Exception
      *
      * @param[in]   message a string containing the failure message
      */
-    FWTOOLS_API Failed(const std::string &message) throw();
+    FWTOOLS_API Failed(const std::string &message) noexcept;
 
     /**
      * @brief   Destructor : do nothing.
      */
-    FWTOOLS_API ~Failed() throw();
+    FWTOOLS_API ~Failed() noexcept;
 
 
 };
 
 } // namespace fwTools
 
-#endif // _FWTOOLS_FAILED_HPP_
+#endif // __FWTOOLS_FAILED_HPP__
