@@ -1,20 +1,20 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef FWTOOLSNAMESPACE_HPP_
-#define FWTOOLSNAMESPACE_HPP_
+#ifndef __FWTOOLS_NAMESPACE_HPP__
+#define __FWTOOLS_NAMESPACE_HPP__
 
 /**
  * @brief       The namespace fwTools contains several tools like UUID, factory, dispatche, stringizer, macros, helper.
  * @namespace   fwTools
- * 
+ *
  * @date        2009-2010.
  *
  */
 namespace fwTools
 {
 }
-#endif /* FWTOOLSNAMESPACE_HPP_ */
+#endif /* __FWTOOLS_NAMESPACE_HPP__ */
