@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -9,14 +9,16 @@
 namespace fwTools
 {
 
-Failed::Failed(const std::string &message) throw()
-: ::fwCore::Exception(message)
-{}
+Failed::Failed(const std::string &message) noexcept
+    : ::fwCore::Exception(message)
+{
+}
 
 
-Failed::~Failed() throw()
-{}
+Failed::~Failed() noexcept
+{
+}
+
 
 
-    
 } // namespace fwTools
