@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWTOOLS_UT_FWIDTEST_HPP__
-#define __FWTOOLS_UT_FWIDTEST_HPP__
+#pragma once
 
 #include <fwTools/Object.hpp>
 
@@ -20,8 +19,7 @@ class FwIDTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE( FwIDTest );
 CPPUNIT_TEST( objectFwIDTest );
-CPPUNIT_TEST( conccurentAccessOnFwIDMapTest );
-CPPUNIT_TEST( conccurentAccessOnSameObjFwIDTest );
+CPPUNIT_TEST( concurrentAccessOnFwIDMapTest );
 CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -31,17 +29,11 @@ public:
 
     void objectFwIDTest();
 
-    void conccurentAccessOnFwIDMapTest();
-    void conccurentAccessOnSameObjFwIDTest();
+    void concurrentAccessOnFwIDMapTest();
 
 private:
     void runFwIDCreation();
-    void runAccessToObjectFwID();
-
-    ::fwTools::Object::sptr m_object;
 };
 
 } // namespace ut
 } // namespace fwTools
-
-#endif //__FWTOOLS_UT_FWIDTEST_HPP__
