@@ -1,14 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <fwCore/base.hpp>
+#include "MacrosTest.hpp"
 
 #include <fwTools/Object.hpp>
 
-#include "MacrosTest.hpp"
+#include <fwCore/base.hpp>
 
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION( ::fwTools::ut::MacrosTest );
@@ -22,36 +22,49 @@ class ClassTest
 {
 
 public:
-    fwCoreClassDefinitionsWithFactoryMacro((ClassTest), (()) ( ((int)) ), new ClassTest);
+    fwCoreClassFactoryMacro((ClassTest), (())( ((int)) ), new ClassTest);
 
-    int getNum() { return m_num; }
+    //------------------------------------------------------------------------------
 
-protected:
-    ClassTest()
-    : m_num(1)
-    {}
+    int getNum()
+    {
+        return m_num;
+    }
 
-    ClassTest(int num)
-    : m_num(num)
-    {}
+    ClassTest() :
+        m_num(1)
+    {
+    }
+
+    ClassTest(int num) :
+        m_num(num)
+    {
+    }
 
     virtual ~ClassTest()
-    {}
+    {
+    }
 
 private:
     int m_num;
 };
 
+//------------------------------------------------------------------------------
+
 void MacrosTest::setUp()
 {
     // Set up context before running a test.
 }
 
+//------------------------------------------------------------------------------
+
 void MacrosTest::tearDown()
 {
     // Clean up after the test run.
 }
 
+//------------------------------------------------------------------------------
+
 void MacrosTest::factoryMacroTest()
 {
     const int NUM = 15;
