@@ -1,32 +1,34 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWZIP_READARCHIVE_HPP__
-#define __FWZIP_READARCHIVE_HPP__
-
-#include <istream>
-#include <boost/filesystem/path.hpp>
+#ifndef __FWZIP_IREADARCHIVE_HPP__
+#define __FWZIP_IREADARCHIVE_HPP__
 
 #include <fwCore/macros.hpp>
 
+#include <boost/filesystem/path.hpp>
+
+#include <istream>
+
 namespace fwZip
 {
 
 /**
  * @brief   This interface defines functions to read a file in an archive.
- * @class   IReadArchive
  */
 class IReadArchive
 {
 
 public:
 
-    fwCoreNonInstanciableClassDefinitionsMacro((IReadArchive));
+    fwCoreBaseClassDefinitionsMacro((IReadArchive))
 
-    virtual ~IReadArchive(){};
+    virtual ~IReadArchive()
+    {
+    }
 
     /**
      * @brief Returns input stream for the file in current archive.
@@ -40,11 +42,10 @@ public:
      */
     virtual const ::boost::filesystem::path getArchivePath() const = 0;
 
-    virtual IReadArchive::sptr clone() const = 0 ;
+    virtual IReadArchive::sptr clone() const = 0;
 };
 
 }
 
-
-#endif /* __FWZIP_READARCHIVE_HPP__ */
+#endif /* __FWZIP_IREADARCHIVE_HPP__ */
 
