@@ -1,27 +1,28 @@
 /* ***** BEGIN LICENSE BLOCK *****
-* FW4SPL - Copyright (C) IRCAD, 2009-2014.
-* Distributed under the terms of the GNU Lesser General Public License (LGPL) as
-* published by the Free Software Foundation.
-* ****** END LICENSE BLOCK ****** */
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
+ * published by the Free Software Foundation.
+ * ****** END LICENSE BLOCK ****** */
 
 #ifndef __FWATOMSBOOSTIO_WRITER_HPP__
 #define __FWATOMSBOOSTIO_WRITER_HPP__
 
 #include <sstream>
 
-#include <fwCore/macros.hpp>
 #include <boost/filesystem/path.hpp>
 
+#include <fwCore/macros.hpp>
+
 #include "fwAtomsBoostIO/types.hpp"
 #include "fwAtomsBoostIO/config.hpp"
 
 namespace fwAtoms
 {
-    class Base;
+class Base;
 }
 namespace fwZip
 {
-    class IWriteArchive;
+class IWriteArchive;
 }
 
 namespace fwAtomsBoostIO
@@ -41,9 +42,11 @@ public:
     /// Defines key to retrieve writer version from file.
     FWATOMSBOOSTIO_API static const std::string s_WRITER_VERSION_KEY;
 
-    Writer( SPTR(::fwAtoms::Base) atom ) : m_atom(atom) {}
+    Writer(const SPTR(::fwAtoms::Base)& atom) : m_atom(atom)
+    {
+    }
 
-    FWATOMSBOOSTIO_API void write( SPTR(::fwZip::IWriteArchive) archive,
+    FWATOMSBOOSTIO_API void write( const SPTR(::fwZip::IWriteArchive)& archive,
                                    const ::boost::filesystem::path& rootFilename = "root.json",
                                    FormatType format = JSON ) const;
 
