@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2016.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -24,6 +24,7 @@
 #include <dcmtk/config/osconfig.h>
 #include <dcmtk/dcmdata/dcdeftag.h>
 #include <dcmtk/dcmdata/dcfilefo.h>
+#include <dcmtk/dcmdata/dcistrmb.h>
 #include <dcmtk/dcmimgle/dcmimage.h>
 #include <dcmtk/dcmnet/diutil.h>
 
@@ -46,13 +47,13 @@ ImageStorageReader::~ImageStorageReader()
 
 //-----------------------------------------------------------------------------
 
-::fwMedData::Series::sptr ImageStorageReader::read(::fwMedData::DicomSeries::sptr series)
+::fwMedData::Series::sptr ImageStorageReader::read(const ::fwMedData::DicomSeries::csptr& series)
 {
     ::fwMedData::DicomSeries::SOPClassUIDContainerType sopClassUIDContainer = series->getSOPClassUIDs();
     std::string sopClassUID = dcmFindNameOfUID(sopClassUIDContainer.begin()->c_str());
 
     ::fwMedData::ImageSeries::sptr imageSeries = ::fwDicomTools::Series::convertToImageSeries(series);
-    DicomPathContainerType instances = series->getLocalDicomPaths();
+    DicomContainerType instances = series->getDicomContainer();
 
     ::fwData::Image::sptr image = ::fwData::Image::New();
     DcmFileFormat fileFormat;
@@ -60,19 +61,39 @@ ImageStorageReader::~ImageStorageReader()
     DcmDataset* dataset;
 
     //Get informations from the first instance
-    std::string firstInstance = instances.begin()->second.string();
-    status = fileFormat.loadFile(firstInstance.c_str());
-    DicomImage dicomImage(firstInstance.c_str());
+    const auto firstItem                           = series->getDicomContainer().begin();
+    const ::fwMemory::BufferObject::sptr bufferObj = firstItem->second;
+    const size_t buffSize                          = bufferObj->getSize();
+    const std::string dicomPath                    = bufferObj->getStreamInfo().fsFile.string();
+    ::fwMemory::BufferObject::Lock lock(bufferObj);
+    char* buffer = static_cast< char* >( lock.getBuffer() );
 
-    FW_RAISE_IF("Unable to read the file: \""+firstInstance+"\"", status.bad() || (
+    DcmInputBufferStream is;
+    is.setBuffer(buffer, offile_off_t(buffSize));
+    is.setEos();
+
+    fileFormat.transferInit();
+    if (!fileFormat.read(is).good())
+    {
+        FW_RAISE("Unable to read Dicom file '"<< dicomPath <<"' "<<
+                 "(slice: '" << firstItem->first << "')");
+    }
+
+    fileFormat.loadAllDataIntoMemory();
+    fileFormat.transferEnd();
+
+    dataset = fileFormat.getDataset();
+
+    DicomImage dicomImage(dataset, dataset->getOriginalXfer());
+
+    FW_RAISE_IF("Unable to read the file: \""+dicomPath+"\"", status.bad() || (
                     dicomImage.getStatus() != EIS_Normal
                     && dicomImage.getStatus() != EIS_MissingAttribute
                     && dicomImage.getStatus() != EIS_NotSupportedValue
                     ));
-    dataset = fileFormat.getDataset();
 
     // Decompress data set if compressed
-    dataset->chooseRepresentation(EXS_LittleEndianExplicit, NULL);
+    dataset->chooseRepresentation(EXS_LittleEndianExplicit, nullptr);
 
     if(dicomImage.getStatus() != EIS_MissingAttribute)
     {
@@ -81,9 +102,9 @@ ImageStorageReader::~ImageStorageReader()
 
     //Spacing
     double spacing[3];
-    dataset->findAndGetFloat64(DCM_PixelSpacing,spacing[0],0);
-    dataset->findAndGetFloat64(DCM_PixelSpacing,spacing[1],1);
-    dataset->findAndGetFloat64(DCM_SliceThickness,spacing[2]);
+    dataset->findAndGetFloat64(DCM_PixelSpacing, spacing[0], 0);
+    dataset->findAndGetFloat64(DCM_PixelSpacing, spacing[1], 1);
+    dataset->findAndGetFloat64(DCM_SliceThickness, spacing[2]);
 
     if(series->hasComputedValues("SliceThickness"))
     {
@@ -96,7 +117,6 @@ ImageStorageReader::~ImageStorageReader()
         OSLM_WARN("Invalid value for pixel spacing. Assuming pixel value is 1.");
     }
 
-
     image->setSpacing(std::vector< double >(spacing, spacing+3));
 
     //Origin
@@ -109,8 +129,8 @@ ImageStorageReader::~ImageStorageReader()
 
     //Size
     unsigned short rows, columns;
-    dataset->findAndGetUint16(DCM_Rows,rows);
-    dataset->findAndGetUint16(DCM_Columns,columns);
+    dataset->findAndGetUint16(DCM_Rows, rows);
+    dataset->findAndGetUint16(DCM_Columns, columns);
 
     uint32_t depth;
     if(instances.size() == 1)
@@ -136,12 +156,12 @@ ImageStorageReader::~ImageStorageReader()
 
     //Window Center
     double windowCenter = 0;
-    dataset->findAndGetFloat64(DCM_WindowCenter,windowCenter);
+    dataset->findAndGetFloat64(DCM_WindowCenter, windowCenter);
     image->setWindowCenter(windowCenter);
 
     //Window Width
     double windowWidth = 0;
-    dataset->findAndGetFloat64(DCM_WindowWidth,windowWidth);
+    dataset->findAndGetFloat64(DCM_WindowWidth, windowWidth);
     image->setWindowWidth(windowWidth);
 
     //Number of components
@@ -169,15 +189,15 @@ ImageStorageReader::~ImageStorageReader()
     }
     else
     {
-        FW_RAISE ( "The photometric interpretation \"" << photometricInterpretation << "\" is not supported.");
+        FW_RAISE( "The photometric interpretation \"" << photometricInterpretation << "\" is not supported.");
     }
 
     //Rescale Slope
     double rescaleSlope;
     double rescaleIntercept;
-    status           = dataset->findAndGetFloat64(DCM_RescaleSlope,rescaleSlope);
+    status           = dataset->findAndGetFloat64(DCM_RescaleSlope, rescaleSlope);
     rescaleSlope     = (status.bad()) ? 1 : rescaleSlope;
-    status           = dataset->findAndGetFloat64(DCM_RescaleIntercept,rescaleIntercept);
+    status           = dataset->findAndGetFloat64(DCM_RescaleIntercept, rescaleIntercept);
     rescaleIntercept = (status.bad()) ? 0 : rescaleIntercept;
 
     //Type
@@ -187,11 +207,11 @@ ImageStorageReader::~ImageStorageReader()
     unsigned short highBit             = 7;
     unsigned short pixelRepresentation = 0;
 
-    dataset->findAndGetUint16(DCM_SamplesPerPixel,samplesPerPixel);
-    dataset->findAndGetUint16(DCM_BitsAllocated,bitsAllocated);
-    dataset->findAndGetUint16(DCM_BitsStored,bitsStored);
-    dataset->findAndGetUint16(DCM_HighBit,highBit);
-    dataset->findAndGetUint16(DCM_PixelRepresentation,pixelRepresentation);
+    dataset->findAndGetUint16(DCM_SamplesPerPixel, samplesPerPixel);
+    dataset->findAndGetUint16(DCM_BitsAllocated, bitsAllocated);
+    dataset->findAndGetUint16(DCM_BitsStored, bitsStored);
+    dataset->findAndGetUint16(DCM_HighBit, highBit);
+    dataset->findAndGetUint16(DCM_PixelRepresentation, pixelRepresentation);
 
     //Using lookup tables
     if(photometricInterpretation == "COLOR" || photometricInterpretation == "PALETTE COLOR")
@@ -204,13 +224,12 @@ ImageStorageReader::~ImageStorageReader()
 
     //Find image type
     ::fwDicomTools::Image imageHelper(
-        samplesPerPixel,bitsAllocated,bitsStored, highBit, pixelRepresentation, rescaleSlope, rescaleIntercept);
+        samplesPerPixel, bitsAllocated, bitsStored, highBit, pixelRepresentation, rescaleSlope, rescaleIntercept);
     ::fwTools::Type imageType = imageHelper.findImageTypeFromMinMaxValues();
 
     //Set image type
     image->setType(imageType);
 
-
     //Direct reading mode
     if(::fwMemory::BufferManager::getDefault()->getLoadingMode() == ::fwMemory::BufferManager::DIRECT)
     {
@@ -255,10 +274,13 @@ ImageStorageReader::~ImageStorageReader()
 
 //-----------------------------------------------------------------------------
 
-void ImageStorageReader::directRead(::fwData::Image::sptr image, DicomPathContainerType instances,
-                                    unsigned short rows, unsigned short columns, int depth, double rescaleSlope,
+void ImageStorageReader::directRead(const ::fwData::Image::sptr& image,
+                                    DicomContainerType instances,
+                                    unsigned short rows, unsigned short columns,
+                                    int depth, double rescaleSlope,
                                     double rescaleIntercept,
-                                    unsigned short pixelRepresentation, ::fwTools::Type imageType)
+                                    unsigned short pixelRepresentation,
+                                    ::fwTools::Type imageType)
 {
     //Allocate image
     image->allocate();
@@ -273,10 +295,11 @@ void ImageStorageReader::directRead(::fwData::Image::sptr image, DicomPathContai
 
 //-----------------------------------------------------------------------------
 
-void ImageStorageReader::directRGBLookupRead(::fwData::Image::sptr image, DcmDataset& dataset,
-                                             DicomPathContainerType instances, unsigned short rows,
-                                             unsigned short columns, int depth,
-                                             unsigned short bitsAllocated)
+void ImageStorageReader::directRGBLookupRead(const ::fwData::Image::sptr& image,
+                                             DcmDataset& dataset,
+                                             DicomContainerType instances,
+                                             unsigned short rows, unsigned short columns,
+                                             int depth, unsigned short bitsAllocated)
 {
     //Allocate image
     image->allocate();
@@ -284,7 +307,7 @@ void ImageStorageReader::directRGBLookupRead(::fwData::Image::sptr image, DcmDat
     ::fwDataTools::helper::Array arrayHelper(array);
 
     unsigned short pixelValueBitsAllocated = 8;
-    dataset.findAndGetUint16(DCM_BitsAllocated,pixelValueBitsAllocated);
+    dataset.findAndGetUint16(DCM_BitsAllocated, pixelValueBitsAllocated);
 
     // 16 bits allocated
     if(bitsAllocated == 16)
@@ -313,7 +336,6 @@ void ImageStorageReader::directRGBLookupRead(::fwData::Image::sptr image, DcmDat
                                                                                                  arrayHelper.getBuffer(), redLookup, greenLookup,
                                                                                                  blueLookup);
         }
-
     }
     // 8 bits allocated
     else
@@ -343,15 +365,17 @@ void ImageStorageReader::directRGBLookupRead(::fwData::Image::sptr image, DcmDat
                                                                                                 blueLookup);
         }
     }
-
 }
 
 //-----------------------------------------------------------------------------
 
-void ImageStorageReader::lazyRead(::fwData::Image::sptr image, ::fwMedData::DicomSeries::sptr series,
-                                  unsigned short rows, unsigned short columns, int depth, double rescaleSlope,
+void ImageStorageReader::lazyRead(const ::fwData::Image::sptr& image,
+                                  const ::fwMedData::DicomSeries::csptr& series,
+                                  unsigned short rows, unsigned short columns,
+                                  int depth, double rescaleSlope,
                                   double rescaleIntercept,
-                                  unsigned short pixelRepresentation, ::fwTools::Type imageType)
+                                  unsigned short pixelRepresentation,
+                                  ::fwTools::Type imageType)
 {
     // Create information object
     ::fwDcmtkIO::reader::main::ImageLazyInformation::sptr dcmInfo =
@@ -374,13 +398,16 @@ void ImageStorageReader::lazyRead(::fwData::Image::sptr image, ::fwMedData::Dico
 
 //-----------------------------------------------------------------------------
 
-void ImageStorageReader::lazyRGBLookupRead(::fwData::Image::sptr image, ::fwMedData::DicomSeries::sptr series,
-                                           DcmDataset& dataset, DicomPathContainerType instances, unsigned short rows,
-                                           unsigned short columns, int depth,
-                                           unsigned short bitsAllocated, ::fwTools::Type imageType)
+void ImageStorageReader::lazyRGBLookupRead(const ::fwData::Image::sptr& image,
+                                           const ::fwMedData::DicomSeries::csptr& series,
+                                           DcmDataset& dataset,
+                                           DicomContainerType instances,
+                                           unsigned short rows, unsigned short columns,
+                                           int depth, unsigned short bitsAllocated,
+                                           ::fwTools::Type imageType)
 {
     unsigned short pixelValueBitsAllocated = 8;
-    dataset.findAndGetUint16(DCM_BitsAllocated,pixelValueBitsAllocated);
+    dataset.findAndGetUint16(DCM_BitsAllocated, pixelValueBitsAllocated);
 
     // Create information object
     ::fwDcmtkIO::reader::rgblookup::ImageRGBLookupLazyInformation::sptr dcmInfo =
