@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -262,7 +262,7 @@ void DicomAnonymizer::anonymizationProcess(const ::boost::filesystem::path& dirP
         ::boost::filesystem::ifstream inStream(file, std::ios::binary);
 
         std::stringstream ss;
-        ss << "im" << std::setfill('0') << std::setw(5) << fileIndex++;
+        ss << std::setfill('0') << std::setw(7) << fileIndex++;
 
         ::boost::filesystem::ofstream outStream(dirPath / ss.str(), std::ios::binary | std::ios::trunc);
 
@@ -559,7 +559,7 @@ void DicomAnonymizer::generateDummyValue(const ::gdcm::Tag& tag)
         }
         case ::gdcm::VR::CS:
         {
-            //Patient’s Sex
+            // Patient's sex
             if(tag == ::gdcm::Tag(0x0010, 0x0040))
             {
                 m_anonymizer.Replace(tag, "O");
@@ -748,4 +748,3 @@ SPTR(::fwJobs::IJob) DicomAnonymizer::getJob() const
 
 } // namespace helper
 } // namespace fwGdcmIO
-
