@@ -1,22 +1,21 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWITKIO_IMAGEREADER_HPP_
-#define _FWITKIO_IMAGEREADER_HPP_
-
-#include <boost/filesystem/path.hpp>
-
-#include <fwDataIO/reader/GenericObjectReader.hpp>
-#include <fwData/location/SingleFile.hpp>
-#include <fwData/Image.hpp>
-
-#include <fwTools/ProgressAdviser.hpp>
+#ifndef __FWITKIO_IMAGEREADER_HPP__
+#define __FWITKIO_IMAGEREADER_HPP__
 
 #include "fwItkIO/config.hpp"
 
+#include <fwData/Image.hpp>
+#include <fwData/location/SingleFile.hpp>
+
+#include <fwDataIO/reader/GenericObjectReader.hpp>
+
+#include <fwTools/ProgressAdviser.hpp>
+
 namespace fwItkIO
 {
 
@@ -25,11 +24,11 @@ class ImageReader : public ::fwDataIO::reader::GenericObjectReader< ::fwData::Im
                     public ::fwTools::ProgressAdviser
 {
 
-public :
+public:
 
     fwCoreClassDefinitionsWithFactoryMacro((ImageReader)(::fwDataIO::reader::GenericObjectReader< ::fwData::Image>),
-                                            (()),
-                                            ::fwDataIO::reader::factory::New< ImageReader >
+                                           (()),
+                                           ::fwDataIO::reader::factory::New< ImageReader >
                                            );
     fwCoreAllowSharedFromThis();
 
@@ -37,9 +36,9 @@ public :
 
     FWITKIO_API ~ImageReader();
 
-    FWITKIO_API void read();
+    FWITKIO_API void read() override;
 };
 
 } // namespace fwItkIO
 
-#endif // _FWITKIO_IMAGEREADER_HPP_
+#endif // __FWITKIO_IMAGEREADER_HPP__
