@@ -1,21 +1,21 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWITKIO_IMAGEWRITER_HPP_
-#define _FWITKIO_IMAGEWRITER_HPP_
-
-#include <boost/filesystem/path.hpp>
-
-#include <fwDataIO/writer/GenericObjectWriter.hpp>
-#include <fwData/location/SingleFile.hpp>
-#include <fwTools/ProgressAdviser.hpp>
-#include <fwData/Image.hpp>
+#ifndef __FWITKIO_IMAGEWRITER_HPP__
+#define __FWITKIO_IMAGEWRITER_HPP__
 
 #include "fwItkIO/config.hpp"
 
+#include <fwData/Image.hpp>
+#include <fwData/location/SingleFile.hpp>
+
+#include <fwDataIO/writer/GenericObjectWriter.hpp>
+
+#include <fwTools/ProgressAdviser.hpp>
+
 namespace fwItkIO
 {
 
@@ -24,11 +24,11 @@ class ImageWriter : public ::fwDataIO::writer::GenericObjectWriter< ::fwData::Im
                     public ::fwTools::ProgressAdviser
 {
 
-public :
+public:
 
     fwCoreClassDefinitionsWithFactoryMacro((ImageWriter)( ::fwDataIO::writer::GenericObjectWriter< ::fwData::Image>),
-                                            (()),
-                                            ::fwDataIO::writer::factory::New< ImageWriter >
+                                           (()),
+                                           ::fwDataIO::writer::factory::New< ImageWriter >
                                            );
     fwCoreAllowSharedFromThis();
 
@@ -36,11 +36,11 @@ public :
 
     FWITKIO_API ~ImageWriter();
 
-    FWITKIO_API void write();
+    FWITKIO_API void write() override;
 
-    FWITKIO_API std::string extension();
+    FWITKIO_API std::string extension() override;
 };
 
 } // namespace fwItkIO
 
-#endif // _FWITKIO_IMAGEWRITER_HPP_
+#endif // __FWITKIO_IMAGEWRITER_HPP__
