@@ -1,37 +1,34 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <boost/filesystem.hpp>
+#include "fwItkIO/ImageWriter.hpp"
+
+#include "fwItkIO/helper/ProgressItkToFw.hpp"
+#include "fwItkIO/itk.hpp"
 
 #include <fwCore/base.hpp>
 
-#include <itkImageFileWriter.h>
-
-#include <fwTools/IntrinsicTypes.hpp>
-#include <fwTools/DynamicTypeKeyTypeMapping.hpp>
-#include <fwTools/Dispatcher.hpp>
-#include <fwTools/IntrinsicTypes.hpp>
-#include <fwTools/DynamicTypeKeyTypeMapping.hpp>
-
 #include <fwDataIO/writer/registry/macros.hpp>
 
-#include "fwItkIO/itk.hpp"
-#include "fwItkIO/helper/ProgressItkToFw.hpp"
-#include "fwItkIO/ImageWriter.hpp"
+#include <fwTools/Dispatcher.hpp>
+#include <fwTools/DynamicTypeKeyTypeMapping.hpp>
+#include <fwTools/IntrinsicTypes.hpp>
 
+#include <boost/filesystem.hpp>
+
+#include <itkImageFileWriter.h>
 
 fwDataIOWriterRegisterMacro( ::fwItkIO::ImageWriter );
 
-
 namespace fwItkIO
 {
 //------------------------------------------------------------------------------
 
-ImageWriter::ImageWriter(::fwDataIO::writer::IObjectWriter::Key key)
-    : ::fwData::location::enableSingleFile< ::fwDataIO::writer::IObjectWriter >(this)
+ImageWriter::ImageWriter(::fwDataIO::writer::IObjectWriter::Key key) :
+    ::fwData::location::enableSingleFile< ::fwDataIO::writer::IObjectWriter >(this)
 {
     SLM_TRACE_FUNC();
 }
@@ -43,25 +40,28 @@ ImageWriter::~ImageWriter()
     SLM_TRACE_FUNC();
 }
 
-
 struct ITKSaverFunctor
 {
 
     struct Parameter
     {
         std::string m_filename;
-        ::fwData::Image::sptr m_dataImage;
+        ::fwData::Image::csptr m_dataImage;
         ::fwItkIO::ImageWriter::sptr m_fwWriter;
     };
 
+    //------------------------------------------------------------------------------
+
     template<class PIXELTYPE>
-    void operator()( const Parameter &param )
+    void operator()( const Parameter& param )
     {
         OSLM_DEBUG( "itk::ImageFileWriter with PIXELTYPE "<<  fwTools::DynamicType::string<PIXELTYPE>() );
 
-        // VAG attention : ImageFileReader ne notifie AUCUNE progressEvent mais son ImageIO oui!!!! mais ImageFileReader ne permet pas de l'atteindre
+        // VAG attention : ImageFileReader ne notifie AUCUNE progressEvent mais son ImageIO oui!!!! mais ImageFileReader
+        // ne permet pas de l'atteindre
         // car soit mis a la mano ou alors construit lors de l'Update donc trop tard
-        // Il faut dont creer une ImageIO a la mano (*1*): affecter l'observation  sur IO (*2*) et mettre le IO dans le reader (voir *3*)
+        // Il faut dont creer une ImageIO a la mano (*1*): affecter l'observation  sur IO (*2*) et mettre le IO dans le
+        // reader (voir *3*)
 
         // Reader IO (*1*)
         typename itk::ImageIOBase::Pointer imageIOWrite = itk::ImageIOFactory::CreateImageIO(
@@ -70,12 +70,11 @@ struct ITKSaverFunctor
 
         // create writer
         typedef itk::Image< PIXELTYPE, 3> itkImageType;
-        typedef typename  itk::ImageFileWriter< itkImageType >      WriterType;
+        typedef typename itk::ImageFileWriter< itkImageType >      WriterType;
         typename WriterType::Pointer writer = WriterType::New();
 
-
         // set observation (*2*)
-        itk::LightProcessObject::Pointer castHelper = (itk::LightProcessObject *)(imageIOWrite.GetPointer());
+        itk::LightProcessObject::Pointer castHelper = (itk::LightProcessObject*)(imageIOWrite.GetPointer());
         assert( castHelper.IsNotNull() );
         Progressor progress(castHelper, param.m_fwWriter, param.m_filename);
 
@@ -108,11 +107,11 @@ void ImageWriter::write()
         saverParam.m_dataImage->getPixelType(), saverParam );
 }
 
-
+//------------------------------------------------------------------------------
 
 std::string ImageWriter::extension()
 {
-    if ( getFile().empty() ||  ( getFile().string().find(".inr.gz") !=  std::string::npos ) )
+    if ( getFile().empty() ||  ( getFile().string().find(".inr.gz") != std::string::npos ) )
     {
         return ".inr.gz";
     }
