@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWITKIO_UT_HELPER_HPP_
-#define _FWITKIO_UT_HELPER_HPP_
+#ifndef __FWITKIO_UT_HELPER_HPP__
+#define __FWITKIO_UT_HELPER_HPP__
 
 namespace fwData
 {
@@ -26,4 +26,4 @@ void roundSpacing( SPTR(::fwData::Image) image);
 } //namespace fwItkIO
 
 
-#endif // _FWITKIO_UT_HELPER_HPP_
+#endif // __FWITKIO_UT_HELPER_HPP__
