@@ -1,13 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWVTKIO_MODELSERIESOBJWRITER_HPP__
-#define __FWVTKIO_MODELSERIESOBJWRITER_HPP__
-
-#ifndef ANDROID
+#pragma once
 
 #include "fwVtkIO/config.hpp"
 
@@ -78,7 +75,3 @@ private:
 };
 
 } // namespace fwVtkIO
-
-#endif // ANDROID
-
-#endif //__FWVTKIO_MODELSERIESOBJWRITER_HPP__
