@@ -1,12 +1,13 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include "fwVtkIO/vtk.hpp"
 #include "fwVtkIO/VtiImageWriter.hpp"
+
 #include "fwVtkIO/helper/vtkLambdaCommand.hpp"
+#include "fwVtkIO/vtk.hpp"
 
 #include <fwCore/base.hpp>
 
@@ -16,14 +17,12 @@
 #include <fwJobs/Observer.hpp>
 
 #include <vtkImageData.h>
+#include <vtkSmartPointer.h>
 #include <vtkXMLImageDataWriter.h>
 #include <vtkZLibDataCompressor.h>
-#include <vtkSmartPointer.h>
-
 
 fwDataIOWriterRegisterMacro( ::fwVtkIO::VtiImageWriter );
 
-
 namespace fwVtkIO
 {
 //------------------------------------------------------------------------------
@@ -51,7 +50,7 @@ void VtiImageWriter::write()
     assert( !m_object.expired() );
     assert( m_object.lock() );
 
-    ::fwData::Image::sptr pImage = getConcreteObject();
+    ::fwData::Image::csptr pImage = getConcreteObject();
 
     vtkSmartPointer< vtkXMLImageDataWriter > writer = vtkSmartPointer< vtkXMLImageDataWriter >::New();
     vtkSmartPointer< vtkImageData > vtkImage        = vtkSmartPointer< vtkImageData >::New();
