@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -38,13 +38,13 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
     if (points)
     {
         mesh->clear();
-        vtkIdType numberOfPoints = points->GetNumberOfPoints();
-        vtkIdType numberOfCells  = polyData->GetNumberOfCells();
+        const vtkIdType numberOfPoints = points->GetNumberOfPoints();
+        const vtkIdType numberOfCells  = polyData->GetNumberOfCells();
 
         mesh->allocate(numberOfPoints, numberOfCells, numberOfCells*3);
         ::fwDataTools::helper::Mesh meshHelper(mesh);
 
-        double* point;
+        const double* point;
         ::fwData::Mesh::Id idx;
         for (vtkIdType i = 0; i < numberOfPoints; ++i)
         {
@@ -97,7 +97,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             colors = vtkUnsignedCharArray::SafeDownCast(polyData->GetPointData()->GetArray("Colors"));
             FW_RAISE_IF("Only vtkUnsignedCharArray is supported to manage color.", !colors);
 
-            size_t nbComponents = colors->GetNumberOfComponents();
+            const size_t nbComponents = colors->GetNumberOfComponents();
             SLM_ASSERT("Wrong nb of components ("<<nbComponents<<")",
                        nbComponents == 3 || nbComponents == 4);
             mesh->allocatePointColors((::fwData::Mesh::ColorArrayTypes)nbComponents);
@@ -122,7 +122,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             mesh->allocateCellColors((::fwData::Mesh::ColorArrayTypes)nbComponents);
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellColor(i, colors->GetPointer(i*nbComponents));
@@ -141,7 +141,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             mesh->allocatePointNormals();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
+            const ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
             for (size_t i = 0; i != nbPoints; ++i)
             {
                 meshHelper.setPointNormal(i, normals->GetPointer(i*nbComponents));
@@ -160,7 +160,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             mesh->allocateCellNormals();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellNormal(i, normals->GetPointer(i*nbComponents));
@@ -179,7 +179,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             mesh->allocatePointTexCoords();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
+            const ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
             for (size_t i = 0; i != nbPoints; ++i)
             {
                 meshHelper.setPointTexCoord(i, texCoords->GetPointer(i*nbComponents));
@@ -198,7 +198,7 @@ void Mesh::fromVTKMesh(  vtkSmartPointer<vtkPolyData> polyData, ::fwData::Mesh::
             mesh->allocateCellTexCoords();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellTexCoord(i, texCoords->GetPointer(i*nbComponents));
@@ -217,8 +217,8 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
     if(points)
     {
         mesh->clear();
-        vtkIdType numberOfPoints = points->GetNumberOfPoints();
-        vtkIdType numberOfCells  = grid->GetNumberOfCells();
+        const vtkIdType numberOfPoints = points->GetNumberOfPoints();
+        const vtkIdType numberOfCells  = grid->GetNumberOfCells();
 
         mesh->allocate(numberOfPoints, numberOfCells, numberOfCells*3);
         ::fwDataTools::helper::Mesh meshHelper(mesh);
@@ -260,7 +260,8 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
                     break;
                 case VTK_TETRA:
                     SLM_ASSERT("Wrong number of ids: "<<idList->GetNumberOfIds(), idList->GetNumberOfIds() == 4);
-                    meshHelper.insertNextCell( idList->GetId(0), idList->GetId(1), idList->GetId(2), idList->GetId(3));
+                    meshHelper.insertNextCell( idList->GetId(0), idList->GetId(1), idList->GetId(2), idList->GetId(3),
+                                               ::fwData::Mesh::TETRA);
                     break;
                 default:
                     FW_RAISE("VTK Mesh type "<<cellType<< " not supported.");
@@ -279,7 +280,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocatePointColors((::fwData::Mesh::ColorArrayTypes)nbComponents);
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
+            const ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
             for (size_t i = 0; i != nbPoints; ++i)
             {
                 meshHelper.setPointColor(i, colors->GetPointer(i*nbComponents));
@@ -298,7 +299,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocateCellColors((::fwData::Mesh::ColorArrayTypes)nbComponents);
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellColor(i, colors->GetPointer(i*nbComponents));
@@ -317,7 +318,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocatePointNormals();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
+            const ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
             for (size_t i = 0; i != nbPoints; ++i)
             {
                 meshHelper.setPointNormal(i, normals->GetPointer(i*nbComponents));
@@ -336,7 +337,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocateCellNormals();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellNormal(i, normals->GetPointer(i*nbComponents));
@@ -355,7 +356,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocatePointTexCoords();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
+            const ::fwData::Mesh::Id nbPoints = mesh->getNumberOfPoints();
             for (size_t i = 0; i != nbPoints; ++i)
             {
                 meshHelper.setPointTexCoord(i, texCoords->GetPointer(i*nbComponents));
@@ -374,7 +375,7 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
             mesh->allocateCellTexCoords();
             meshHelper.updateLock();
 
-            ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
+            const ::fwData::Mesh::Id nbCells = mesh->getNumberOfCells();
             for (size_t i = 0; i != nbCells; ++i)
             {
                 meshHelper.setCellTexCoord(i, texCoords->GetPointer(i*nbComponents));
@@ -391,25 +392,25 @@ void Mesh::fromVTKGrid(vtkSmartPointer<vtkUnstructuredGrid> grid, ::fwData::Mesh
 
 void Mesh::toVTKMesh( const ::fwData::Mesh::csptr& mesh, vtkSmartPointer<vtkPolyData> polyData)
 {
-    vtkSmartPointer< vtkPoints > pts = vtkSmartPointer< vtkPoints >::New();
+    const vtkSmartPointer< vtkPoints > pts = vtkSmartPointer< vtkPoints >::New();
     polyData->SetPoints(pts);
     Mesh::updatePolyDataPoints(polyData, mesh);
 
     ::fwDataTools::helper::MeshGetter meshHelper(mesh);
-    unsigned int nbCells = mesh->getNumberOfCells();
+    const unsigned int nbCells = mesh->getNumberOfCells();
 
-    ::fwData::Mesh::ConstCellTypesMultiArrayType cellTypes             = meshHelper.getCellTypes();
-    ::fwData::Mesh::ConstCellDataMultiArrayType cellData               = meshHelper.getCellData();
-    ::fwData::Mesh::ConstCellDataOffsetsMultiArrayType cellDataOffsets = meshHelper.getCellDataOffsets();
+    const ::fwData::Mesh::ConstCellTypesMultiArrayType cellTypes             = meshHelper.getCellTypes();
+    const ::fwData::Mesh::ConstCellDataMultiArrayType cellData               = meshHelper.getCellData();
+    const ::fwData::Mesh::ConstCellDataOffsetsMultiArrayType cellDataOffsets = meshHelper.getCellDataOffsets();
 
-    polyData->Allocate(4, nbCells);
+    polyData->Allocate(static_cast< int >(nbCells));
 
     vtkIdType typeVtkCell;
     vtkIdType cell[4];
     for(unsigned int i = 0; i < nbCells; ++i )
     {
-        ::fwData::Mesh::CellTypes cellType = cellTypes[i];
-        ::fwData::Mesh::Id offset          = cellDataOffsets[i];
+        const ::fwData::Mesh::CellTypes cellType = cellTypes[i];
+        const ::fwData::Mesh::Id offset          = cellDataOffsets[i];
         switch( cellType )
         {
             case ::fwData::Mesh::POINT:
@@ -440,9 +441,6 @@ void Mesh::toVTKMesh( const ::fwData::Mesh::csptr& mesh, vtkSmartPointer<vtkPoly
                 break;
             case ::fwData::Mesh::TETRA:
                 typeVtkCell = VTK_LINE;
-                cell[0]     = cellData[offset];
-                cell[1]     = cellData[offset+1];
-                polyData->InsertNextCell( typeVtkCell, 2, cell );
 
                 cell[0] = cellData[offset+1];
                 cell[1] = cellData[offset+2];
@@ -479,15 +477,86 @@ void Mesh::toVTKMesh( const ::fwData::Mesh::csptr& mesh, vtkSmartPointer<vtkPoly
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPoints(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                        const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::toVTKGrid( const ::fwData::Mesh::csptr& mesh, vtkSmartPointer<vtkUnstructuredGrid> grid)
+{
+    const vtkSmartPointer< vtkPoints > pts = vtkSmartPointer< vtkPoints >::New();
+    grid->SetPoints(pts);
+    Mesh::updateGridPoints(grid, mesh);
+
+    ::fwDataTools::helper::MeshGetter meshHelper(mesh);
+    const unsigned int nbCells = mesh->getNumberOfCells();
+
+    const ::fwData::Mesh::ConstCellTypesMultiArrayType cellTypes             = meshHelper.getCellTypes();
+    const ::fwData::Mesh::ConstCellDataMultiArrayType cellData               = meshHelper.getCellData();
+    const ::fwData::Mesh::ConstCellDataOffsetsMultiArrayType cellDataOffsets = meshHelper.getCellDataOffsets();
+
+    grid->Allocate(static_cast<int>(nbCells));
+
+    vtkIdType typeVtkCell;
+    vtkIdType cell[4];
+    for(unsigned int i = 0; i < nbCells; ++i )
+    {
+        const ::fwData::Mesh::CellTypes cellType = cellTypes[i];
+        const ::fwData::Mesh::Id offset          = cellDataOffsets[i];
+        switch( cellType )
+        {
+            case ::fwData::Mesh::POINT:
+                typeVtkCell = VTK_VERTEX;
+                cell[0]     = cellData[offset];
+                grid->InsertNextCell( typeVtkCell, 1, cell );
+                break;
+            case ::fwData::Mesh::EDGE:
+                typeVtkCell = VTK_LINE;
+                cell[0]     = cellData[offset];
+                cell[1]     = cellData[offset+1];
+                grid->InsertNextCell( typeVtkCell, 2, cell );
+                break;
+            case ::fwData::Mesh::TRIANGLE:
+                typeVtkCell = VTK_TRIANGLE;
+                cell[0]     = cellData[offset];
+                cell[1]     = cellData[offset+1];
+                cell[2]     = cellData[offset+2];
+                grid->InsertNextCell( typeVtkCell, 3, cell );
+                break;
+            case ::fwData::Mesh::QUAD:
+                typeVtkCell = VTK_QUAD;
+                cell[0]     = cellData[offset];
+                cell[1]     = cellData[offset+1];
+                cell[2]     = cellData[offset+2];
+                cell[3]     = cellData[offset+3];
+                grid->InsertNextCell( typeVtkCell, 4, cell );
+                break;
+            case ::fwData::Mesh::TETRA:
+                typeVtkCell = VTK_TETRA;
+                cell[0]     = cellData[offset];
+                cell[1]     = cellData[offset+1];
+                cell[2]     = cellData[offset+2];
+                cell[3]     = cellData[offset+3];
+                grid->InsertNextCell( typeVtkCell, 4, cell );
+        }
+    }
+
+    Mesh::updateGridPointNormals(grid, mesh);
+    Mesh::updateGridCellNormals(grid, mesh);
+
+    Mesh::updateGridPointColor(grid, mesh);
+    Mesh::updateGridCellColor(grid, mesh);
+
+    Mesh::updateGridPointTexCoords(grid, mesh);
+    Mesh::updateGridCellTexCoords(grid, mesh);
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updatePolyDataPoints(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
     ::fwDataTools::helper::MeshGetter meshHelper(meshSrc);
 
-    vtkPoints* polyDataPoints = polyDataDst->GetPoints();
-    ::fwData::Mesh::Id nbPoints                      = meshSrc->getNumberOfPoints();
-    ::fwData::Mesh::ConstPointsMultiArrayType points = meshHelper.getPoints();
+    vtkPoints* polyDataPoints                              = polyDataDst->GetPoints();
+    const ::fwData::Mesh::Id nbPoints                      = meshSrc->getNumberOfPoints();
+    const ::fwData::Mesh::ConstPointsMultiArrayType points = meshHelper.getPoints();
 
     if (nbPoints != polyDataPoints->GetNumberOfPoints())
     {
@@ -502,28 +571,27 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPoints(vtkSmartPointer<vtkPolyD
     }
 
     polyDataPoints->Modified();
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointColor(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                            const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataPointColor(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                    const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr pointColorArray = meshSrc->getPointColorsArray();
+    const ::fwData::Array::sptr pointColorArray = meshSrc->getPointColorsArray();
     if(pointColorArray)
     {
         ::fwDataTools::helper::Array arrayHelper(pointColorArray);
 
-        vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
-        size_t nbComponents                          = pointColorArray->getNumberOfComponents();
-        colors->SetNumberOfComponents(nbComponents);
+        const vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
+        const size_t nbComponents                          = pointColorArray->getNumberOfComponents();
+        colors->SetNumberOfComponents(static_cast<int>(nbComponents));
         colors->SetName("Colors");
 
-        unsigned char* pointColor    = arrayHelper.begin< unsigned char >();
-        unsigned char* pointColorEnd = arrayHelper.end< unsigned char >();
+        const unsigned char* pointColor    = arrayHelper.begin< unsigned char >();
+        const unsigned char* pointColorEnd = arrayHelper.end< unsigned char >();
 
         for (; pointColor != pointColorEnd; pointColor += nbComponents)
         {
@@ -545,30 +613,28 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointColor(vtkSmartPointer<vtkP
         }
         polyDataDst->Modified();
     }
-
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellColor(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                           const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataCellColor(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                   const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr cellColorArray = meshSrc->getCellColorsArray();
+    const ::fwData::Array::sptr cellColorArray = meshSrc->getCellColorsArray();
     if(cellColorArray)
     {
         ::fwDataTools::helper::Array arrayHelper(cellColorArray);
 
-        vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
-        size_t nbComponents                          = cellColorArray->getNumberOfComponents();
-        colors->SetNumberOfComponents(nbComponents);
+        const vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
+        const size_t nbComponents                          = cellColorArray->getNumberOfComponents();
+        colors->SetNumberOfComponents(static_cast<int>(nbComponents));
         colors->SetName("Colors");
 
         ::fwMemory::BufferObject::Lock lock = cellColorArray->getBufferObject()->lock();
-        unsigned char* cellColor    = arrayHelper.begin< unsigned char >();
-        unsigned char* cellColorEnd = arrayHelper.end< unsigned char >();
+        const unsigned char* cellColor    = arrayHelper.begin< unsigned char >();
+        const unsigned char* cellColorEnd = arrayHelper.end< unsigned char >();
 
         for (; cellColor != cellColorEnd; cellColor += nbComponents)
         {
@@ -592,27 +658,26 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellColor(vtkSmartPointer<vtkPo
         polyDataDst->Modified();
     }
 
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointNormals(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                              const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataPointNormals(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                      const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr pointNormalsArray = meshSrc->getPointNormalsArray();
+    const ::fwData::Array::sptr pointNormalsArray = meshSrc->getPointNormalsArray();
     if(pointNormalsArray)
     {
         ::fwDataTools::helper::Array arrayHelper(pointNormalsArray);
 
         vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
-        size_t nbComponents                    = pointNormalsArray->getNumberOfComponents();
-        normals->SetNumberOfComponents(nbComponents);
+        const size_t nbComponents              = pointNormalsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
 
-        float* pointNormal    = arrayHelper.begin< float >();
-        float* pointNormalEnd = arrayHelper.end< float >();
+        const float* pointNormal          = arrayHelper.begin< float >();
+        const float* const pointNormalEnd = arrayHelper.end< float >();
 
         for (; pointNormal != pointNormalEnd; pointNormal += nbComponents)
         {
@@ -635,29 +700,27 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointNormals(vtkSmartPointer<vt
         }
         polyDataDst->Modified();
     }
-
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellNormals(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                             const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataCellNormals(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                     const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr cellNormalsArray = meshSrc->getCellNormalsArray();
+    const ::fwData::Array::sptr cellNormalsArray = meshSrc->getCellNormalsArray();
 
     if(cellNormalsArray)
     {
         ::fwDataTools::helper::Array arrayHelper(cellNormalsArray);
 
         vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
-        size_t nbComponents                    = cellNormalsArray->getNumberOfComponents();
-        normals->SetNumberOfComponents(nbComponents);
+        const size_t nbComponents              = cellNormalsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
 
-        float* cellNormal    = arrayHelper.begin< float >();
-        float* cellNormalEnd = arrayHelper.end< float >();
+        const float* cellNormal          = arrayHelper.begin< float >();
+        const float* const cellNormalEnd = arrayHelper.end< float >();
 
         for (; cellNormal != cellNormalEnd; cellNormal += nbComponents)
         {
@@ -680,28 +743,26 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellNormals(vtkSmartPointer<vtk
         }
         polyDataDst->Modified();
     }
-
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointTexCoords(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                                const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataPointTexCoords(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                        const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr pointTexCoordsArray = meshSrc->getPointTexCoordsArray();
+    const ::fwData::Array::sptr pointTexCoordsArray = meshSrc->getPointTexCoordsArray();
     if(pointTexCoordsArray)
     {
         ::fwDataTools::helper::Array arrayHelper(pointTexCoordsArray);
 
         vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
-        size_t nbComponents                    = pointTexCoordsArray->getNumberOfComponents();
-        normals->SetNumberOfComponents(nbComponents);
+        const size_t nbComponents              = pointTexCoordsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
 
-        float* pointTexCoord    = arrayHelper.begin< float >();
-        float* pointTexCoordEnd = arrayHelper.end< float >();
+        const float* pointTexCoord          = arrayHelper.begin< float >();
+        const float* const pointTexCoordEnd = arrayHelper.end< float >();
 
         for (; pointTexCoord != pointTexCoordEnd; pointTexCoord += nbComponents)
         {
@@ -724,29 +785,26 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataPointTexCoords(vtkSmartPointer<
         }
         polyDataDst->Modified();
     }
-
-    return polyDataDst;
 }
 
 //------------------------------------------------------------------------------
 
-vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellTexCoords(vtkSmartPointer<vtkPolyData> polyDataDst,
-                                                               const ::fwData::Mesh::csptr& meshSrc )
+void Mesh::updatePolyDataCellTexCoords(vtkSmartPointer<vtkPolyData> polyDataDst,
+                                       const ::fwData::Mesh::csptr& meshSrc )
 {
     SLM_ASSERT( "vtkPolyData should not be NULL", polyDataDst);
 
-    ::fwData::Array::sptr cellTexCoordsArray = meshSrc->getCellTexCoordsArray();
-
+    const ::fwData::Array::sptr cellTexCoordsArray = meshSrc->getCellTexCoordsArray();
     if(cellTexCoordsArray)
     {
         ::fwDataTools::helper::Array arrayHelper(cellTexCoordsArray);
 
         vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
-        size_t nbComponents                    = cellTexCoordsArray->getNumberOfComponents();
-        normals->SetNumberOfComponents(nbComponents);
+        const size_t nbComponents              = cellTexCoordsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
 
-        float* cellTexCoord    = arrayHelper.begin< float >();
-        float* cellTexCoordEnd = arrayHelper.end< float >();
+        const float* cellTexCoord          = arrayHelper.begin< float >();
+        const float* const cellTexCoordEnd = arrayHelper.end< float >();
 
         for (; cellTexCoord != cellTexCoordEnd; cellTexCoord += nbComponents)
         {
@@ -770,7 +828,6 @@ vtkSmartPointer<vtkPolyData> Mesh::updatePolyDataCellTexCoords(vtkSmartPointer<v
         polyDataDst->Modified();
     }
 
-    return polyDataDst;
 }
 
 //-----------------------------------------------------------------------------
@@ -792,20 +849,20 @@ double Mesh::computeVolume( const ::fwData::Mesh::csptr& mesh )
     }
 
     // compute normals for polygonal mesh
-    vtkSmartPointer< vtkPolyDataNormals > filter = vtkSmartPointer< vtkPolyDataNormals >::New();
+    const vtkSmartPointer< vtkPolyDataNormals > filter = vtkSmartPointer< vtkPolyDataNormals >::New();
     filter->SetInputData(vtkMeshRaw);
     filter->AutoOrientNormalsOn();
     filter->FlipNormalsOff();
 
     // estimate volume, area, shape index of triangle mesh
-    vtkSmartPointer< vtkMassProperties > calculator = vtkSmartPointer< vtkMassProperties >::New();
+    const vtkSmartPointer< vtkMassProperties > calculator = vtkSmartPointer< vtkMassProperties >::New();
     calculator->SetInputConnection( filter->GetOutputPort() );
     calculator->Update();
 
-    double volume = calculator->GetVolume();
+    const double volume = calculator->GetVolume();
     OSLM_DEBUG(
         "GetVolume : " << volume << " vtkMassProperties::GetVolumeProjected = " <<
-        calculator->GetVolumeProjected() );
+            calculator->GetVolumeProjected() );
     OSLM_DEBUG("Error : " << (calculator->GetVolume()- fabs(calculator->GetVolumeProjected()))*10000);
     if ( (calculator->GetVolume()- fabs(calculator->GetVolumeProjected()))*10000 > calculator->GetVolume() )
     {
@@ -821,5 +878,292 @@ double Mesh::computeVolume( const ::fwData::Mesh::csptr& mesh )
 
 //------------------------------------------------------------------------------
 
+void Mesh::updateGridPointNormals(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                                  const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkUnstructuredGrid should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr pointNormalsArray = meshSrc->getPointNormalsArray();
+    if(pointNormalsArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(pointNormalsArray);
+
+        vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
+        const size_t nbComponents              = pointNormalsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
+
+        const float* pointNormal          = arrayHelper.begin< float >();
+        const float* const pointNormalEnd = arrayHelper.end< float >();
+
+        for (; pointNormal != pointNormalEnd; pointNormal += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            normals->InsertNextTypedTuple(pointNormal);
+#else
+            normals->InsertNextTupleValue(pointNormal);
+#endif
+        }
+
+        gridDst->GetPointData()->SetNormals(normals);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetPointData()->GetAttribute(vtkDataSetAttributes::NORMALS))
+        {
+            gridDst->GetPointData()->RemoveArray(vtkDataSetAttributes::NORMALS);
+        }
+        gridDst->Modified();
+    }
+
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updateGridPoints(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                            const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+    ::fwDataTools::helper::MeshGetter meshHelper(meshSrc);
+
+    vtkPoints* polyDataPoints                              = gridDst->GetPoints();
+    const ::fwData::Mesh::Id nbPoints                      = meshSrc->getNumberOfPoints();
+    const ::fwData::Mesh::ConstPointsMultiArrayType points = meshHelper.getPoints();
+
+    if (nbPoints != polyDataPoints->GetNumberOfPoints())
+    {
+        polyDataPoints->SetNumberOfPoints(nbPoints);
+    }
+
+    vtkIdType id = 0;
+    typedef ::fwData::Mesh::PointsMultiArrayType::index PointTypesIndex;
+    for (PointTypesIndex i = 0; i != nbPoints; ++i)
+    {
+        polyDataPoints->SetPoint(id++, points[i][0], points[i][1], points[i][2]);
+    }
+
+    polyDataPoints->Modified();
+}
+
+//------------------------------------------------------------------------------
+void Mesh::updateGridPointColor(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                                const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr pointColorArray = meshSrc->getPointColorsArray();
+    if(pointColorArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(pointColorArray);
+
+        vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
+        const size_t nbComponents                    = pointColorArray->getNumberOfComponents();
+        colors->SetNumberOfComponents(static_cast<int>(nbComponents));
+        colors->SetName("Colors");
+
+        const unsigned char* pointColor          = arrayHelper.begin< unsigned char >();
+        const unsigned char* const pointColorEnd = arrayHelper.end< unsigned char >();
+
+        for (; pointColor != pointColorEnd; pointColor += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            colors->InsertNextTypedTuple(pointColor);
+#else
+            colors->InsertNextTupleValue(pointColor);
+#endif
+        }
+        gridDst->GetPointData()->SetScalars(colors);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetPointData()->HasArray("Colors"))
+        {
+            gridDst->GetPointData()->RemoveArray("Colors");
+        }
+        gridDst->Modified();
+    }
+
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updateGridCellColor(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                               const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr cellColorArray = meshSrc->getCellColorsArray();
+    if(cellColorArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(cellColorArray);
+
+        vtkSmartPointer<vtkUnsignedCharArray> colors = vtkSmartPointer<vtkUnsignedCharArray>::New();
+        const size_t nbComponents                    = cellColorArray->getNumberOfComponents();
+        colors->SetNumberOfComponents(static_cast<int>(nbComponents));
+        colors->SetName("Colors");
+
+        const ::fwMemory::BufferObject::Lock lock = cellColorArray->getBufferObject()->lock();
+        const unsigned char* cellColor            = arrayHelper.begin< unsigned char >();
+        const unsigned char* const cellColorEnd   = arrayHelper.end< unsigned char >();
+
+        for (; cellColor != cellColorEnd; cellColor += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            colors->InsertNextTypedTuple(cellColor);
+#else
+            colors->InsertNextTupleValue(cellColor);
+#endif
+        }
+
+        gridDst->GetCellData()->SetScalars(colors);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetCellData()->HasArray("Colors"))
+        {
+            gridDst->GetCellData()->RemoveArray("Colors");
+        }
+        gridDst->Modified();
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updateGridCellNormals(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                                 const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr cellNormalsArray = meshSrc->getCellNormalsArray();
+
+    if(cellNormalsArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(cellNormalsArray);
+
+        vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
+        const size_t nbComponents              = cellNormalsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
+
+        const float* cellNormal          = arrayHelper.begin< float >();
+        const float* const cellNormalEnd = arrayHelper.end< float >();
+
+        for (; cellNormal != cellNormalEnd; cellNormal += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            normals->InsertNextTypedTuple(cellNormal);
+#else
+            normals->InsertNextTupleValue(cellNormal);
+#endif
+        }
+
+        gridDst->GetCellData()->SetNormals(normals);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetCellData()->GetAttribute(vtkDataSetAttributes::NORMALS))
+        {
+            gridDst->GetCellData()->RemoveArray(vtkDataSetAttributes::NORMALS);
+        }
+        gridDst->Modified();
+    }
+
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updateGridPointTexCoords(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                                    const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr pointTexCoordsArray = meshSrc->getPointTexCoordsArray();
+    if(pointTexCoordsArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(pointTexCoordsArray);
+
+        vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
+        const size_t nbComponents              = pointTexCoordsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
+
+        const float* pointTexCoord          = arrayHelper.begin< float >();
+        const float* const pointTexCoordEnd = arrayHelper.end< float >();
+
+        for (; pointTexCoord != pointTexCoordEnd; pointTexCoord += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            normals->InsertNextTypedTuple(pointTexCoord);
+#else
+            normals->InsertNextTupleValue(pointTexCoord);
+#endif
+        }
+
+        gridDst->GetPointData()->SetTCoords(normals);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetPointData()->GetAttribute(vtkDataSetAttributes::TCOORDS))
+        {
+            gridDst->GetPointData()->RemoveArray(vtkDataSetAttributes::TCOORDS);
+        }
+        gridDst->Modified();
+    }
+
+}
+
+//------------------------------------------------------------------------------
+
+void Mesh::updateGridCellTexCoords(vtkSmartPointer<vtkUnstructuredGrid> gridDst,
+                                   const ::fwData::Mesh::csptr& meshSrc )
+{
+    SLM_ASSERT( "vtkPolyData should not be NULL", gridDst);
+
+    const ::fwData::Array::sptr cellTexCoordsArray = meshSrc->getCellTexCoordsArray();
+
+    if(cellTexCoordsArray)
+    {
+        ::fwDataTools::helper::Array arrayHelper(cellTexCoordsArray);
+
+        vtkSmartPointer<vtkFloatArray> normals = vtkSmartPointer<vtkFloatArray>::New();
+        size_t nbComponents                    = cellTexCoordsArray->getNumberOfComponents();
+        normals->SetNumberOfComponents(static_cast<int>(nbComponents));
+
+        const float* cellTexCoord          = arrayHelper.begin< float >();
+        const float* const cellTexCoordEnd = arrayHelper.end< float >();
+
+        for (; cellTexCoord != cellTexCoordEnd; cellTexCoord += nbComponents)
+        {
+            // Since VTK 7.1, InsertNextTupleValue is deprecated in favor of InsertNextTypedTuple.
+#if (VTK_MAJOR_VERSION == 7 && VTK_MINOR_VERSION >= 1) ||  VTK_MAJOR_VERSION > 7
+            normals->InsertNextTypedTuple(cellTexCoord);
+#else
+            normals->InsertNextTupleValue(cellTexCoord);
+#endif
+        }
+
+        gridDst->GetCellData()->SetTCoords(normals);
+        gridDst->Modified();
+    }
+    else
+    {
+        if(gridDst->GetCellData()->GetAttribute(vtkDataSetAttributes::TCOORDS))
+        {
+            gridDst->GetCellData()->RemoveArray(vtkDataSetAttributes::TCOORDS);
+        }
+        gridDst->Modified();
+    }
+
+}
+
+//-----------------------------------------------------------------------------
+
 } // namespace helper
 } // namespace fwVtkIO
