@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -21,9 +21,6 @@ void TransferFunction::toVtkLookupTable(
     bool allowTransparency,
     unsigned int size )
 {
-    SLM_WARN_IF( "This transfer function conversion is not managed, transfer function is clamped.",
-                 tf->getIsClamped() );
-
     // Configures basic parameters
     lt->SetNumberOfTableValues( size );
     lt->SetScaleToLinear();
