@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWVTKIO_UT_SERIESDBTEST_HPP_
-#define _FWVTKIO_UT_SERIESDBTEST_HPP_
+#ifndef __FWVTKIO_UT_SERIESDBTEST_HPP__
+#define __FWVTKIO_UT_SERIESDBTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -22,10 +22,10 @@ namespace ut
  */
 class SeriesDBTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( SeriesDBTest );
-    CPPUNIT_TEST( testImportSeriesDB );
-    CPPUNIT_TEST( testLazyImportSeriesDB );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( SeriesDBTest );
+CPPUNIT_TEST( testImportSeriesDB );
+CPPUNIT_TEST( testLazyImportSeriesDB );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -40,4 +40,4 @@ public:
 } // namespace ut
 } // namespace fwVtkIO
 
-#endif //_FWVTKIO_UT_SERIESDBTEST_HPP_
+#endif //__FWVTKIO_UT_SERIESDBTEST_HPP__
