@@ -1,20 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWVTKGDCMIO_TEST_TU_SERIESDBLAZYREADER_HPP__
-#define __FWVTKGDCMIO_TEST_TU_SERIESDBLAZYREADER_HPP__
+#ifndef __VTKGDCMIO_UT_SERIESDBLAZYREADERTEST_HPP__
+#define __VTKGDCMIO_UT_SERIESDBLAZYREADERTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 #include <fwServices/macros.hpp>
-#include <fwRuntime/EConfigurationElement.hpp>
-
-namespace fwMedData
-{
-    class SeriesDB;
-}
 
 namespace vtkGdcmIO
 {
@@ -23,9 +17,9 @@ namespace ut
 
 class SeriesDBLazyReaderTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( SeriesDBLazyReaderTest );
-    CPPUNIT_TEST( readSeriesDBTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( SeriesDBLazyReaderTest );
+CPPUNIT_TEST( readSeriesDBTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
 
@@ -34,13 +28,10 @@ public:
 
     void readSeriesDBTest();
 
-private:
-    ::fwMedData::SeriesDB::sptr m_seriesDB;
-
 };
 
 } // namespace ut
 } // namespace vtkGdcmIO
 
-#endif // __FWVTKGDCMIO_TEST_TU_SERIESDBLAZYREADER_HPP__
+#endif // __VTKGDCMIO_UT_SERIESDBLAZYREADERTEST_HPP__
 
