@@ -1,11 +1,10 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWMDSEMANTICPATCH_PATCHLOADER_HPP__
-#define __FWMDSEMANTICPATCH_PATCHLOADER_HPP__
+#pragma once
 
 #include "fwMDSemanticPatch/config.hpp"
 
@@ -23,9 +22,14 @@ public:
 
     /// Returns current MedicalData version.
     FWMDSEMANTICPATCH_API static std::string getCurrentVersion();
+
+    /// Set the current MedicalData version.
+    FWMDSEMANTICPATCH_API static void setCurrentVersion(const std::string& version);
+
+private:
+
+    /// Current version of the MedicalData context
+    static std::string s_currentVersion;
 };
 
 } //namespace fwMDSemanticPatch
-
-#endif /* __FWMDSEMANTICPATCH_PATCHLOADER_HPP__ */
-
