@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2017.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -13,6 +13,8 @@
 namespace fwMDSemanticPatch
 {
 
+std::string PatchLoader::s_currentVersion = "V11";
+
 //------------------------------------------------------------------------------
 
 void PatchLoader::loadPatches()
@@ -25,12 +27,18 @@ void PatchLoader::loadPatches()
 
 //------------------------------------------------------------------------------
 
+void PatchLoader::setCurrentVersion(const std::string& version)
+{
+    s_currentVersion = version;
+}
+
+//------------------------------------------------------------------------------
+
 std::string PatchLoader::getCurrentVersion()
 {
-    return "V10";
+    return s_currentVersion;
 }
 
 //------------------------------------------------------------------------------
 
 } //namespace fwMDSemanticPatch
-
