@@ -1,14 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_EQUIPMENT1_HPP__
-#define __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_EQUIPMENT1_HPP__
+#pragma once
+
+#include "fwStructuralPatch/config.hpp"
 
 #include <fwAtomsPatch/IStructuralCreator.hpp>
-#include "fwStructuralPatch/config.hpp"
 
 namespace fwStructuralPatch
 {
@@ -21,7 +21,7 @@ namespace fwMedData
 class FWSTRUCTURALPATCH_CLASS_API Equipment1 : public ::fwAtomsPatch::IStructuralCreator
 {
 public:
-    fwCoreClassDefinitionsWithFactoryMacro( (Equipment1)(::fwAtomsPatch::IStructuralCreator), (()), new Equipment1) ;
+    fwCoreClassDefinitionsWithFactoryMacro( (Equipment1)(::fwAtomsPatch::IStructuralCreator), (()), new Equipment1);
 
     /// Constructor
     FWSTRUCTURALPATCH_API Equipment1();
@@ -30,15 +30,13 @@ public:
     FWSTRUCTURALPATCH_API ~Equipment1();
 
     /// Copy constructor
-    FWSTRUCTURALPATCH_API Equipment1( const Equipment1 &cpy );
+    FWSTRUCTURALPATCH_API Equipment1( const Equipment1& cpy );
 
     /// Create the specified object (sets 'institution_name' attribute).
-    FWSTRUCTURALPATCH_API virtual ::fwAtoms::Object::sptr create();
+    FWSTRUCTURALPATCH_API virtual ::fwAtoms::Object::sptr create() override;
 
 };
 
 } // namespace fwMedData
 } // namespace creator
 } // namespace fwStructuralPatch
-
-#endif // __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_EQUIPMENT1_HPP__
