@@ -1,14 +1,14 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_SERIES1_HPP__
-#define __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_SERIES1_HPP__
+#pragma once
+
+#include "fwStructuralPatch/config.hpp"
 
 #include <fwAtomsPatch/IStructuralCreator.hpp>
-#include "fwStructuralPatch/config.hpp"
 
 namespace fwStructuralPatch
 {
@@ -23,7 +23,7 @@ class FWSTRUCTURALPATCH_CLASS_API Series1 : public ::fwAtomsPatch::IStructuralCr
 
 public:
 
-    fwCoreClassDefinitionsWithFactoryMacro( (Series1)(::fwAtomsPatch::IStructuralCreator),(()), new Series1) ;
+    fwCoreClassDefinitionsWithFactoryMacro( (Series1)(::fwAtomsPatch::IStructuralCreator), (()), new Series1);
 
     /// Constructor
     FWSTRUCTURALPATCH_API Series1();
@@ -32,19 +32,17 @@ public:
     FWSTRUCTURALPATCH_API ~Series1();
 
     /// Copy constructor
-    FWSTRUCTURALPATCH_API Series1( const Series1 &cpy );
+    FWSTRUCTURALPATCH_API Series1( const Series1& cpy );
 
     /**
      * @brief Creates the specified object.
      *
      * Calls creators for 'patient', 'study' and 'equipment' attributes and sets remaining attributes.
      */
-    FWSTRUCTURALPATCH_API virtual ::fwAtoms::Object::sptr create();
+    FWSTRUCTURALPATCH_API virtual ::fwAtoms::Object::sptr create() override;
 
 };
 
 } // namespace fwMedData
 } // namespace creator
 } // namespace fwStructuralPatch
-
-#endif // __FWSTRUCTURALPATCH_CREATOR_FWMEDDATA_SERIES1_HPP__
