@@ -1,34 +1,24 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2015.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2018.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSTRUCTURALPATCH_NAMESPACE_HPP__
-#define __FWSTRUCTURALPATCH_NAMESPACE_HPP__
+#pragma once
 
-/**
- * @brief Contains creators and structural patches.
- * @namespace fwStructuralPatch
- */
+/// Contains creators and structural patches.
 namespace fwStructuralPatch
 {
 
-/**
- * @brief Contains creators (implementation if ::fwAtomsPatch::IStructuralCreator).
- * @namespace fwStructuralPatch::creator
- */
+/// Contains creators (implementation if ::fwAtomsPatch::IStructuralCreator).
 namespace creator
 {
 
-/**
- * @brief Contains creators for fwMedData.
- * @namespace fwStructuralPatch::creator::fwMedData
- */
+/// Contains creators for fwMedData.
 namespace fwMedData
 {
 }
-}     // namespace creator
+} // namespace creator
 
 /// Contains the structural patch (::fwAtomsPatch::IStructuralPatch) to tranforms atoms from fwData objects.
 namespace fwData
@@ -52,8 +42,19 @@ namespace Reconstruction
 namespace Study
 {
 }
-}     // namespace fwData
+} // namespace fwData
+
+/// Contains the structural patch (::fwAtomsPatch::IStructuralPatch) to tranforms atoms from fwMedData objects.
+namespace fwMedData
+{
+/// Contains the structural patch to transform atoms from fwMedData::ImageSeries.
+namespace ImageSeries
+{
+}
+/// Contains the structural patch to transform atoms from fwMedData::ModelSeries.
+namespace ModelSeries
+{
+}
+} // namespace fwMedData
 
 } // namespace fwStructuralPatch
-
-#endif // __FWSTRUCTURALPATCH_NAMESPACE_HPP__
