@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -22,29 +22,31 @@ namespace fwMedData
 ImageSeries1::ImageSeries1()
 {
     m_classname = "::fwMedData::ImageSeries";
-    m_version = "1";
+    m_version   = "1";
 }
 
 // ----------------------------------------------------------------------------
 
 ImageSeries1::~ImageSeries1()
-{}
+{
+}
 
 // ----------------------------------------------------------------------------
 
 ImageSeries1::ImageSeries1( const ImageSeries1 &cpy ) : Series1(cpy)
-{}
+{
+}
 
 // ----------------------------------------------------------------------------
 
 ::fwAtoms::Object::sptr ImageSeries1::create()
 {
-    ::fwAtoms::Object::sptr modelSeries = this->Series1::create();
-    ::fwAtomsPatch::helper::Object helper(modelSeries);
+    ::fwAtoms::Object::sptr imageSeries = this->Series1::create();
+    ::fwAtomsPatch::helper::Object helper(imageSeries);
 
     helper.addAttribute("image", ::fwAtoms::Blob::New());
 
-    return modelSeries;
+    return imageSeries;
 }
 
 } // namespace fwMedData
