@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSTRUCTURALPATCH_TEST_TU_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
-#define __FWSTRUCTURALPATCH_TEST_TU_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
+#ifndef __FWSTRUCTURALPATCH_UT_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
+#define __FWSTRUCTURALPATCH_UT_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -23,9 +23,9 @@ namespace Patient
  */
 class V1ToFwMedDataPatientV1Test : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( V1ToFwMedDataPatientV1Test );
-    CPPUNIT_TEST( applyPatchTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( V1ToFwMedDataPatientV1Test );
+CPPUNIT_TEST( applyPatchTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -39,4 +39,4 @@ public:
 } //namespace ut
 } //namespace fwStructuralPatch
 
-#endif //__FWSTRUCTURALPATCH_TEST_TU_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
+#endif //__FWSTRUCTURALPATCH_UT_FWDATA_PATIENT_V1TOFWMEDDATAPATIENTV1TEST_HPP__
