@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWSTRUCTURALPATCH_TEST_TU_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
-#define __FWSTRUCTURALPATCH_TEST_TU_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
+#ifndef __FWSTRUCTURALPATCH_UT_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
+#define __FWSTRUCTURALPATCH_UT_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -24,9 +24,9 @@ namespace Reconstruction
  */
 class V1ToV2Test : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( V1ToV2Test );
-    CPPUNIT_TEST( applyPatchTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( V1ToV2Test );
+CPPUNIT_TEST( applyPatchTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -41,4 +41,4 @@ public:
 } //namespace ut
 } //namespace fwStructuralPatch
 
-#endif //__FWSTRUCTURALPATCH_TEST_TU_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
+#endif //__FWSTRUCTURALPATCH_UT_FWDATA_RECONSTRUCTION_V1TOV2TEST_HPP__
