@@ -1,23 +1,24 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#include <cstdlib>
-#include <sstream>
+#include "fwTest/Exception.hpp"
+#include "fwTest/Data.hpp"
 
 #include <boost/filesystem/operations.hpp>
 
-#include "fwTest/Exception.hpp"
-#include "fwTest/Data.hpp"
+#include <cstdlib>
+#include <sstream>
+
 
 namespace fwTest
 {
 
 const std::string Data::s_TEST_DATA_DIR_ENV_VAR("FWTEST_DATA_DIR");
 
-boost::filesystem::path Data::dir() throw(fwTest::Exception)
+::boost::filesystem::path Data::dir()
 {
     char * val = std::getenv(s_TEST_DATA_DIR_ENV_VAR.c_str());
     if (val == 0)
