@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -9,8 +9,7 @@
 namespace fwTest
 {
 
-Exception::Exception ( const std::string &err ) 
-    : std::runtime_error ( err )
+Exception::Exception ( const std::string &err ) : std::runtime_error ( err )
 {
 }
 
