@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWTEST_TEST_TU_IMAGETEST_HPP_
-#define _FWTEST_TEST_TU_IMAGETEST_HPP_
+#ifndef __FWTEST_UT_IMAGETEST_HPP__
+#define __FWTEST_UT_IMAGETEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -21,12 +21,12 @@ namespace ut
  */
 class ImageTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( ImageTest );
-    CPPUNIT_TEST( generator3DTest );
-    CPPUNIT_TEST( generator2DTest );
-    CPPUNIT_TEST( deepCopyTest );
-    CPPUNIT_TEST( stressTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( ImageTest );
+CPPUNIT_TEST( generator3DTest );
+CPPUNIT_TEST( generator2DTest );
+CPPUNIT_TEST( deepCopyTest );
+CPPUNIT_TEST( stressTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -48,4 +48,4 @@ private:
 } //namespace ut
 } //namespace fwTest
 
-#endif //_FWTEST_TEST_TU_IMAGETEST_HPP_
+#endif //__FWTEST_UT_IMAGETEST_HPP__
