@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2013.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef _FWTEST_TEST_TU_SERIESDBTEST_HPP_
-#define _FWTEST_TEST_TU_SERIESDBTEST_HPP_
+#ifndef __FWTEST_UT_SERIESDBTEST_HPP__
+#define __FWTEST_UT_SERIESDBTEST_HPP__
 
 #include <cppunit/extensions/HelperMacros.h>
 
@@ -19,9 +19,9 @@ namespace ut
  */
 class SeriesDBTest : public CPPUNIT_NS::TestFixture
 {
-    CPPUNIT_TEST_SUITE( SeriesDBTest );
-    CPPUNIT_TEST( generationTest );
-    CPPUNIT_TEST_SUITE_END();
+CPPUNIT_TEST_SUITE( SeriesDBTest );
+CPPUNIT_TEST( generationTest );
+CPPUNIT_TEST_SUITE_END();
 
 public:
     // interface
@@ -38,4 +38,4 @@ public:
 } //namespace ut
 } //namespace fwTest
 
-#endif //_FWTEST_TEST_TU_SERIESDBTEST_HPP_
+#endif //__FWTEST_UT_SERIESDBTEST_HPP__
