@@ -1,5 +1,5 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2017.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
@@ -7,15 +7,11 @@
 #ifndef __FWRENDERVTK_FACTORY_NEW_HPP__
 #define __FWRENDERVTK_FACTORY_NEW_HPP__
 
-#include <string>
-
-#include <boost/make_shared.hpp>
-
-#include <fwTools/macros.hpp>
-
 #include "fwRenderVTK/config.hpp"
 #include "fwRenderVTK/registry/detail.hpp"
 
+#include <string>
+
 namespace fwRenderVTK
 {
 
@@ -24,7 +20,6 @@ class IVtkRenderWindowInteractorManager;
 namespace factory
 {
 
-
 template<class CLASSNAME > SPTR( CLASSNAME )  New();
 
 /**
@@ -33,20 +28,20 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New();
  */
 class Key
 {
-    template<typename CLASSNAME>
-    friend SPTR( CLASSNAME ) fwRenderVTK::factory::New();
+template<typename CLASSNAME>
+friend SPTR( CLASSNAME ) fwRenderVTK::factory::New();
 
-    Key(){};
+Key()
+{
+}
 };
 
-
 FWRENDERVTK_API SPTR( ::fwRenderVTK::IVtkRenderWindowInteractorManager ) New(
-        const ::fwRenderVTK::registry::KeyType & classname );
-
+    const ::fwRenderVTK::registry::KeyType & classname );
 
 template<class CLASSNAME > SPTR( CLASSNAME )  New()
 {
-    SPTR(CLASSNAME) obj = ::boost::make_shared< CLASSNAME >( Key() );
+    SPTR(CLASSNAME) obj = std::make_shared< CLASSNAME >( Key() );
     return obj;
 }
 
@@ -56,4 +51,3 @@ template<class CLASSNAME > SPTR( CLASSNAME )  New()
 
 #endif /* __FWRENDERVTK_FACTORY_NEW_HPP__ */
 
-
