@@ -1,11 +1,11 @@
 /* ***** BEGIN LICENSE BLOCK *****
- * FW4SPL - Copyright (C) IRCAD, 2009-2012.
+ * FW4SPL - Copyright (C) IRCAD, 2009-2015.
  * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
  * published by the Free Software Foundation.
  * ****** END LICENSE BLOCK ****** */
 
-#ifndef __FWRENDERVTK_REGISTRY_MACRO_HPP__
-#define __FWRENDERVTK_REGISTRY_MACRO_HPP__
+#ifndef __FWRENDERVTK_REGISTRY_MACROS_HPP__
+#define __FWRENDERVTK_REGISTRY_MACROS_HPP__
 
 #include <boost/preprocessor/cat.hpp>
 
@@ -24,4 +24,4 @@ namespace registry
 } // end namespace registry
 } // end namespace fwRenderVTK
 
-#endif /*__FWRENDERVTK_REGISTRY_MACRO_HPP__*/
+#endif /*__FWRENDERVTK_REGISTRY_MACROS_HPP__*/
