@@ -51,8 +51,6 @@
 
 #include <functional>
 
-fwServicesRegisterMacro( ::fwRender::IRender, ::fwRenderVTK::SRender );
-
 using namespace fwServices;
 
 namespace fwRenderVTK
@@ -69,8 +67,8 @@ static const ::fwServices::IService::KeyType s_OFFSCREEN_INOUT = "offScreen";
 SRender::SRender() noexcept :
     m_pendingRenderRequest(false),
     m_renderMode(RenderMode::AUTO),
-    m_width(1280),
-    m_height(720),
+    m_width(160),
+    m_height(90),
     m_offScreen(false),
     m_flip(false)
 {
@@ -262,6 +260,10 @@ void SRender::configuring()
     {
         m_renderMode = RenderMode::TIMER;
     }
+    else if (renderMode == "sync")
+    {
+        m_renderMode = RenderMode::SYNC;
+    }
     else if (renderMode == "none")
     {
         m_renderMode = RenderMode::NONE;
@@ -430,7 +432,6 @@ bool SRender::isShownOnScreen()
     {
         return true;
     }
-    return false;
 }
 
 //-----------------------------------------------------------------------------
@@ -440,7 +441,15 @@ void SRender::requestRender()
     if ( this->isShownOnScreen() && !this->getPendingRenderRequest())
     {
         this->setPendingRenderRequest(true);
-        this->slot(SRender::s_RENDER_SLOT)->asyncRun();
+        if(m_renderMode == RenderMode::SYNC)
+        {
+            OSLM_DEBUG("sync SRender: " << this->getID());
+            this->slot(SRender::s_RENDER_SLOT)->run();
+        }
+        else
+        {
+            this->slot(SRender::s_RENDER_SLOT)->asyncRun();
+        }
     }
 }
 
@@ -561,4 +570,27 @@ vtkTransform* SRender::getOrAddVtkTransform( const VtkObjectIdType& _id )
 
 //-----------------------------------------------------------------------------
 
+bool SRender::isOffScreen() const
+{
+    return m_offScreen;
+}
+
+//-----------------------------------------------------------------------------
+
+void SRender::setOffScreenRenderSize(unsigned int _width, unsigned int _height)
+{
+    if(m_offScreen)
+    {
+        m_width  = std::max(_width, 1u);
+        m_height = std::max(_height, 1u);
+
+        // The MakeCurrent() is really essential otherwise this breaks the rendering of other rendering windows
+        m_interactorManager->getInteractor()->GetRenderWindow()->MakeCurrent();
+        m_interactorManager->getInteractor()->GetRenderWindow()->SetSize(static_cast<int>(m_width),
+                                                                         static_cast<int>(m_height));
+    }
+}
+
+//-----------------------------------------------------------------------------
+
 } //namespace fwRenderVTK
