@@ -1,19 +1,25 @@
-#include <iostream>
-#include <cmath>
-
-#include <vtkBitArray.h>
-#include <vtkObjectFactory.h>
-#include <vtkMath.h>
+/* ***** BEGIN LICENSE BLOCK *****
+ * FW4SPL - Copyright (C) IRCAD, 2004-2017.
+ * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
+ * published by the Free Software Foundation.
+ * ****** END LICENSE BLOCK ****** */
 
 #include "fwRenderVTK/vtk/fwVtkWindowLevelLookupTable.hpp"
 
+#include <vtkBitArray.h>
+#include <vtkMath.h>
+#include <vtkObjectFactory.h>
+
+#include <cmath>
+#include <iostream>
+
 vtkStandardNewMacro(fwVtkWindowLevelLookupTable);
 
 //----------------------------------------------------------------------------
-    fwVtkWindowLevelLookupTable::fwVtkWindowLevelLookupTable(int sze, int ext)
-: vtkLookupTable(sze, ext)
+fwVtkWindowLevelLookupTable::fwVtkWindowLevelLookupTable(int sze, int ext) :
+    vtkLookupTable(sze, ext)
 {
-    this->Level = (this->TableRange[0] + this->TableRange[1])/2;
+    this->Level  = (this->TableRange[0] + this->TableRange[1])/2;
     this->Window = (this->TableRange[1] - this->TableRange[0]);
 
     this->InverseVideo = 0;
@@ -34,16 +40,17 @@ vtkStandardNewMacro(fwVtkWindowLevelLookupTable);
     this->InvertTable->Register(this);
     this->InvertTable->Delete();
     this->InvertTable->SetNumberOfComponents(4);
-    this->InvertTable->Allocate(4*sze,4*ext);
+    this->InvertTable->Allocate(4*sze, 4*ext);
 }
 
-
 fwVtkWindowLevelLookupTable::~fwVtkWindowLevelLookupTable()
 {
     this->InvertTable->UnRegister(this);
     this->InvertTable = NULL;
 }
 
+//------------------------------------------------------------------------------
+
 void fwVtkWindowLevelLookupTable::BuildInvert()
 {
     if (this->GetMTime() < this->InvertTime)
@@ -57,13 +64,13 @@ void fwVtkWindowLevelLookupTable::BuildInvert()
 
     this->InvertTable->SetNumberOfTuples(this->NumberOfColors);
 
-    unsigned char *tableRgba, *invertTableRgba2;
+    unsigned char* tableRgba, * invertTableRgba2;
 
-    int n = this->NumberOfColors-1;
+    int n = static_cast<int>(this->NumberOfColors-1);
     for (int i = 0; i < this->NumberOfColors; i++)
     {
-        tableRgba = this->Table->GetPointer(4*i);
-        invertTableRgba2 = this->InvertTable->WritePointer(4*(n-i),4);
+        tableRgba        = this->Table->GetPointer(4*i);
+        invertTableRgba2 = this->InvertTable->WritePointer(4*(n-i), 4);
 
         invertTableRgba2[0] = tableRgba[0];
         invertTableRgba2[1] = tableRgba[1];
@@ -75,8 +82,9 @@ void fwVtkWindowLevelLookupTable::BuildInvert()
 
 }
 
+//------------------------------------------------------------------------------
 
-unsigned char * fwVtkWindowLevelLookupTable::GetCurrentPointer(const vtkIdType id)
+unsigned char* fwVtkWindowLevelLookupTable::GetCurrentPointer(const vtkIdType id)
 {
     if(this->InverseVideo)
     {
@@ -89,33 +97,31 @@ unsigned char * fwVtkWindowLevelLookupTable::GetCurrentPointer(const vtkIdType i
     }
 }
 
-
 //----------------------------------------------------------------------------
 void fwVtkWindowLevelLookupTable::PrintSelf(ostream& os, vtkIndent indent)
 {
-    this->Superclass::PrintSelf(os,indent);
+    this->Superclass::PrintSelf(os, indent);
 
     os << indent << "Window: " << this->Window << "\n";
     os << indent << "Level: " << this->Level << "\n";
     os << indent << "InverseVideo: "
-        << (this->InverseVideo ? "On\n" : "Off\n");
+       << (this->InverseVideo ? "On\n" : "Off\n");
     os << indent << "LeftClampValue : ("
-        << this->LeftClampValue[0] << ", "
-        << this->LeftClampValue[1] << ", "
-        << this->LeftClampValue[2] << ", "
-        << this->LeftClampValue[3] << ")\n";
+       << this->LeftClampValue[0] << ", "
+       << this->LeftClampValue[1] << ", "
+       << this->LeftClampValue[2] << ", "
+       << this->LeftClampValue[3] << ")\n";
     os << indent << "RightClampValue : ("
-        << this->RightClampValue[0] << ", "
-        << this->RightClampValue[1] << ", "
-        << this->RightClampValue[2] << ", "
-        << this->RightClampValue[3] << ")\n";
+       << this->RightClampValue[0] << ", "
+       << this->RightClampValue[1] << ", "
+       << this->RightClampValue[2] << ", "
+       << this->RightClampValue[3] << ")\n";
 }
 
-
 //----------------------------------------------------------------------------
 // Apply log to value, with appropriate constraints.
 inline double vtkApplyLogScale(double v, const double range[2],
-        const double logRange[2])
+                               const double logRange[2])
 {
     // is the range set for negative numbers?
     if (range[0] < 0)
@@ -151,17 +157,16 @@ inline double vtkApplyLogScale(double v, const double range[2],
     return v;
 }
 
-
 //----------------------------------------------------------------------------
 // Apply shift/scale to the scalar value v and do table lookup.
-inline unsigned char *vtkLinearLookup(double v,
-        unsigned char *table,
-        double maxIndex,
-        double shift, double scale,
-        unsigned char *nanColor,
-        unsigned char *leftColor,
-        unsigned char *rightColor
-        )
+inline unsigned char* vtkLinearLookup(double v,
+                                      unsigned char* table,
+                                      double maxIndex,
+                                      double shift, double scale,
+                                      unsigned char* nanColor,
+                                      unsigned char* leftColor,
+                                      unsigned char* rightColor
+                                      )
 {
 
     if (vtkMath::IsNan(v))
@@ -181,10 +186,9 @@ inline unsigned char *vtkLinearLookup(double v,
     return &table[4*static_cast<unsigned int>(findx)];
     /* round
        return &table[4*(unsigned int)(findx + 0.5f)];
-       */
+     */
 }
 
-
 //----------------------------------------------------------------------------
 // There is a little more to this than simply taking the log10 of the
 // two range values: we do conversion of negative ranges to positive
@@ -222,22 +226,20 @@ void fwVtkWindowLevelLookupTableLogRange(const double range[2], double logRange[
     }
 }
 
-
-
 //----------------------------------------------------------------------------
 // accelerate the mapping by copying the data in 32-bit chunks instead
 // of 8-bit chunks
-    template<class T>
-void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *input,
-        unsigned char *output, int length,
-        int inIncr, int outFormat)
+template<class T>
+void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable* self, T* input,
+                                        unsigned char* output, int length,
+                                        int inIncr, int outFormat)
 {
-    int i = length;
-    double *range = self->GetTableRange();
+    int i           = length;
+    double* range   = self->GetTableRange();
     double maxIndex = self->GetNumberOfColors() - 1;
     double shift, scale;
-    unsigned char *table = self->GetCurrentPointer(0);
-    unsigned char *cptr;
+    unsigned char* table = self->GetCurrentPointer(0);
+    unsigned char* cptr;
     double alpha;
 
     unsigned char nanColor[4];
@@ -246,22 +248,21 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
 
     for (int c = 0; c < 4; c++)
     {
-        nanColor[c] = static_cast<unsigned char>(self->GetNanColor()[c]*255.0);
-        selfLeftColor[c] = static_cast<unsigned char>(self->GetLeftClampValue()[c]*255.0);
+        nanColor[c]       = static_cast<unsigned char>(self->GetNanColor()[c]*255.0);
+        selfLeftColor[c]  = static_cast<unsigned char>(self->GetLeftClampValue()[c]*255.0);
         selfRightColor[c] = static_cast<unsigned char>(self->GetRightClampValue()[c]*255.0);
     }
 
-
-    unsigned char *leftColor = selfLeftColor;
-    unsigned char *rightColor = selfRightColor;
+    unsigned char* leftColor  = selfLeftColor;
+    unsigned char* rightColor = selfRightColor;
 
     if(self->GetClamping())
     {
-        leftColor = &table[0];
+        leftColor  = &table[0];
         rightColor = &table[(self->GetNumberOfColors()-1) * 4];
     }
 
-    if ( (alpha=self->GetAlpha()) >= 1.0 ) //no blending required
+    if ( (alpha = self->GetAlpha()) >= 1.0 ) //no blending required
     {
         if (self->GetScale() == VTK_SCALE_LOG10)
         {
@@ -285,47 +286,47 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_RGB)
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_LUMINANCE_ALPHA)
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     *output++ = cptr[3];
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else // outFormat == VTK_LUMINANCE
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     input += inIncr;
                 }
             }
@@ -352,12 +353,12 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_RGB)
@@ -365,11 +366,11 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_LUMINANCE_ALPHA)
@@ -377,11 +378,11 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     *output++ = cptr[3];
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else // outFormat == VTK_LUMINANCE
@@ -389,9 +390,9 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     input += inIncr;
                 }
             }
@@ -422,47 +423,47 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = static_cast<unsigned char>((*cptr)*alpha); cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_RGB)
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_LUMINANCE_ALPHA)
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     *output++ = static_cast<unsigned char>(alpha*cptr[3]);
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else // outFormat == VTK_LUMINANCE
             {
                 while (--i >= 0)
                 {
-                    val = vtkApplyLogScale(*input, range, logRange);
-                    cptr = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
+                    val       = vtkApplyLogScale(*input, range, logRange);
+                    cptr      = vtkLinearLookup(val, table, maxIndex, shift, scale, nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     input += inIncr;
                 }
             }
@@ -489,12 +490,12 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = static_cast<unsigned char>((*cptr)*alpha); cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_RGB)
@@ -502,11 +503,11 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = *cptr++;
                     *output++ = *cptr++;
                     *output++ = *cptr++;
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else if (outFormat == VTK_LUMINANCE_ALPHA)
@@ -514,11 +515,11 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     *output++ = static_cast<unsigned char>(cptr[3]*alpha);
-                    input += inIncr;
+                    input    += inIncr;
                 }
             }
             else // outFormat == VTK_LUMINANCE
@@ -526,9 +527,9 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
                 while (--i >= 0)
                 {
                     cptr = vtkLinearLookup(*input, table, maxIndex, shift, scale,
-                            nanColor, leftColor, rightColor);
+                                           nanColor, leftColor, rightColor);
                     *output++ = static_cast<unsigned char>(cptr[0]*0.30 + cptr[1]*0.59 +
-                            cptr[2]*0.11 + 0.5);
+                                                           cptr[2]*0.11 + 0.5);
                     input += inIncr;
                 }
             }
@@ -537,20 +538,17 @@ void fwVtkWindowLevelLookupTableMapData(fwVtkWindowLevelLookupTable *self, T *in
 
 }
 
-
-
-
 //----------------------------------------------------------------------------
 // Although this is a relatively expensive calculation,
 // it is only done on the first render. Colors are cached
 // for subsequent renders.
-    template<class T>
-void fwVtkWindowLevelLookupTableMapMag(fwVtkWindowLevelLookupTable *self, T *input,
-        unsigned char *output, int length,
-        int inIncr, int outFormat)
+template<class T>
+void fwVtkWindowLevelLookupTableMapMag(fwVtkWindowLevelLookupTable* self, T* input,
+                                       unsigned char* output, int length,
+                                       int inIncr, int outFormat)
 {
     double tmp, sum;
-    double *mag;
+    double* mag;
     int i, j;
 
     mag = new double[length];
@@ -559,7 +557,7 @@ void fwVtkWindowLevelLookupTableMapMag(fwVtkWindowLevelLookupTable *self, T *inp
         sum = 0;
         for (j = 0; j < inIncr; ++j)
         {
-            tmp = static_cast<double>(*input);
+            tmp  = static_cast<double>(*input);
             sum += (tmp * tmp);
             ++input;
         }
@@ -571,58 +569,57 @@ void fwVtkWindowLevelLookupTableMapMag(fwVtkWindowLevelLookupTable *self, T *inp
     delete [] mag;
 }
 
-
 //----------------------------------------------------------------------------
-void fwVtkWindowLevelLookupTable::MapScalarsThroughTable2(void *input,
-        unsigned char *output,
-        int inputDataType,
-        int numberOfValues,
-        int inputIncrement,
-        int outputFormat)
+void fwVtkWindowLevelLookupTable::MapScalarsThroughTable2(void* input,
+                                                          unsigned char* output,
+                                                          int inputDataType,
+                                                          int numberOfValues,
+                                                          int inputIncrement,
+                                                          int outputFormat)
 {
     if (this->UseMagnitude && inputIncrement > 1)
     {
         switch (inputDataType)
         {
             vtkTemplateMacro(
-                    fwVtkWindowLevelLookupTableMapMag(this,static_cast<VTK_TT*>(input),output,
-                        numberOfValues,inputIncrement,outputFormat);
-                    return
-                    );
+                fwVtkWindowLevelLookupTableMapMag(this, static_cast<VTK_TT*>(input), output,
+                                                  numberOfValues, inputIncrement, outputFormat);
+                return
+                );
             case VTK_BIT:
-            vtkErrorMacro("Cannot comput magnitude of bit array.");
-            break;
+                vtkErrorMacro("Cannot comput magnitude of bit array.");
+                break;
             default:
-            vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
+                vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
         }
     }
 
     switch (inputDataType)
     {
         case VTK_BIT:
+        {
+            vtkIdType i, id;
+            vtkBitArray* bitArray = vtkBitArray::New();
+            bitArray->SetVoidArray(input, numberOfValues, 1);
+            vtkUnsignedCharArray* newInput = vtkUnsignedCharArray::New();
+            newInput->SetNumberOfValues(numberOfValues);
+            for (id = i = 0; i < numberOfValues; i++, id += inputIncrement)
             {
-                vtkIdType i, id;
-                vtkBitArray *bitArray = vtkBitArray::New();
-                bitArray->SetVoidArray(input,numberOfValues,1);
-                vtkUnsignedCharArray *newInput = vtkUnsignedCharArray::New();
-                newInput->SetNumberOfValues(numberOfValues);
-                for (id=i=0; i<numberOfValues; i++, id+=inputIncrement)
-                {
-                    newInput->SetValue(i, bitArray->GetValue(id));
-                }
-                fwVtkWindowLevelLookupTableMapData(this,
-                        static_cast<unsigned char*>(newInput->GetPointer(0)),
-                        output,numberOfValues,
-                        inputIncrement,outputFormat);
-                newInput->Delete();
-                bitArray->Delete();
+                newInput->SetValue(i, static_cast<vtkUnsignedCharArray::ValueType>(bitArray->GetValue(id)));
             }
-            break;
+            fwVtkWindowLevelLookupTableMapData(this,
+                                               static_cast<unsigned char*>(newInput->GetPointer(0)),
+                                               output, numberOfValues,
+                                               inputIncrement, outputFormat);
+            newInput->Delete();
+            bitArray->Delete();
+        }
+        break;
 
             vtkTemplateMacro(
-                    fwVtkWindowLevelLookupTableMapData(this,static_cast<VTK_TT*>(input),output,
-                        numberOfValues,inputIncrement,outputFormat)
-                    );
+                fwVtkWindowLevelLookupTableMapData(this, static_cast<VTK_TT*>(input), output,
+                                                   numberOfValues, inputIncrement, outputFormat)
+                );
         default:
             vtkErrorMacro(<< "MapImageThroughTable: Unknown input ScalarType");
             return;
